@@ -22,6 +22,7 @@ import (
 	"strconv"
 
 	"github.com/apache/incubator-devlake/api/shared"
+	"github.com/apache/incubator-devlake/errors"
 	"github.com/apache/incubator-devlake/services"
 	"github.com/gin-gonic/gin"
 )
@@ -56,17 +57,17 @@ func Index(c *gin.Context) {
 	var query services.TaskQuery
 	err := c.ShouldBindQuery(&query)
 	if err != nil {
-		shared.ApiOutputError(c, err, http.StatusBadRequest)
+		shared.ApiOutputError(c, errors.BadInput.Wrap(err, shared.BadRequestBody))
 		return
 	}
 	err = c.ShouldBindUri(&query)
 	if err != nil {
-		shared.ApiOutputError(c, err, http.StatusBadRequest)
+		shared.ApiOutputError(c, errors.BadInput.Wrap(err, "bad request URI format"))
 		return
 	}
 	tasks, count, err := services.GetTasks(&query)
 	if err != nil {
-		shared.ApiOutputError(c, err, http.StatusBadRequest)
+		shared.ApiOutputError(c, errors.Default.Wrap(err, "error getting tasks"))
 		return
 	}
 	shared.ApiOutputSuccess(c, gin.H{"tasks": tasks, "count": count}, http.StatusOK)
@@ -76,12 +77,12 @@ func Delete(c *gin.Context) {
 	taskId := c.Param("taskId")
 	id, err := strconv.ParseUint(taskId, 10, 64)
 	if err != nil {
-		c.JSON(http.StatusBadRequest, "invalid task id")
+		shared.ApiOutputError(c, errors.BadInput.Wrap(err, "invalid task ID format"))
 		return
 	}
 	err = services.CancelTask(id)
 	if err != nil {
-		shared.ApiOutputError(c, err, http.StatusBadRequest)
+		shared.ApiOutputError(c, errors.Default.Wrap(err, "error cancelling task"))
 		return
 	}
 	shared.ApiOutputSuccess(c, nil, http.StatusOK)
