@@ -37,12 +37,4 @@ context('Navbar', () => {
       .should('be.visible')
       .and('have.class', 'navIconLink')
   })
-
-  it('shows merico discord icon link', () => {
-    cy.get('.navbar')
-      .should('have.class', 'bp3-navbar')
-      .find('a[href="https://discord.com/invite/83rDG6ydVZ"]')
-      .should('be.visible')
-      .and('have.class', 'navIconLink')
-  })
-})
\ No newline at end of file
+})
