@@ -18,7 +18,12 @@
 import React from 'react'
 import { Button, Intent } from '@blueprintjs/core'
 
-const ClearButton = ({ onClick, minimal = true, intent = Intent.NONE, disabled = false }) => {
+const ClearButton = ({
+  onClick,
+  minimal = true,
+  intent = Intent.NONE,
+  disabled = false
+}) => {
   return (
     <Button
       disabled={disabled}
