@@ -18,7 +18,7 @@
 import React, { useEffect, useState } from 'react'
 import {
   // BrowserRouter as Router,
-  useRouteMatch,
+  useRouteMatch
 } from 'react-router-dom'
 import { Card, Elevation } from '@blueprintjs/core'
 import request from '@/utils/request'
@@ -44,7 +44,7 @@ const Sidebar = () => {
     const fetchVersion = async () => {
       try {
         const versionUrl = `${DEVLAKE_ENDPOINT}/version`
-        const res = await request.get(versionUrl).catch(e => {
+        const res = await request.get(versionUrl).catch((e) => {
           console.log('>>> API VERSION ERROR...', e)
           setVersionTag('')
         })
@@ -57,7 +57,11 @@ const Sidebar = () => {
   }, [])
 
   return (
-    <Card interactive={false} elevation={Elevation.ZERO} className='card sidebar-card'>
+    <Card
+      interactive={false}
+      elevation={Elevation.ZERO}
+      className='card sidebar-card'
+    >
       <div className='devlake-logo'>
         <Logo width={48} height={48} className='logo' />
         <LogoText width={100} height={13} className='logo-textmark' />
@@ -82,7 +86,8 @@ const Sidebar = () => {
       <SidebarMenu menu={menu} />
       <span className='copyright-tag'>
         {/* <span className='version-tag'>{versionTag || ''}</span><br /> */}
-        <strong>Apache 2.0 License</strong><br />
+        <strong>Apache 2.0 License</strong>
+        <br />
       </span>
     </Card>
   )
