@@ -18,7 +18,8 @@
 
 import React, { Fragment } from 'react'
 import {
-  Button, Colors,
+  Button,
+  Colors,
   Position,
   Icon,
   Intent,
@@ -28,7 +29,11 @@ import {
 
 const DeleteAction = (props) => {
   const {
-    id, connection, showConfirmation = () => {}, onConfirm = () => {}, onCancel = () => {},
+    id,
+    connection,
+    showConfirmation = () => {},
+    onConfirm = () => {},
+    onCancel = () => {},
     isDisabled = false,
     isLoading = false,
     text = 'Delete',
@@ -36,13 +41,13 @@ const DeleteAction = (props) => {
   } = props
   return (
     <Popover
-      key={`delete-popover-key-${connection.ID}`}
+      key={`delete-popover-key-${connection.id}`}
       className='trigger-delete-connection'
       popoverClassName='popover-delete-connection'
       position={Position.RIGHT}
       autoFocus={false}
       enforceFocus={false}
-      isOpen={id === connection.ID}
+      isOpen={id !== null && id === connection.id}
       usePortal={false}
     >
       <a
@@ -59,7 +64,13 @@ const DeleteAction = (props) => {
       <>
         <div style={{ padding: '15px 20px 15px 15px' }}>
           {children}
-          <div style={{ display: 'flex', justifyContent: 'flex-end', marginTop: 15 }}>
+          <div
+            style={{
+              display: 'flex',
+              justifyContent: 'flex-end',
+              marginTop: 15
+            }}
+          >
             <Button
               className={Classes.POPOVER2_DISMISS}
               style={{ marginRight: 10 }}
