@@ -16,16 +16,15 @@
  *
  */
 import React, { useEffect, useMemo } from 'react'
-import {
-  Intent,
-  MenuItem,
-} from '@blueprintjs/core'
+import { Intent, MenuItem } from '@blueprintjs/core'
 import { MultiSelect, Select } from '@blueprintjs/select'
+import JiraBoard from '@/models/JiraBoard'
+
 const BoardsSelector = (props) => {
   const {
     boards = [],
     configuredConnection,
-    placeholder = 'Select boards',
+    placeholder = 'Search and select boards',
     items = [],
     selectedItems = [],
     // eslint-disable-next-line max-len
@@ -37,35 +36,32 @@ const BoardsSelector = (props) => {
     onItemSelect = () => {},
     onRemove = () => {},
     onClear = () => {},
+    onQueryChange = () => {},
     itemRenderer = (item, { handleClick, modifiers }) => (
       <MenuItem
         active={modifiers.active}
-        disabled={
-          selectedItems.find(i => i?.id === item?.id)
-        }
+        disabled={selectedItems.find((i) => i?.id === item?.id)}
         key={item.value}
         // label=
         onClick={handleClick}
         text={
-          selectedItems.find(i => i?.id === item?.id)
-            ? (
-              <>
-                <input type='checkbox' checked readOnly /> {item?.title}
-              </>
-              )
-            : (
-              <span style={{ fontWeight: 700 }}>
-                <input type='checkbox' readOnly /> {item?.title}
-              </span>
-              )
+          selectedItems.find((i) => i?.id === item?.id) ? (
+            <>
+              <input type='checkbox' checked readOnly /> {item?.title}
+            </>
+          ) : (
+            <span style={{ fontWeight: 700 }}>
+              <input type='checkbox' readOnly /> {item?.title}
+            </span>
+          )
         }
         style={{
           marginBottom: '2px',
-          fontWeight: items.includes(item) ? 700 : 'normal',
+          fontWeight: items.includes(item) ? 700 : 'normal'
         }}
       />
     ),
-    tagRenderer = (item) => item?.title,
+    tagRenderer = (item) => item?.title
   } = props
 
   return (
@@ -80,7 +76,7 @@ const BoardsSelector = (props) => {
         >
           <MultiSelect
             disabled={disabled || isSaving || isLoading}
-            // openOnKeyDown={true}
+            openOnKeyDown={true}
             resetOnSelect={true}
             placeholder={placeholder}
             popoverProps={{ usePortal: false, minimal: true }}
@@ -90,24 +86,23 @@ const BoardsSelector = (props) => {
             items={items}
             selectedItems={selectedItems}
             activeItem={activeItem}
-            itemPredicate={(query, item) =>
-              item?.title?.toLowerCase().indexOf(query.toLowerCase()) >= 0}
             itemRenderer={itemRenderer}
             tagRenderer={tagRenderer}
             tagInputProps={{
               tagProps: {
                 intent: Intent.PRIMARY,
                 minimal: true
-              },
+              }
             }}
             noResults={<MenuItem disabled={true} text='No Boards Available.' />}
+            onQueryChange={(query) => onQueryChange(query)}
             onRemove={(item) => {
               onRemove((rT) => {
                 return {
                   ...rT,
                   [configuredConnection.id]: rT[configuredConnection.id].filter(
                     (t) => t?.id !== item.id
-                  ),
+                  )
                 }
               })
             }}
@@ -118,15 +113,14 @@ const BoardsSelector = (props) => {
                       ...rT,
                       [configuredConnection.id]: [
                         ...rT[configuredConnection.id],
-                        item,
-                      ],
+                        new JiraBoard(item)
+                      ]
                     }
                   : { ...rT }
               })
             }}
             style={{ borderRight: 0 }}
           />
-
         </div>
       </div>
     </>
