@@ -15,8 +15,7 @@
  * limitations under the License.
  *
  */
-import React, { Fragment, useEffect, useState, useCallback } from 'react'
-import { CSSTransition } from 'react-transition-group'
+import React from 'react'
 import {
   Button,
   Icon,
@@ -24,6 +23,8 @@ import {
   Elevation,
   Card,
   Colors,
+  Popover,
+  PopoverInteractionKind
 } from '@blueprintjs/core'
 
 const StandardStackedList = (props) => {
@@ -38,7 +39,7 @@ const StandardStackedList = (props) => {
     onAdd = () => {},
     onChange = () => {},
     isEditing = () => {},
-    style = { padding: 0, marginTop: '10px' },
+    style = { padding: 0, marginTop: '10px' }
   } = props
 
   return (
@@ -59,7 +60,7 @@ const StandardStackedList = (props) => {
                 padding: '8px 12px',
                 borderBottom: '1px solid #f0f0f0',
                 backgroundColor:
-                  activeItem === item ? 'rgba(116, 151, 247, 0.2)' : '#fff',
+                  activeItem === item ? 'rgba(116, 151, 247, 0.2)' : '#fff'
               }}
             >
               <div>
@@ -68,14 +69,49 @@ const StandardStackedList = (props) => {
                     onClick={() => onAdd(item)}
                     style={{ cursor: 'pointer' }}
                   >
-                    {item?.name || item}
+                    {item.shortTitle || item.icon ? (
+                      <Popover
+                        className='docs-popover-portal-example-popover'
+                        interactionKind={
+                          PopoverInteractionKind.HOVER_TARGET_ONLY
+                        }
+                        content={
+                          <div
+                            style={{
+                              padding: '5px',
+                              justifyContent: 'center',
+                              display: 'flex'
+                            }}
+                          >
+                            {item.icon && (
+                              <img
+                                src={item.icon}
+                                style={{
+                                  maxWidth: '100%',
+                                  overflow: 'hidden',
+                                  width: '14px',
+                                  height: '14px',
+                                  borderRadius: '50%',
+                                  marginRight: '2px'
+                                }}
+                              />
+                            )}
+                            {item.title}
+                          </div>
+                        }
+                      >
+                        {item.shortTitle || item.title}
+                      </Popover>
+                    ) : (
+                      item.title
+                    )}
                   </label>
                 </div>
               </div>
               <div
                 style={{
                   display: 'flex',
-                  alignContent: 'center',
+                  alignContent: 'center'
                 }}
               >
                 <div className='item-actions' style={{ paddingLeft: '20px' }}>
@@ -90,7 +126,7 @@ const StandardStackedList = (props) => {
                     style={{
                       minWidth: '18px',
                       minHeight: '18px',
-                      fontSize: '11px',
+                      fontSize: '11px'
                     }}
                     onClick={() => onAdd(item)}
                   />
