@@ -15,29 +15,22 @@
  * limitations under the License.
  *
  */
-import React, { Fragment, useEffect, useState, useCallback, useMemo } from 'react'
+import React, { useEffect, useMemo } from 'react'
 import {
   Button,
-  Icon,
-  Intent,
-  TagInput,
+  Card,
   Divider,
   Elevation,
-  Card,
-  Colors,
+  Intent,
+  TagInput
 } from '@blueprintjs/core'
-import {
-  Providers,
-  ProviderTypes,
-  ProviderIcons,
-  ConnectionStatus,
-  ConnectionStatusLabels,
-} from '@/data/Providers'
-
+import { ProviderIcons, Providers } from '@/data/Providers'
 import ConnectionTabs from '@/components/blueprints/ConnectionTabs'
 import BoardsSelector from '@/components/blueprints/BoardsSelector'
 import DataEntitiesSelector from '@/components/blueprints/DataEntitiesSelector'
 import NoData from '@/components/NoData'
+import GitlabProjectsSelector from '@/components/blueprints/GitlabProjectsSelector'
+import GitHubProject from '@/models/GithubProject'
 
 const DataScopes = (props) => {
   const {
@@ -46,6 +39,9 @@ const DataScopes = (props) => {
     blueprintConnections = [],
     dataEntitiesList = [],
     boardsList = [],
+    fetchGitlabProjects = () => [],
+    isFetchingGitlab = false,
+    gitlabProjects = [],
     dataEntities = [],
     projects = [],
     boards = [],
@@ -55,6 +51,7 @@ const DataScopes = (props) => {
     setDataEntities = () => {},
     setProjects = () => {},
     setBoards = () => {},
+    setBoardSearch = () => {},
     prevStep = () => {},
     fieldHasError = () => {},
     getFieldError = () => {},
@@ -66,14 +63,28 @@ const DataScopes = (props) => {
     cardStyle = {}
   } = props
 
-  const selectedBoards = useMemo(() => boards[configuredConnection.id], [boards, configuredConnection?.id])
+  const selectedBoards = useMemo(
+    () => boards[configuredConnection.id],
+    [boards, configuredConnection?.id]
+  )
+  const selectedProjects = useMemo(
+    () => projects[configuredConnection.id],
+    [projects, configuredConnection?.id]
+  )
 
   useEffect(() => {
     console.log('>> OVER HERE!!!', selectedBoards)
   }, [selectedBoards])
 
+  useEffect(() => {
+    console.log('>> OVER HERE FOR Projects!!!', selectedProjects)
+  }, [selectedProjects])
+
   return (
-    <div className='workflow-step workflow-step-data-scope' data-step={activeStep?.id}>
+    <div
+      className='workflow-step workflow-step-data-scope'
+      data-step={activeStep?.id}
+    >
       {blueprintConnections.length > 0 && (
         <div style={{ display: 'flex' }}>
           {enableConnectionTabs && (
@@ -108,40 +119,49 @@ const DataScopes = (props) => {
                 <>
                   <h3>
                     <span style={{ float: 'left', marginRight: '8px' }}>
-                      {ProviderIcons[configuredConnection.provider]
-                        ? (
-                            ProviderIcons[configuredConnection.provider](24, 24)
-                          )
-                        : (
-                          <></>
-                          )}
+                      {ProviderIcons[configuredConnection.provider] ? (
+                        ProviderIcons[configuredConnection.provider](24, 24)
+                      ) : (
+                        <></>
+                      )}
                     </span>{' '}
                     {configuredConnection.title}
                   </h3>
                   <Divider className='section-divider' />
 
-                  {[Providers.GITLAB, Providers.GITHUB].includes(
+                  {[Providers.GITHUB].includes(
                     configuredConnection.provider
                   ) && (
                     <>
                       <h4>Projects *</h4>
-                      {configuredConnection.provider === Providers.GITHUB && (<p>Enter the project names you would like to sync.</p>)}
-                      {configuredConnection.provider === Providers.GITLAB && (<p>Enter the project ids you would like to sync.</p>)}
+                      <p>Enter the project names you would like to sync.</p>
                       <TagInput
                         id='project-id'
                         disabled={isRunning}
-                        placeholder={
-                          configuredConnection.provider === Providers.GITHUB
-                            ? 'username/repo, username/another-repo'
-                            : '1000000, 200000'
+                        placeholder='username/repo, username/another-repo'
+                        values={
+                          projects[configuredConnection.id]?.map(
+                            (p) => p.value
+                          ) || []
                         }
-                        values={projects[configuredConnection.id] || []}
                         fill={true}
                         onChange={(values) =>
                           setProjects((p) => ({
                             ...p,
-                            [configuredConnection.id]: [...new Set(values)],
-                          }))}
+                            [configuredConnection.id]: [
+                              ...values.map(
+                                (v, vIdx) =>
+                                  new GitHubProject({
+                                    id: v,
+                                    key: v,
+                                    title: v,
+                                    value: v,
+                                    type: 'string'
+                                  })
+                              )
+                            ]
+                          }))
+                        }
                         addOnPaste={true}
                         addOnBlur={true}
                         rightElement={
@@ -152,15 +172,21 @@ const DataScopes = (props) => {
                             onClick={() =>
                               setProjects((p) => ({
                                 ...p,
-                                [configuredConnection.id]: [],
-                              }))}
+                                [configuredConnection.id]: []
+                              }))
+                            }
                           />
                         }
                         onKeyDown={(e) =>
-                          e.key === 'Enter' && e.preventDefault()}
+                          e.key === 'Enter' && e.preventDefault()
+                        }
                         tagProps={{
-                          intent: validationErrors.some(e => e.startsWith('Projects:')) ? Intent.WARNING : Intent.PRIMARY,
-                          minimal: true,
+                          intent: validationErrors.some((e) =>
+                            e.startsWith('Projects:')
+                          )
+                            ? Intent.WARNING
+                            : Intent.PRIMARY,
+                          minimal: true
                         }}
                         className='input-project-id tagInput'
                       />
@@ -174,6 +200,7 @@ const DataScopes = (props) => {
                       <BoardsSelector
                         items={boardsList}
                         selectedItems={selectedBoards}
+                        onQueryChange={setBoardSearch}
                         onItemSelect={setBoards}
                         onClear={setBoards}
                         onRemove={setBoards}
@@ -184,6 +211,27 @@ const DataScopes = (props) => {
                     </>
                   )}
 
+                  {[Providers.GITLAB].includes(
+                    configuredConnection.provider
+                  ) && (
+                    <>
+                      <h4>Projects *</h4>
+                      <p>Select the project you would like to sync.</p>
+                      <GitlabProjectsSelector
+                        onFetch={fetchGitlabProjects}
+                        isFetching={isFetchingGitlab}
+                        items={gitlabProjects}
+                        selectedItems={selectedProjects}
+                        onItemSelect={setProjects}
+                        onClear={setProjects}
+                        onRemove={setProjects}
+                        disabled={isSaving}
+                        configuredConnection={configuredConnection}
+                        isLoading={isFetching}
+                      />
+                    </>
+                  )}
+
                   <h4>Data Entities</h4>
                   <p>
                     Select the data entities you wish to collect for the
