@@ -16,10 +16,7 @@
  *
  */
 import React, { Fragment } from 'react'
-import {
-  Icon,
-  Colors
-} from '@blueprintjs/core'
+import { Icon, Colors } from '@blueprintjs/core'
 const FormValidationErrors = (props) => {
   const { errors = [], textAlign = 'right', styles = {} } = props
 
@@ -28,10 +25,13 @@ const FormValidationErrors = (props) => {
       {errors.length > 0 && (
         <div className='validation-errors'>
           <p style={{ margin: '5px 0 5px 0', textAlign: textAlign, ...styles }}>
-            <Icon icon='warning-sign' size={13} color={Colors.ORANGE4} style={{ marginRight: '6px', marginBottom: '2px' }} />
-            <span>
-              {errors[0]}
-            </span>
+            <Icon
+              icon='warning-sign'
+              size={13}
+              color={Colors.ORANGE4}
+              style={{ marginRight: '6px', marginBottom: '2px' }}
+            />
+            <span>{errors[0]}</span>
           </p>
         </div>
       )}
