@@ -17,13 +17,7 @@
  */
 import React, { useState, useEffect } from 'react'
 import { CSSTransition } from 'react-transition-group'
-import {
-  Icon,
-  Colors,
-  H4,
-  Spinner,
-  Intent,
-} from '@blueprintjs/core'
+import { Icon, Colors, H4, Spinner, Intent } from '@blueprintjs/core'
 import dayjs from '@/utils/time'
 import StageTask from '@/components/pipelines/StageTask'
 import StageLaneStatus from '@/components/pipelines/StageLaneStatus'
@@ -35,19 +29,22 @@ const StageLane = (props) => {
   const [readyStageModules, setReadyStageModules] = useState([])
 
   const isStageActive = (stageId) => {
-    return stages[stageId].some(s => s.status === 'TASK_RUNNING')
+    return stages[stageId].some((s) => s.status === 'TASK_RUNNING')
   }
 
   const isStageCompleted = (stageId) => {
-    return stages[stageId].every(s => s.status === 'TASK_COMPLETED')
+    return stages[stageId].every((s) => s.status === 'TASK_COMPLETED')
   }
 
   const isStageFailed = (stageId) => {
-    return !isStageActive(stageId) && stages[stageId].some(s => s.status === 'TASK_FAILED')
+    return (
+      !isStageActive(stageId) &&
+      stages[stageId].some((s) => s.status === 'TASK_FAILED')
+    )
   }
 
   const isStagePending = (stageId) => {
-    return stages[stageId].every(s => s.status === 'TASK_CREATED')
+    return stages[stageId].every((s) => s.status === 'TASK_CREATED')
   }
 
   const generateStageCssClasses = (stageId) => {
@@ -68,39 +65,63 @@ const StageLane = (props) => {
   }
 
   const calculateStageLaneProgress = (stageTasks) => {
-    const completed = stageTasks.filter(s => s.status === 'TASK_COMPLETED')
-    const remaining = stageTasks.filter(s => s.status !== 'TASK_COMPLETED')
+    const completed = stageTasks.filter((s) => s.status === 'TASK_COMPLETED')
+    const remaining = stageTasks.filter((s) => s.status !== 'TASK_COMPLETED')
     const minProgressValue = 0.05
     let progress = completed.length / (remaining.length + completed.length)
-    console.log('>>> STAGE LANE PROGRESS  = ', completed, remaining, completed.length / remaining.length)
+    console.log(
+      '>>> STAGE LANE PROGRESS  = ',
+      completed,
+      remaining,
+      completed.length / remaining.length
+    )
     if (stageTasks.length === 1) {
       progress = Math.max(minProgressValue, stageTasks[0].progress)
     }
     if (completed.length === 0 && remaining.length === stageTasks.length) {
-      progress = stageTasks.reduce((pV, cV) => pV + cV.progress, minProgressValue)
+      progress = stageTasks.reduce(
+        (pV, cV) => pV + cV.progress,
+        minProgressValue
+      )
     }
     return progress
   }
 
-  const calculateStageLaneDuration = (stageTasks, unit = 'minute', parallelMode = true) => {
+  const calculateStageLaneDuration = (
+    stageTasks,
+    unit = 'minute',
+    parallelMode = true
+  ) => {
     let duration = 0
     const now = dayjs()
-    const diffDuration = (pV, cV) => pV + dayjs(cV.status === 'TASK_RUNNING'
-      ? now
-      : (cV.status === 'TASK_FAILED' ? cV.finishedAt == null : cV.updatedAt || cV.finishedAt)).diff(dayjs(cV.beganAt), unit)
-    const filterParallel = (pV, cV) => !pV.some(t => t.createdAt.split('.')[0] === cV.createdAt.split('.')[0]) ? [...pV, cV] : [...pV]
+    const diffDuration = (pV, cV) =>
+      pV +
+      dayjs(
+        cV.status === 'TASK_RUNNING'
+          ? now
+          : cV.status === 'TASK_FAILED'
+          ? cV.finishedAt == null
+          : cV.updatedAt || cV.finishedAt
+      ).diff(dayjs(cV.beganAt), unit)
+    const filterParallel = (pV, cV) =>
+      !pV.some((t) => t.createdAt.split('.')[0] === cV.createdAt.split('.')[0])
+        ? [...pV, cV]
+        : [...pV]
     const parallelTasks = stageTasks.reduce(filterParallel, [])
-    duration = parallelMode && !isStageFailed(sK) ? parallelTasks.reduce(diffDuration, 0) : stageTasks.reduce(diffDuration, 0)
+    duration =
+      parallelMode && !isStageFailed(sK)
+        ? parallelTasks.reduce(diffDuration, 0)
+        : stageTasks.reduce(diffDuration, 0)
     // console.log('>> CALCULATED DURATION =', stageTasks, duration)
     return duration
   }
 
   const getRunningTaskCount = (stageTasks) => {
-    return stageTasks.filter(s => s.status === 'TASK_RUNNING').length
+    return stageTasks.filter((s) => s.status === 'TASK_RUNNING').length
   }
 
   const getCompletedTaskCount = (stageTasks) => {
-    return stageTasks.filter(s => s.status === 'TASK_COMPLETED').length
+    return stageTasks.filter((s) => s.status === 'TASK_COMPLETED').length
   }
 
   const getTotalTasksCount = (stageTasks) => {
@@ -116,20 +137,20 @@ const StageLane = (props) => {
     if (activeStage.length > 0) {
       activeStage.forEach((s, sIdx) => {
         setTimeout(() => {
-          setReadyStageModules(rS => [...rS, sIdx])
+          setReadyStageModules((rS) => [...rS, sIdx])
         }, sIdx * 150)
       })
     }
-    return () => {
-
-    }
+    return () => {}
   }, [activeStage])
 
   return (
     <>
       <div
         // key={`stage-lane-key-${sIdx}`}
-        className={`stage-lane ${generateStageCssClasses(sK)} ${isStageActive(sK) ? '' : ''}`}
+        className={`stage-lane ${generateStageCssClasses(sK)} ${
+          isStageActive(sK) ? '' : ''
+        }`}
         style={{
           position: 'relative',
           display: 'flex',
@@ -142,7 +163,14 @@ const StageLane = (props) => {
         }}
       >
         {isStageActive(sK) && (
-          <span style={{ position: 'absolute', display: 'inline-block', right: '8px', top: '8px' }}>
+          <span
+            style={{
+              position: 'absolute',
+              display: 'inline-block',
+              right: '8px',
+              top: '8px'
+            }}
+          >
             <Spinner size={14} intent={Intent.PRIMARY} />
           </span>
         )}
@@ -151,7 +179,12 @@ const StageLane = (props) => {
             icon='error'
             color={Colors.RED5}
             size={14}
-            style={{ position: 'absolute', display: 'inline-block', right: '8px', top: '8px' }}
+            style={{
+              position: 'absolute',
+              display: 'inline-block',
+              right: '8px',
+              top: '8px'
+            }}
           />
         )}
         {isStageCompleted(sK) && (
@@ -159,29 +192,30 @@ const StageLane = (props) => {
             icon='tick'
             color={Colors.GREEN5}
             size={14}
-            style={{ position: 'absolute', display: 'inline-block', right: '8px', top: '8px' }}
+            style={{
+              position: 'absolute',
+              display: 'inline-block',
+              right: '8px',
+              top: '8px'
+            }}
           />
         )}
-        <H4
-          className='stage-title'
-          style={{
-
-          }}
-        >
+        <H4 className='stage-title' style={{}}>
           Stage {sIdx + 1}
         </H4>
         {/* {sIdx} */}
-        {showStageTasks && stages[sK].map((t, tIdx) => (
-          <CSSTransition
-            key={`fx-key-stage-task-${tIdx}`}
-            in={readyStageModules.includes(tIdx)}
-            timeout={350}
-            classNames='pipeline-task-fx'
-            // unmountOnExit
-          >
-            <StageTask task={t} key={`stage-task-key-${tIdx}`} />
-          </CSSTransition>
-        ))}
+        {showStageTasks &&
+          stages[sK].map((t, tIdx) => (
+            <CSSTransition
+              key={`fx-key-stage-task-${tIdx}`}
+              in={readyStageModules.includes(tIdx)}
+              timeout={350}
+              classNames='pipeline-task-fx'
+              // unmountOnExit
+            >
+              <StageTask task={t} key={`stage-task-key-${tIdx}`} />
+            </CSSTransition>
+          ))}
         {/* <StageLaneStatus
           sK={sK}
           stage={activeStage}
