@@ -41,12 +41,29 @@ const StageTaskCaption = (props) => {
           {task.status === 'TASK_RUNNING'
             ? dayjs(task.beganAt).toNow(true)
             : dayjs(task.beganAt).from(task.finishedAt || task.updatedAt, true)}
-        </span>)}
-      {task.status === 'TASK_RUNNING' && <span>Subtask {task?.progressDetail?.finishedSubTasks} / {task?.progressDetail?.totalSubTasks}</span>}
-      {task.status === 'TASK_COMPLETED' && <span>{task?.progressDetail?.finishedSubTasks || 'All'} Subtasks completed</span>}
-      {task.status === 'TASK_COMPLETED' && <span>{task?.progressDetail?.finishedRecords}</span>}
+        </span>
+      )}
+      {task.status === 'TASK_RUNNING' && (
+        <span>
+          Subtask {task?.progressDetail?.finishedSubTasks} /{' '}
+          {task?.progressDetail?.totalSubTasks}
+        </span>
+      )}
+      {task.status === 'TASK_COMPLETED' && (
+        <span>
+          {task?.progressDetail?.finishedSubTasks || 'All'} Subtasks completed
+        </span>
+      )}
+      {task.status === 'TASK_COMPLETED' && (
+        <span>{task?.progressDetail?.finishedRecords}</span>
+      )}
       {task.status === 'TASK_CREATED' && <span>Records Pending</span>}
-      {task.status === 'TASK_FAILED' && <span style={{ color: Colors.RED3 }}>Task failed &mdash; <strong>{task?.failedSubTask || task?.message}</strong></span>}
+      {task.status === 'TASK_FAILED' && (
+        <span style={{ color: Colors.RED3 }}>
+          Task failed &mdash;{' '}
+          <strong>{task?.failedSubTask || task?.message}</strong>
+        </span>
+      )}
     </span>
   )
 }
