@@ -25,7 +25,7 @@ import {
   Intent,
   Tag,
   Tooltip,
-  Colors,
+  Colors
 } from '@blueprintjs/core'
 import RefDiffTasksMenu from '@/components/menus/RefDiffTasksMenu'
 
@@ -39,16 +39,18 @@ const RefDiffSettings = (props) => {
     isEnabled,
     setRepoId = () => {},
     setTasks = () => {},
-    setPairs = () => {},
+    setPairs = () => {}
   } = props
 
   const [refDiffOldTag, setOldTag] = useState('')
   const [refDiffNewTag, setNewTag] = useState('')
 
   const handleRefDiffTaskSelect = (e, task) => {
-    setTasks(t => t.includes(task.task)
-      ? t.filter(t2 => t2 !== task.task)
-      : [...new Set([...t, task.task])])
+    setTasks((t) =>
+      t.includes(task.task)
+        ? t.filter((t2) => t2 !== task.task)
+        : [...new Set([...t, task.task])]
+    )
   }
 
   // eslint-disable-next-line no-unused-vars
@@ -60,28 +62,42 @@ const RefDiffSettings = (props) => {
   }
 
   const addRefDiffPairObject = (oldRef, newRef) => {
-    setPairs(pairs => (!pairs.some(p => p.oldRef === oldRef && p.newRef === newRef))
-      ? [...pairs, { oldRef, newRef }]
-      : [...pairs])
+    setPairs((pairs) =>
+      !pairs.some((p) => p.oldRef === oldRef && p.newRef === newRef)
+        ? [...pairs, { oldRef, newRef }]
+        : [...pairs]
+    )
     setNewTag('')
     setOldTag('')
   }
 
   const removeRefDiffPairObject = (oldRef, newRef) => {
-    setPairs(pairs => pairs.filter(p => !(p.oldRef === oldRef && p.newRef === newRef)))
+    setPairs((pairs) =>
+      pairs.filter((p) => !(p.oldRef === oldRef && p.newRef === newRef))
+    )
   }
 
   return (
     <>
       <FormGroup
         disabled={isRunning || !isEnabled(providerId)}
-        label={<strong>Repository ID<span className='requiredStar'>*</span></strong>}
-        labelInfo={<span style={{ display: 'block' }}>Enter Repo Column ID</span>}
+        label={
+          <strong>
+            Repository ID<span className='requiredStar'>*</span>
+          </strong>
+        }
+        labelInfo={
+          <span style={{ display: 'block' }}>Enter Repo Column ID</span>
+        }
         inline={false}
         labelFor='refdiff-repo-id'
         className=''
         contentClassName=''
-        style={{ minWidth: '280px', marginBottom: 'auto', whiteSpace: 'nowrap' }}
+        style={{
+          minWidth: '280px',
+          marginBottom: 'auto',
+          whiteSpace: 'nowrap'
+        }}
         fill
       >
         <InputGroup
@@ -98,46 +114,73 @@ const RefDiffSettings = (props) => {
       </FormGroup>
       <FormGroup
         disabled={isRunning || !isEnabled(providerId)}
-        label={(
-          <strong>Tasks<span className='requiredStar'>*</span>
+        label={
+          <strong>
+            Tasks<span className='requiredStar'>*</span>
             <span
               className='badge-count'
               style={{
                 opacity: isEnabled(providerId) ? 0.5 : 0.1
               }}
-            >{tasks.length}
+            >
+              {tasks.length}
             </span>
           </strong>
-        )}
-        labelInfo={<span style={{ display: 'block' }}>Select Tasks to Execute</span>}
+        }
+        labelInfo={
+          <span style={{ display: 'block' }}>Select Tasks to Execute</span>
+        }
         inline={false}
         labelFor='refdiff-tasks'
         className=''
         contentClassName=''
-        style={{ marginLeft: '12px', marginRight: '12px', marginBottom: 'auto', whiteSpace: 'nowrap' }}
+        style={{
+          marginLeft: '12px',
+          marginRight: '12px',
+          marginBottom: 'auto',
+          whiteSpace: 'nowrap'
+        }}
         fill
       >
-
         <Popover
           className='provider-tasks-popover'
           disabled={isRunning || !isEnabled(providerId)}
-          content={(
-            <RefDiffTasksMenu onSelect={handleRefDiffTaskSelect} selected={tasks} />
-          )}
+          content={
+            <RefDiffTasksMenu
+              onSelect={handleRefDiffTaskSelect}
+              selected={tasks}
+            />
+          }
           placement='top-center'
         >
           <ButtonGroup disabled={isRunning || !isEnabled(providerId)}>
             <Button
               disabled={isRunning || !isEnabled(providerId)}
               icon='menu'
-              text={tasks.length > 0
-                ? <>Choose Tasks <Tag intent={Intent.PRIMARY} round>{tasks.length}</Tag></>
-                : <>Choose Tasks <Tag intent={Intent.PRIMARY} round>None</Tag></>}
+              text={
+                tasks.length > 0 ? (
+                  <>
+                    Choose Tasks{' '}
+                    <Tag intent={Intent.PRIMARY} round>
+                      {tasks.length}
+                    </Tag>
+                  </>
+                ) : (
+                  <>
+                    Choose Tasks{' '}
+                    <Tag intent={Intent.PRIMARY} round>
+                      None
+                    </Tag>
+                  </>
+                )
+              }
             />
             <Button
               icon='eraser'
               intent={Intent.WARNING}
-              disabled={isRunning || !isEnabled(providerId) || tasks.length === 0}
+              disabled={
+                isRunning || !isEnabled(providerId) || tasks.length === 0
+              }
               onClick={() => setTasks([])}
             />
           </ButtonGroup>
@@ -146,18 +189,22 @@ const RefDiffSettings = (props) => {
       <div style={{ display: 'flex', flex: 1, width: '100%' }}>
         <FormGroup
           disabled={isRunning || !isEnabled(providerId)}
-          label={(
-            <strong>Tags<span className='requiredStar'>*</span>
+          label={
+            <strong>
+              Tags<span className='requiredStar'>*</span>
               <span
                 className='badge-count'
                 style={{
                   opacity: isEnabled(providerId) ? 0.5 : 0.1
                 }}
-              >{pairs.length}
+              >
+                {pairs.length}
               </span>
             </strong>
-          )}
-          labelInfo={<span style={{ display: 'block' }}>Specify tag Ref Pairs</span>}
+          }
+          labelInfo={
+            <span style={{ display: 'block' }}>Specify tag Ref Pairs</span>
+          }
           inline={false}
           labelFor='refdiff-pair-newref'
           className=''
@@ -169,14 +216,16 @@ const RefDiffSettings = (props) => {
             <div>
               <InputGroup
                 id='refdiff-pair-newref'
-                leftElement={(
+                leftElement={
                   <Tag
-                    intent={Intent.WARNING} style={{
+                    intent={Intent.WARNING}
+                    style={{
                       opacity: isEnabled(providerId) ? 1 : 0.3
                     }}
-                  >New Ref
+                  >
+                    New Ref
                   </Tag>
-                )}
+                }
                 inline={true}
                 disabled={isRunning || !isEnabled(providerId)}
                 placeholder='eg. refs/tags/v0.6.0'
@@ -189,14 +238,15 @@ const RefDiffSettings = (props) => {
             <div style={{ marginLeft: '10px', marginRight: 0 }}>
               <InputGroup
                 id='refdiff-pair-oldref'
-                leftElement={(
+                leftElement={
                   <Tag
                     style={{
                       opacity: isEnabled(providerId) ? 1 : 0.3
                     }}
-                  >Old Ref
+                  >
+                    Old Ref
                   </Tag>
-                )}
+                }
                 inline={true}
                 disabled={isRunning || !isEnabled(providerId)}
                 placeholder='eg. refs/tags/v0.5.0'
@@ -204,18 +254,24 @@ const RefDiffSettings = (props) => {
                 onChange={(e) => setOldTag(e.target.value)}
                 autoComplete='off'
                 fill={false}
-                rightElement={(
+                rightElement={
                   <Tooltip content='Add Tag Pair'>
                     <Button
                       className='btn-add-tagpair'
                       intent={Intent.PRIMARY}
-                      disabled={!refDiffOldTag || !refDiffNewTag || refDiffOldTag === refDiffNewTag}
+                      disabled={
+                        !refDiffOldTag ||
+                        !refDiffNewTag ||
+                        refDiffOldTag === refDiffNewTag
+                      }
                       icon='plus'
                       style={{}}
-                      onClick={() => addRefDiffPairObject(refDiffOldTag, refDiffNewTag)}
+                      onClick={() =>
+                        addRefDiffPairObject(refDiffOldTag, refDiffNewTag)
+                      }
                     />
                   </Tooltip>
-                )}
+                }
               />
             </div>
             <div style={{ display: 'flex', justifyContent: 'flex-end' }}>
@@ -238,12 +294,23 @@ const RefDiffSettings = (props) => {
             }}
           >
             {pairs.map((pair, pairIdx) => (
-              <div key={`refdiff-added-pairs-itemkey-$${pairIdx}`} style={{ display: 'flex' }}>
+              <div
+                key={`refdiff-added-pairs-itemkey-$${pairIdx}`}
+                style={{ display: 'flex' }}
+              >
                 <div style={{ flex: 1 }}>
-                  <Tag intent={Intent.WARNING} round='false' small>new</Tag> {pair.newRef}
+                  <Tag intent={Intent.WARNING} round='false' small>
+                    new
+                  </Tag>{' '}
+                  {pair.newRef}
                 </div>
-                <div style={{ flex: 1, marginLeft: '10px', marginRight: '10px' }}>
-                  <Tag round='false' small>old</Tag> {pair.oldRef}
+                <div
+                  style={{ flex: 1, marginLeft: '10px', marginRight: '10px' }}
+                >
+                  <Tag round='false' small>
+                    old
+                  </Tag>{' '}
+                  {pair.oldRef}
                 </div>
                 <div style={{ display: 'flex', justifyContent: 'flex-end' }}>
                   <Button
@@ -252,12 +319,20 @@ const RefDiffSettings = (props) => {
                     minimal
                     small='true'
                     style={{ marginTop: 'auto', alignSelf: 'center' }}
-                    onClick={() => removeRefDiffPairObject(pair.oldRef, pair.newRef)}
+                    onClick={() =>
+                      removeRefDiffPairObject(pair.oldRef, pair.newRef)
+                    }
                   />
                 </div>
               </div>
             ))}
-            {pairs.length === 0 && <><span style={{ color: Colors.GRAY3 }}>( No Tag Pairs Added)</span></>}
+            {pairs.length === 0 && (
+              <>
+                <span style={{ color: Colors.GRAY3 }}>
+                  ( No Tag Pairs Added)
+                </span>
+              </>
+            )}
           </div>
         </FormGroup>
       </div>
