@@ -15,17 +15,18 @@
  * limitations under the License.
  *
  */
-const API_VERSION = 2
+const JIRA_API_VERSION = 2
 // @todo: add string replacer for [:connectionId] or refactor this const
-const API_PROXY_ENDPOINT = '/api/plugins/jira/connections/[:connectionId:]/proxy/rest'
-const ISSUE_TYPES_ENDPOINT = `${API_PROXY_ENDPOINT}/api/${API_VERSION}/issuetype`
-const ISSUE_FIELDS_ENDPOINT = `${API_PROXY_ENDPOINT}/api/${API_VERSION}/field`
-const BOARDS_ENDPOINT = `${API_PROXY_ENDPOINT}/agile/1.0/board`
+const JIRA_API_PROXY_ENDPOINT =
+  '/api/plugins/jira/connections/[:connectionId:]/proxy/rest'
+const ISSUE_TYPES_ENDPOINT = `${JIRA_API_PROXY_ENDPOINT}/api/${JIRA_API_VERSION}/issuetype`
+const ISSUE_FIELDS_ENDPOINT = `${JIRA_API_PROXY_ENDPOINT}/api/${JIRA_API_VERSION}/field`
+const BOARDS_ENDPOINT = `${JIRA_API_PROXY_ENDPOINT}/agile/1.0/board`
 
 export {
-  API_VERSION,
-  API_PROXY_ENDPOINT,
+  JIRA_API_VERSION,
+  JIRA_API_PROXY_ENDPOINT,
   ISSUE_TYPES_ENDPOINT,
   ISSUE_FIELDS_ENDPOINT,
-  BOARDS_ENDPOINT,
+  BOARDS_ENDPOINT
 }
