@@ -20,6 +20,8 @@ const starRocksConfig = [
     {
       plugin: 'starrocks',
       options: {
+        source_type: '', // mysql or postgres
+        source_dsn: '', // gorm dsn
         host: '127.0.0.1',
         port: 9030,
         user: 'root',
@@ -36,6 +38,4 @@ const starRocksConfig = [
   ]
 ]
 
-export {
-  starRocksConfig
-}
+export { starRocksConfig }
