@@ -20,7 +20,8 @@ import { useHistory } from 'react-router-dom'
 import { ToastNotification } from '@/components/Toast'
 import { DEVLAKE_ENDPOINT } from '@/utils/config'
 import request from '@/utils/request'
-import { NullConnection } from '@/data/NullConnection'
+import Connection from '@/models/Connection'
+import ProviderListConnection from '@/models/ProviderListConnection'
 import {
   Providers,
   ProviderConnectionLimits,
@@ -30,11 +31,8 @@ import {
 
 import useNetworkOfflineMode from '@/hooks/useNetworkOfflineMode'
 
-function useConnectionManager (
-  {
-    activeProvider,
-    connectionId,
-  },
+function useConnectionManager(
+  { activeProvider, connectionId },
   updateMode = false
 ) {
   const history = useHistory()
@@ -42,15 +40,13 @@ function useConnectionManager (
 
   const [provider, setProvider] = useState(activeProvider)
   const [name, setName] = useState()
+  // @todo: refactor to endpoint and setEndpoint
   const [endpointUrl, setEndpointUrl] = useState()
   const [proxy, setProxy] = useState()
-  const [rateLimit, setRateLimit] = useState(0)
+  const [rateLimitPerHour, setRateLimitPerHour] = useState(0)
   const [token, setToken] = useState()
-  const [initialTokenStore, setInitialTokenStore] = useState({
-    0: '',
-    1: '',
-    2: ''
-  })
+  const defaultTokenStore = useMemo(() => ({ 0: '', 1: '', 2: '' }), [])
+  const [initialTokenStore, setInitialTokenStore] = useState(defaultTokenStore)
   const [username, setUsername] = useState()
   const [password, setPassword] = useState()
 
@@ -67,19 +63,44 @@ function useConnectionManager (
   const [allTestResponses, setAllTestResponses] = useState({})
   const [sourceLimits, setConnectionLimits] = useState(ProviderConnectionLimits)
 
-  const [activeConnection, setActiveConnection] = useState(NullConnection)
+  const [activeConnection, setActiveConnection] = useState(new Connection())
   const [allConnections, setAllConnections] = useState([])
   const [allProviderConnections, setAllProviderConnections] = useState([])
   const [domainRepositories, setDomainRepositories] = useState([])
   const [testedConnections, setTestedConnections] = useState([])
-  const [connectionCount, setConnectionCount] = useState(0)
-  const [connectionLimitReached, setConnectionLimitReached] = useState(false)
-
+  const connectionCount = useMemo(() => allConnections.length, [allConnections])
+  const connectionLimitReached = useMemo(
+    () =>
+      sourceLimits[provider?.id] &&
+      connectionCount >= sourceLimits[provider?.id],
+    [provider?.id, sourceLimits, connectionCount]
+  )
   const [connectionsList, setConnectionsList] = useState([])
 
   const [saveComplete, setSaveComplete] = useState(false)
   const [deleteComplete, setDeleteComplete] = useState(false)
-  const connectionTestPayload = useMemo(() => ({ endpoint: endpointUrl, username, password, token, proxy }), [endpointUrl, password, proxy, token, username])
+  const connectionTestPayload = useMemo(
+    () => ({
+      endpoint: endpointUrl,
+      username,
+      password,
+      token,
+      proxy
+    }),
+    [endpointUrl, password, proxy, token, username]
+  )
+  const connectionSavePayload = useMemo(
+    () => ({
+      name,
+      endpoint: endpointUrl,
+      username,
+      password,
+      token,
+      proxy,
+      rateLimitPerHour
+    }),
+    [name, endpointUrl, username, password, token, proxy, rateLimitPerHour]
+  )
 
   const testConnection = useCallback(
     (
@@ -90,11 +111,14 @@ function useConnectionManager (
     ) => {
       setIsTesting(true)
       setShowError(false)
-      ToastNotification.clear()
+      // ToastNotification.clear()
       setTestResponse(null)
 
       const runTest = async () => {
-        const payload = Object.keys(manualPayload).length > 0 ? manualPayload : connectionTestPayload
+        const payload =
+          Object.keys(manualPayload).length > 0
+            ? manualPayload
+            : connectionTestPayload
         const testUrl = `${DEVLAKE_ENDPOINT}/plugins/${provider.id}/test`
         console.log(
           'INFO >>> Endpoint URL & Payload for testing: ',
@@ -104,8 +128,14 @@ function useConnectionManager (
         const res = await request.post(testUrl, payload)
         setTestResponse(res.data)
         if ([Providers.GITHUB].includes(provider.id)) {
-          console.log('>>> SETTING TOKEN TEST RESPONSE FOR TOKEN >>>', manualPayload?.token || connectionTestPayload.token)
-          setAllTestResponses(tRs => ({ ...tRs, [manualPayload?.token]: res.data }))
+          console.log(
+            '>>> SETTING TOKEN TEST RESPONSE FOR TOKEN >>>',
+            manualPayload?.token || connectionTestPayload.token
+          )
+          setAllTestResponses((tRs) => ({
+            ...tRs,
+            [manualPayload?.token]: res.data
+          }))
         }
         if (res.data?.success && res.status === 200) {
           setIsTesting(false)
@@ -114,7 +144,7 @@ function useConnectionManager (
             ToastNotification.show({
               message: `Connection test OK. ${payload.endpoint}`,
               intent: 'success',
-              icon: 'small-tick',
+              icon: 'small-tick'
             })
           }
           onSuccess(res)
@@ -127,7 +157,7 @@ function useConnectionManager (
             ToastNotification.show({
               message: errorMessage,
               intent: 'danger',
-              icon: 'error',
+              icon: 'error'
             })
           }
           onFail(res)
@@ -138,200 +168,48 @@ function useConnectionManager (
     [provider?.id, connectionTestPayload]
   )
 
-  const saveConnection = (configurationSettings = {}) => {
-    setIsSaving(true)
-    let connectionPayload = { ...configurationSettings }
-    switch (provider.id) {
-      case Providers.JIRA:
-        connectionPayload = {
-          name: name,
-          endpoint: endpointUrl,
-          username: username,
-          password: password,
-          proxy: proxy,
-          rateLimitPerHour: rateLimit,
-          ...connectionPayload,
-        }
-        break
-      case Providers.TAPD:
-        connectionPayload = {
-          name: name,
-          endpoint: endpointUrl,
-          username: username,
-          password: password,
-          proxy: proxy,
-          rateLimitPerHour: rateLimit,
-          ...connectionPayload,
-        }
-        break
-      case Providers.GITHUB:
-        connectionPayload = {
-          name: name,
-          endpoint: endpointUrl,
-          token: token,
-          proxy: proxy,
-          rateLimitPerHour: rateLimit,
-          ...connectionPayload,
-        }
-        break
-      case Providers.JENKINS:
-      // eslint-disable-next-line max-len
-        connectionPayload = {
-          name: name,
-          endpoint: endpointUrl,
-          username: username,
-          password: password,
-          rateLimitPerHour: rateLimit,
-          ...connectionPayload,
-        }
-        break
-      case Providers.GITLAB:
-        connectionPayload = {
-          name: name,
-          endpoint: endpointUrl,
-          token: token,
-          proxy: proxy,
-          rateLimitPerHour: rateLimit,
-          ...connectionPayload,
-        }
-        break
-    }
+  const notifyConnectionSaveSuccess = useCallback(
+    (message = 'Connection saved successfully.') => {
+      ToastNotification.show({
+        message: message,
+        intent: 'success',
+        icon: 'small-tick'
+      })
+    },
+    []
+  )
 
-    let saveResponse = {
-      success: false,
-      connection: {
-        ...connectionPayload,
-      },
-      errors: [],
-    }
-
-    const saveConfiguration = async (configPayload) => {
-      try {
-        setShowError(false)
-        setErrors([])
-        ToastNotification.clear()
-        const s = await request.post(
-          `${DEVLAKE_ENDPOINT}/plugins/${provider.id}/connections`,
-          configPayload
-        )
-        console.log('>> CONFIGURATION SAVED SUCCESSFULLY', configPayload, s)
-        saveResponse = {
-          ...saveResponse,
-          success: [200, 201].includes(s.status),
-          connection: { ...s.data },
-          errors: s.isAxiosError ? [s.message] : [],
-        }
-      } catch (e) {
-        saveResponse.errors.push(e.message)
-        setErrors(saveResponse.errors)
-        console.log('>> CONFIGURATION FAILED TO SAVE', configPayload, e)
-      }
-    }
-
-    const modifyConfiguration = async (configPayload) => {
-      try {
-        setShowError(false)
-        setErrors([])
-        ToastNotification.clear()
-        // eslint-disable-next-line max-len
-        const s = await request.patch(
-          `${DEVLAKE_ENDPOINT}/plugins/${provider.id}/connections/${
-            activeConnection.id || activeConnection.ID
-          }`,
-          configPayload
-        )
-        const silentRefetch = true
-        console.log('>> CONFIGURATION MODIFIED SUCCESSFULLY', configPayload, s)
-        saveResponse = {
-          ...saveResponse,
-          success: [200, 201].includes(s.status),
-          connection: { ...s.data },
-          errors: s.isAxiosError ? [s.message] : [],
-        }
-        fetchConnection(silentRefetch)
-      } catch (e) {
-        saveResponse.errors.push(e.message)
-        setErrors(saveResponse.errors)
-        console.log('>> CONFIGURATION FAILED TO UPDATE', configPayload, e)
-      }
-    }
-
-    if (updateMode && activeConnection?.id !== null) {
-      modifyConfiguration(connectionPayload)
-    } else {
-      saveConfiguration(connectionPayload)
-    }
-
-    setTimeout(() => {
-      if (saveResponse.success && errors.length === 0) {
-        ToastNotification.show({
-          message: 'Connection saved successfully.',
-          intent: 'success',
-          icon: 'small-tick',
-        })
-        setShowError(false)
-        setIsSaving(false)
-        setSaveComplete(saveResponse.connection)
-        if (
-          [Providers.GITHUB, Providers.JIRA, Providers.GITLAB].includes(provider.id) &&
-          token !== '' &&
-          token?.toString().split(',').length > 1
-        ) {
-          testConnection()
-        }
-        if (!updateMode) {
-          history.push(`/integrations/${provider.id}`)
-        }
-      } else {
-        ToastNotification.show({
-          message: 'Connection failed to save, please try again.',
-          intent: 'danger',
-          icon: 'error',
-        })
-        setShowError(true)
-        setIsSaving(false)
-        setSaveComplete(false)
-      }
-    }, 2000)
-  }
-
-  const runCollection = (options = {}) => {
-    setIsRunning(true)
-    ToastNotification.show({
-      message: 'Triggered Collection Process',
-      intent: 'info',
-      icon: 'info',
-    })
-    console.log('>> RUNNING COLLECTION PROCESS', isRunning)
-    // Run Collection Tasks...
-  }
+  const notifyConnectionSaveFailure = useCallback(
+    (message = 'Connection failed to save, please try again.') => {
+      ToastNotification.show({
+        message: message,
+        intent: 'danger',
+        icon: 'error'
+      })
+    },
+    []
+  )
 
   const fetchConnection = useCallback(
     (silent = false, notify = false, cId = null) => {
-      console.log(`>> FETCHING CONNECTION [PROVIDER = ${provider.id}]....`)
+      console.log(`>> FETCHING CONNECTION [PROVIDER = ${provider?.id}]....`)
       try {
         setIsFetching(!silent)
         setErrors([])
-        ToastNotification.clear()
         console.log('>> FETCHING CONNECTION SOURCE')
         const fetch = async () => {
           const f = await request.get(
-            `${DEVLAKE_ENDPOINT}/plugins/${provider.id}/connections/${cId || connectionId}`
+            `${DEVLAKE_ENDPOINT}/plugins/${provider?.id}/connections/${
+              cId || connectionId
+            }`
           )
           const connectionData = f.data
           console.log('>> RAW CONNECTION DATA FROM API...', connectionData)
-          // @todo: cleanup legacy api pascal-case parameters
-          setActiveConnection({
-            ...connectionData,
-            ID: connectionData.ID || connectionData.id,
-            name: connectionData.name || connectionData.Name,
-            endpoint: connectionData.endpoint || connectionData.Endpoint,
-            proxy: connectionData.proxy || connectionData.Proxy,
-            rateLimit: connectionData.rateLimitPerHour,
-            username: connectionData.username || connectionData.Username,
-            password: connectionData.password || connectionData.Password,
-            token: connectionData.token || connectionData.auth
-          })
+          setActiveConnection(
+            new Connection({
+              ...connectionData
+            })
+          )
           setTimeout(() => {
             setIsFetching(false)
           }, 500)
@@ -339,12 +217,13 @@ function useConnectionManager (
         fetch()
       } catch (e) {
         setIsFetching(false)
-        setActiveConnection(NullConnection)
+        setActiveConnection(new Connection())
         setErrors([e.message])
+        ToastNotification.clear()
         ToastNotification.show({
           message: `${e}`,
           intent: 'danger',
-          icon: 'error',
+          icon: 'error'
         })
         console.log('>> FAILED TO FETCH CONNECTION', e)
       }
@@ -352,12 +231,120 @@ function useConnectionManager (
     [provider?.id, connectionId]
   )
 
+  const saveConnection = useCallback(
+    (configurationSettings = {}) => {
+      setIsSaving(true)
+
+      let saveResponse = {
+        success: false,
+        connection: {
+          ...connectionSavePayload
+        },
+        errors: []
+      }
+
+      const saveConfiguration = async (configPayload) => {
+        try {
+          setShowError(false)
+          setErrors([])
+          ToastNotification.clear()
+          const s = await request.post(
+            `${DEVLAKE_ENDPOINT}/plugins/${provider?.id}/connections`,
+            configPayload
+          )
+          console.log('>> CONFIGURATION SAVED SUCCESSFULLY', configPayload, s)
+          saveResponse = {
+            ...saveResponse,
+            success: [200, 201].includes(s.status),
+            connection: { ...s.data },
+            errors: s.isAxiosError ? [s.message] : []
+          }
+          setIsSaving(false)
+          setSaveComplete(saveResponse.success ? new Connection(s.data) : false)
+          if (!saveResponse.success) {
+            notifyConnectionSaveFailure(s?.data?.message || s.message)
+          }
+        } catch (e) {
+          saveResponse.errors.push(e.message)
+          setErrors(saveResponse.errors)
+          setIsSaving(false)
+          setSaveComplete(false)
+          notifyConnectionSaveFailure(e.message)
+          console.log('>> CONFIGURATION FAILED TO SAVE', configPayload, e)
+        }
+      }
+
+      const modifyConfiguration = async (configPayload) => {
+        try {
+          setShowError(false)
+          setErrors([])
+          ToastNotification.clear()
+          // eslint-disable-next-line max-len
+          const s = await request.patch(
+            `${DEVLAKE_ENDPOINT}/plugins/${provider?.id}/connections/${activeConnection.id}`,
+            configPayload
+          )
+          const silentRefetch = true
+          console.log(
+            '>> CONFIGURATION MODIFIED SUCCESSFULLY',
+            configPayload,
+            s
+          )
+          saveResponse = {
+            ...saveResponse,
+            success: [200, 201].includes(s.status),
+            connection: { ...s.data },
+            errors: s.isAxiosError ? [s.message] : []
+          }
+          fetchConnection(silentRefetch)
+          setIsSaving(false)
+          setSaveComplete(saveResponse.success ? new Connection(s.data) : false)
+          if (!saveResponse.success) {
+            notifyConnectionSaveFailure(s.data || s.message)
+          }
+        } catch (e) {
+          saveResponse.errors.push(e.message)
+          setErrors(saveResponse.errors)
+          setIsSaving(false)
+          setSaveComplete(false)
+          notifyConnectionSaveFailure(e.message)
+          console.log('>> CONFIGURATION FAILED TO UPDATE', configPayload, e)
+        }
+      }
+
+      if (updateMode && activeConnection?.id !== null) {
+        modifyConfiguration(connectionSavePayload)
+      } else {
+        saveConfiguration(connectionSavePayload)
+      }
+    },
+    [
+      activeConnection?.id,
+      connectionSavePayload,
+      fetchConnection,
+      notifyConnectionSaveFailure,
+      provider?.id,
+      updateMode
+    ]
+  )
+
+  const runCollection = (options = {}) => {
+    setIsRunning(true)
+    ToastNotification.show({
+      message: 'Triggered Collection Process',
+      intent: 'info',
+      icon: 'info'
+    })
+    console.log('>> RUNNING COLLECTION PROCESS', isRunning)
+    // Run Collection Tasks...
+  }
+
   const fetchAllConnections = useCallback(
     async (notify = false, allSources = false) => {
       try {
         setIsFetching(true)
         setErrors([])
-        ToastNotification.clear()
+        // ToastNotification.clear()
         console.log('>> FETCHING ALL CONNECTION SOURCES')
         let c = null
         if (allSources) {
@@ -377,16 +364,27 @@ function useConnectionManager (
             ),
             request.get(
               `${DEVLAKE_ENDPOINT}/plugins/${Providers.TAPD}/connections`
-            ),
+            )
           ])
-          const builtConnections = aC
-            .map((providerResponse) => [].concat(providerResponse.data || []).map(c => ({
-              ...c,
-              connectionId: c.id,
-              provider: providerResponse.config?.url?.split('/')[3],
-              // @todo: inject realtime connection status...
-              status: ConnectionStatus.ONLINE
-            })))
+          const builtConnections = aC.map((providerResponse) =>
+            []
+              .concat(
+                Array.isArray(providerResponse.data)
+                  ? providerResponse.data
+                  : []
+              )
+              .map(
+                (c) =>
+                  new Connection({
+                    ...c,
+                    connectionId: c.id,
+                    plugin: providerResponse.config?.url?.split('/')[3],
+                    provider: providerResponse.config?.url?.split('/')[3],
+                    // @note: realtime connection status will be later injected by hook callees (non-blocking)
+                    status: ConnectionStatus.ONLINE
+                  })
+              )
+          )
           setAllProviderConnections(builtConnections.flat())
           console.log(
             '>> ALL SOURCE CONNECTIONS: FETCHING ALL CONNECTION FROM ALL DATA SOURCES'
@@ -394,54 +392,47 @@ function useConnectionManager (
           console.log('>> ALL SOURCE CONNECTIONS: ', aC)
         } else {
           c = await request.get(
-            `${DEVLAKE_ENDPOINT}/plugins/${provider.id}/connections`
+            `${DEVLAKE_ENDPOINT}/plugins/${provider?.id}/connections`
           )
+          console.log('>> RAW ALL CONNECTIONS DATA FROM API...', c?.data)
+          handleOfflineMode(c?.status, c)
+          const providerConnections = []
+            .concat(Array.isArray(c?.data) ? c?.data : [])
+            .map(
+              (conn, idx) =>
+                new Connection({
+                  ...conn,
+                  status: ConnectionStatus.OFFLINE,
+                  id: conn.id,
+                  name: conn.name,
+                  endpoint: conn.endpoint,
+                  errors: []
+                })
+            )
+          setAllConnections(providerConnections)
         }
-
-        console.log('>> RAW ALL CONNECTIONS DATA FROM API...', c?.data)
-        const providerConnections = []
-          .concat(Array.isArray(c?.data) ? c?.data : [])
-          .map((conn, idx) => {
-            return {
-              ...conn,
-              status: ConnectionStatus.OFFLINE,
-              ID: conn.ID || conn.id,
-              id: conn.id,
-              name: conn.name,
-              endpoint: conn.endpoint,
-              errors: [],
-            }
-          })
         if (notify) {
           ToastNotification.show({
             message: 'Loaded all connections.',
             intent: 'success',
-            icon: 'small-tick',
+            icon: 'small-tick'
           })
         }
-        setAllConnections(providerConnections)
-        setConnectionCount(c?.data?.length)
-        setConnectionLimitReached(
-          sourceLimits[provider.id] &&
-            c.data?.length >= sourceLimits[provider.id]
-        )
         setIsFetching(false)
       } catch (e) {
         console.log('>> FAILED TO FETCH ALL CONNECTIONS', e)
         ToastNotification.show({
           message: `Failed to Load Connections - ${e.message}`,
           intent: 'danger',
-          icon: 'error',
+          icon: 'error'
         })
         setIsFetching(false)
         setAllConnections([])
-        setConnectionCount(0)
-        setConnectionLimitReached(false)
         setErrors([e.message])
         handleOfflineMode(e.response?.status, e.response)
       }
     },
-    [provider?.id, sourceLimits, handleOfflineMode]
+    [provider?.id, handleOfflineMode]
   )
 
   const deleteConnection = useCallback(
@@ -451,15 +442,13 @@ function useConnectionManager (
         setErrors([])
         console.log('>> TRYING TO DELETE CONNECTION...', connection)
         const d = await request.delete(
-          `${DEVLAKE_ENDPOINT}/plugins/${provider.id}/connections/${
-            connection.ID || connection.id
-          }`
+          `${DEVLAKE_ENDPOINT}/plugins/${provider?.id}/connections/${connection.id}`
         )
         console.log('>> CONNECTION DELETED...', d)
         setIsDeleting(false)
         setDeleteComplete({
           provider: activeProvider,
-          connection: d.data,
+          connection: d.data
         })
       } catch (e) {
         setIsDeleting(false)
@@ -487,22 +476,22 @@ function useConnectionManager (
           username: c.username,
           password: c.password,
           token: c.token,
-          proxy: c.proxy,
+          proxy: c.proxy
         }
         const onSuccess = (res) => {
           setTestedConnections((testedConnections) => [
             ...new Set([
               ...testedConnections.filter((oC) => oC.id !== c.id),
-              { ...c, status: ConnectionStatus.ONLINE },
-            ]),
+              new Connection({ ...c, status: ConnectionStatus.ONLINE })
+            ])
           ])
         }
         const onFail = (res) => {
           setTestedConnections((testedConnections) => [
             ...new Set([
-              ...testedConnections.filter((oC) => oC.ID !== c.ID),
-              { ...c, status: ConnectionStatus.DISCONNECTED },
-            ]),
+              ...testedConnections.filter((oC) => oC.id !== c.id),
+              new Connection({ ...c, status: ConnectionStatus.DISCONNECTED })
+            ])
           ])
         }
         testConnection(notify, payload, onSuccess, onFail)
@@ -511,6 +500,7 @@ function useConnectionManager (
     [testConnection]
   )
 
+  // @note: not in use since V12
   const fetchDomainLayerRepositories = useCallback(() => {
     console.log('>> FETCHING DOMAIN LAYER REPOS....')
     try {
@@ -520,6 +510,7 @@ function useConnectionManager (
       const fetch = async () => {
         const r = await request.get(`${DEVLAKE_ENDPOINT}/domainlayer/repos`)
         console.log('>> RAW REPOSITORY DATA FROM API...', r.data?.repos)
+        // @todo: create data model for DomainRepository
         setDomainRepositories(r.data?.repos || [])
         setTimeout(() => {
           setIsFetching(false)
@@ -533,7 +524,7 @@ function useConnectionManager (
       ToastNotification.show({
         message: `${e}`,
         intent: 'danger',
-        icon: 'error',
+        icon: 'error'
       })
       console.log('>> FAILED TO FETCH DOMAIN LAYER REPOS', e)
     }
@@ -545,68 +536,58 @@ function useConnectionManager (
     setUsername('')
     setPassword('')
     setToken('')
-    setInitialTokenStore({
-      0: '',
-      1: '',
-      2: ''
-    })
+    setInitialTokenStore(defaultTokenStore)
     setProxy('')
-    setRateLimit(0)
-  }, [])
+    setRateLimitPerHour(0)
+  }, [defaultTokenStore])
 
   useEffect(() => {
     if (activeConnection && activeConnection.id !== null) {
-      const connectionToken = activeConnection.auth || activeConnection.token || activeConnection.basicAuthEncoded
-      setName(activeConnection.name)
-      setEndpointUrl(activeConnection.endpoint)
-      switch (provider.id) {
-        case Providers.JENKINS:
-          setUsername(activeConnection.username)
-          setPassword(activeConnection.password)
-          setRateLimit(activeConnection.rateLimitPerHour)
-          break
-        case Providers.GITLAB:
-          setToken(activeConnection.basicAuthEncoded || activeConnection.token || activeConnection.auth)
-          setProxy(activeConnection.Proxy || activeConnection.proxy)
-          setRateLimit(activeConnection.rateLimitPerHour)
-          break
-        case Providers.GITHUB:
-          setToken(connectionToken)
-          setInitialTokenStore(connectionToken?.split(',')?.reduce((tS, cT, id) => ({ ...tS, [id]: cT }), {}))
-          setProxy(activeConnection.Proxy || activeConnection.proxy)
-          setRateLimit(activeConnection.rateLimitPerHour)
-          break
-        case Providers.JIRA:
-        // setToken(activeConnection.basicAuthEncoded || activeConnection.token)
-          setUsername(activeConnection.username)
-          setPassword(activeConnection.password)
-          setProxy(activeConnection.Proxy || activeConnection.proxy)
-          setRateLimit(activeConnection.rateLimitPerHour)
-          break
-        case Providers.TAPD:
-          setUsername(activeConnection.username)
-          setPassword(activeConnection.password)
-          setProxy(activeConnection.Proxy || activeConnection.proxy)
-          setRateLimit(activeConnection.rateLimitPerHour)
-        break
-      }
-      ToastNotification.clear()
-      // ToastNotification.show({ message: `Fetched settings for ${activeConnection.name}.`, intent: 'success', icon: 'small-tick' })
+      setName(activeConnection?.name)
+      setEndpointUrl(activeConnection?.endpoint)
+      setRateLimitPerHour(activeConnection?.rateLimitPerHour)
+      setProxy(activeConnection?.proxy)
+      setUsername(activeConnection?.username)
+      setPassword(activeConnection?.password)
+      setToken(activeConnection?.token)
+      setInitialTokenStore(
+        activeConnection?.token
+          ? activeConnection?.token
+              ?.split(',')
+              ?.reduce((tS, cT, id) => ({ ...tS, [id]: cT }), {})
+          : defaultTokenStore
+      )
       console.log('>> FETCHED CONNECTION FOR MODIFY', activeConnection)
     }
-  }, [activeConnection, provider?.id])
+  }, [activeConnection, defaultTokenStore])
 
   useEffect(() => {
-    if (saveComplete && saveComplete.ID) {
-      console.log('>>> CONNECTION MANAGER - SAVE COMPLETE EFFECT RUNNING...')
-      setActiveConnection((ac) => {
-        return {
-          ...ac,
-          ...saveComplete,
-        }
-      })
+    if (saveComplete?.id) {
+      console.log(
+        '>>> CONNECTION MANAGER - SAVE COMPLETE EFFECT RUNNING...',
+        saveComplete
+      )
+      setActiveConnection(
+        (ac) =>
+          new Connection({
+            ...ac,
+            ...saveComplete
+          })
+      )
+      if (!updateMode) {
+        history.replace(`/integrations/${provider?.id}`)
+        notifyConnectionSaveSuccess()
+      } else {
+        notifyConnectionSaveSuccess()
+      }
     }
-  }, [saveComplete])
+  }, [
+    saveComplete,
+    updateMode,
+    history,
+    provider?.id,
+    notifyConnectionSaveSuccess
+  ])
 
   useEffect(() => {
     console.log(
@@ -630,29 +611,35 @@ function useConnectionManager (
   }, [testedConnections])
 
   useEffect(() => {
-    console.log('>> CONNECTION MANAGER, ACTIVE PROVIDER CHANGED ====>', activeProvider)
+    console.log(
+      '>> CONNECTION MANAGER, ACTIVE PROVIDER CHANGED ====>',
+      activeProvider
+    )
     setProvider(activeProvider)
   }, [activeProvider])
 
   useEffect(() => {
     console.log('>>> ALL DATA PROVIDER CONNECTIONS...', allProviderConnections)
     setConnectionsList(
-      allProviderConnections?.map((c, cIdx) => ({
-        ...c,
-        id: cIdx,
-        key: cIdx,
-        connectionId: c.id,
-        name: c.name,
-        title: c.name,
-        value: c.id,
-        status:
-          ConnectionStatusLabels[c.status] ||
-          ConnectionStatusLabels[ConnectionStatus.OFFLINE],
-        statusResponse: null,
-        provider: c.provider,
-        providerId: c.provider,
-        plugin: c.provider,
-      }))
+      allProviderConnections?.map(
+        (c, cIdx) =>
+          new ProviderListConnection({
+            ...c,
+            id: cIdx + 1,
+            key: cIdx + 1,
+            connectionId: c.id,
+            name: c.name,
+            title: c.name,
+            value: c.id,
+            status:
+              ConnectionStatusLabels[c.status] ||
+              ConnectionStatusLabels[ConnectionStatus.OFFLINE],
+            statusResponse: null,
+            provider: c.provider,
+            providerId: c.provider,
+            plugin: c.provider
+          })
+      )
     )
   }, [allProviderConnections])
 
@@ -675,7 +662,7 @@ function useConnectionManager (
     name,
     endpointUrl,
     proxy,
-    rateLimit,
+    rateLimitPerHour,
     username,
     password,
     token,
@@ -686,7 +673,7 @@ function useConnectionManager (
     setName,
     setEndpointUrl,
     setProxy,
-    setRateLimit,
+    setRateLimitPerHour,
     setToken,
     setInitialTokenStore,
     setUsername,
