@@ -22,16 +22,17 @@ import Sidebar from '@/components/Sidebar'
 import AppCrumbs from '@/components/Breadcrumbs'
 import Content from '@/components/Content'
 import { integrationsData } from '@/data/integrations'
+import { ReactComponent as WebHookProviderIcon } from '@/images/integrations/incoming-webhook.svg'
 
 import '@/styles/integration.scss'
 
-export default function Integration () {
+export default function Integration() {
   const history = useHistory()
 
   const [activeProvider, setActiveProvider] = useState(integrationsData[0])
 
   const handleProviderClick = (providerId) => {
-    const theProvider = integrationsData.find(p => p.id === providerId)
+    const theProvider = integrationsData.find((p) => p.id === providerId)
     if (theProvider) {
       setActiveProvider(theProvider)
       history.push(`/integrations/${theProvider.id}`)
@@ -45,9 +46,7 @@ export default function Integration () {
     console.log(activeProvider)
   }, [activeProvider, history])
 
-  useEffect(() => {
-
-  }, [])
+  useEffect(() => {}, [])
 
   return (
     <>
@@ -59,12 +58,20 @@ export default function Integration () {
             <AppCrumbs
               items={[
                 { href: '/', icon: false, text: 'Dashboard' },
-                { href: '/integrations', icon: false, text: 'Integrations', current: true }
+                {
+                  href: '/integrations',
+                  icon: false,
+                  text: 'Connections',
+                  current: true
+                }
               ]}
             />
             <div className='headlineContainer'>
-              <h1>Data Integrations</h1>
-              <p className='page-description'>{integrationsData.length} connections are available for data collection.</p>
+              <h1>Data Connections</h1>
+              <p className='page-description'>
+                {integrationsData.length} connections are available for data
+                collection.
+              </p>
             </div>
             <div className='integrationProviders'>
               {integrationsData.map((provider) => (
@@ -73,15 +80,45 @@ export default function Integration () {
                   key={`provider-${provider.id}`}
                   onClick={() => handleProviderClick(provider.id)}
                 >
-                  <div className='providerIcon'>
-                    {provider.iconDashboard}
-                  </div>
+                  <div className='providerIcon'>{provider.iconDashboard}</div>
                   <div className='providerName'>
-                    {provider.name} {provider.isBeta && <><sup>(beta)</sup></>}
+                    {provider.name}{' '}
+                    {provider.isBeta && (
+                      <>
+                        <sup>(beta)</sup>
+                      </>
+                    )}
                   </div>
                 </div>
               ))}
             </div>
+            <div className='headlineContainer'>
+              <h1>Webhooks</h1>
+              <p className='page-description'>
+                You can use webhooks to import deployments and incidents from
+                the unsupported data integrations to calculate DORA metrics,
+                etc. Please note: webhooks cannot be created or managed in
+                Blueprints.
+              </p>
+            </div>
+            <div className='integrationProviders'>
+              <div
+                className='iProvider'
+                style={{ width: 130 }}
+                onClick={() => history.push('/connections/incoming-webhook')}
+              >
+                <div className='providerIcon'>
+                  <WebHookProviderIcon
+                    className='providerIconSvg'
+                    width='40'
+                    height='40'
+                  />
+                </div>
+                <div className='providerName'>
+                  Issue/Deployment Incoming Webhook
+                </div>
+              </div>
+            </div>
           </main>
         </Content>
       </div>
