@@ -16,71 +16,72 @@
  *
  */
 import axios from 'axios'
-import { ToastNotification } from '@/components/Toast'
+import { MigrationOptions } from '@/config/migration'
 
 const headers = {}
-let warned428 = false
 
-const handleErrorResponse = (e) => {
-  let errorResponse = { success: false, message: e.message, data: null, status: 504 }
+const handleErrorResponse = (e, cb = () => {}) => {
+  let errorResponse = {
+    success: false,
+    message: e.message,
+    data: null,
+    status: 504
+  }
   if (e.response) {
     errorResponse = {
       ...errorResponse,
       data: e.response ? e.response.data : null,
       message: e.response?.data?.message,
-      status: e.response ? e.response.status : 504,
+      status: e.response ? e.response.status : 504
     }
   }
-  if (!warned428 && e.response?.status === 428) {
-    warned428 = true
-    ToastNotification.show({ message: e.response.data.message, intent: 'danger', icon: 'error', timeout: -1 })
+  if (e.response?.status === MigrationOptions.apiStatusCode) {
+    console.log(
+      '>>> DATABASE MIGRATION REQUESTED! Setting Warning Identifier in Browser Storage...'
+    )
+    MigrationOptions.runNeedMigrateCallback({
+      migration: true,
+      message: e.response?.data?.message
+    })
   }
+  cb(e)
   return errorResponse
 }
 
 export default {
-  post: async (url, body) => {
-    return await axios.post(
-      url,
-      body,
-      {
+  post: async (url, body, cb = () => {}) => {
+    return await axios
+      .post(url, body, {
         headers
-      }
-    ).catch(e => handleErrorResponse(e))
+      })
+      .catch((e) => handleErrorResponse(e, cb))
   },
-  get: async (url) => {
-    return await axios.get(
-      url,
-      {
+  get: async (url, cb = () => {}) => {
+    return await axios
+      .get(url, {
         headers
-      }
-    ).catch(e => handleErrorResponse(e))
+      })
+      .catch((e) => handleErrorResponse(e, cb))
   },
   put: async (url, body) => {
-    return await axios.put(
-      url,
-      body,
-      {
+    return await axios
+      .put(url, body, {
         headers
-      }
-    ).catch(e => handleErrorResponse(e))
+      })
+      .catch((e) => handleErrorResponse(e))
   },
   patch: async (url, body) => {
-    return await axios.patch(
-      url,
-      body,
-      {
+    return await axios
+      .patch(url, body, {
         headers
-      }
-    ).catch(e => handleErrorResponse(e))
+      })
+      .catch((e) => handleErrorResponse(e))
   },
   delete: async (url, body) => {
-    return await axios.delete(
-      url,
-      body,
-      {
+    return await axios
+      .delete(url, body, {
         headers
-      }
-    ).catch(e => handleErrorResponse(e))
+      })
+      .catch((e) => handleErrorResponse(e))
   }
 }
