@@ -18,11 +18,10 @@ limitations under the License.
 package config
 
 import (
-	"errors"
 	"fmt"
+	"github.com/apache/incubator-devlake/errors"
+	goerror "github.com/cockroachdb/errors"
 	"os"
-	"runtime/debug"
-
 	"path/filepath"
 	"regexp"
 	"strings"
@@ -76,11 +75,11 @@ func setDefaultValue(v *viper.Viper) {
 }
 
 // replaceNewEnvItemInOldContent replace old config to new config in env file content
-func replaceNewEnvItemInOldContent(v *viper.Viper, envFileContent string) (string, error) {
+func replaceNewEnvItemInOldContent(v *viper.Viper, envFileContent string) (string, errors.Error) {
 	// prepare reg exp
 	encodeEnvNameReg := regexp.MustCompile(`[^a-zA-Z0-9]`)
 	if encodeEnvNameReg == nil {
-		return ``, fmt.Errorf("encodeEnvNameReg err")
+		return ``, errors.Default.New("encodeEnvNameReg err")
 	}
 
 	for _, key := range v.AllKeys() {
@@ -91,7 +90,7 @@ func replaceNewEnvItemInOldContent(v *viper.Viper, envFileContent string) (strin
 		})
 		envItemReg, err := regexp.Compile(fmt.Sprintf(`(?im)^\s*%v\s*\=.*$`, encodeEnvName))
 		if err != nil {
-			return ``, fmt.Errorf("regexp Compile failed:[%s] stack:[%s]", err.Error(), debug.Stack())
+			return ``, errors.Default.Wrap(err, "regexp Compile failed")
 		}
 		envFileContent = envItemReg.ReplaceAllStringFunc(envFileContent, func(s string) string {
 			switch ret := val.(type) {
@@ -113,7 +112,7 @@ func replaceNewEnvItemInOldContent(v *viper.Viper, envFileContent string) (strin
 }
 
 // WriteConfig save viper to .env file
-func WriteConfig(v *viper.Viper) error {
+func WriteConfig(v *viper.Viper) errors.Error {
 	envPath := getEnvPath()
 	fileName := getConfigName()
 
@@ -125,7 +124,7 @@ func WriteConfig(v *viper.Viper) error {
 }
 
 // WriteConfigAs save viper to custom filename
-func WriteConfigAs(v *viper.Viper, filename string) error {
+func WriteConfigAs(v *viper.Viper, filename string) errors.Error {
 	aferoFile := afero.NewOsFs()
 	fmt.Println("Attempting to write configuration to .env file.")
 	var configType string
@@ -135,21 +134,21 @@ func WriteConfigAs(v *viper.Viper, filename string) error {
 		configType = ext[1:]
 	}
 	if configType != "env" && configType != "dotenv" {
-		return v.WriteConfigAs(filename)
+		return errors.Convert(v.WriteConfigAs(filename))
 	}
 
 	// FIXME viper just have setter and have no getter so create new configPermissions and file
 	flags := os.O_CREATE | os.O_TRUNC | os.O_WRONLY
 	configPermissions := os.FileMode(0644)
 	file, err := afero.ReadFile(aferoFile, filename)
-	if err != nil && !errors.Is(err, os.ErrNotExist) {
-		return err
+	if err != nil && !goerror.Is(err, os.ErrNotExist) {
+		return errors.Convert(err)
 	}
 
 	envFileContent := string(file)
 	f, err := aferoFile.OpenFile(filename, flags, configPermissions)
 	if err != nil {
-		return err
+		return errors.Convert(err)
 	}
 	defer f.Close()
 
@@ -161,12 +160,12 @@ func WriteConfigAs(v *viper.Viper, filename string) error {
 	}
 	envFileContent, err = replaceNewEnvItemInOldContent(v, envFileContent)
 	if err != nil {
-		return err
+		return errors.Convert(err)
 	}
 	if _, err := f.WriteString(envFileContent); err != nil {
-		return err
+		return errors.Convert(err)
 	}
-	return f.Sync()
+	return errors.Convert(f.Sync())
 }
 
 func init() {
