@@ -18,8 +18,8 @@ limitations under the License.
 package cmd
 
 import (
-	"errors"
 	"fmt"
+	"github.com/apache/incubator-devlake/errors"
 	"github.com/apache/incubator-devlake/generator/util"
 	"github.com/manifoldco/promptui"
 	"github.com/spf13/cobra"
@@ -34,34 +34,34 @@ func init() {
 	rootCmd.AddCommand(createCollectorCmd)
 }
 
-func collectorNameNotExistValidateHoc(pluginName string) func(input string) error {
+func collectorNameNotExistValidateHoc(pluginName string) promptui.ValidateFunc {
 	collectorNameValidate := func(input string) error {
 		if input == `` {
-			return errors.New("please input which data would you will collect (snake_format)")
+			return errors.Default.New("please input which data would you will collect (snake_format)")
 		}
 		snakeNameReg := regexp.MustCompile(`^[A-Za-z][A-Za-z0-9_]*$`)
 		if !snakeNameReg.MatchString(input) {
-			return errors.New("collector name invalid (start with a-z and consist with a-z0-9_)")
+			return errors.Default.New("collector name invalid (start with a-z and consist with a-z0-9_)")
 		}
 		_, err := os.Stat(filepath.Join(`plugins`, pluginName, `tasks`, input+`_collector.go`))
 		if os.IsNotExist(err) {
 			return nil
 		}
 		if err != nil {
-			return err
+			return errors.Default.Wrap(err, "error getting collector src file")
 		}
-		return errors.New("collector exists")
+		return errors.Default.New("collector exists")
 	}
 	return collectorNameValidate
 }
 
-func collectorNameExistValidateHoc(pluginName string) func(input string) error {
+func collectorNameExistValidateHoc(pluginName string) promptui.ValidateFunc {
 	collectorNameValidate := func(input string) error {
 		if input == `` {
-			return errors.New("please input which data would you will collect (snake_format)")
+			return errors.Default.New("please input which data would you will collect (snake_format)")
 		}
 		_, err := os.Stat(filepath.Join(`plugins`, pluginName, `tasks`, input+`_collector.go`))
-		return err
+		return errors.Default.Wrap(err, "error getting collector src file")
 	}
 	return collectorNameValidate
 }
@@ -82,7 +82,7 @@ Type in what the name of collector is, then generator will create a new collecto
 		}
 		prompt := promptui.Prompt{
 			Label:    "plugin_name",
-			Validate: pluginNameExistValidate,
+			Validate: pluginNameExistValidate(),
 			Default:  pluginName,
 		}
 		pluginName, err = prompt.Run()
@@ -105,10 +105,10 @@ Type in what the name of collector is, then generator will create a new collecto
 			Label: "http_path",
 			Validate: func(input string) error {
 				if input == `` {
-					return errors.New("http_path require")
+					return errors.BadInput.New("http_path required")
 				}
 				if strings.HasPrefix(input, `/`) {
-					return errors.New("http_path shouldn't start with '/'")
+					return errors.BadInput.New("http_path shouldn't start with '/'")
 				}
 				return nil
 			},
@@ -140,7 +140,7 @@ Type in what the name of collector is, then generator will create a new collecto
 				fmt.Sprintf("$1$2\t\ttasks.Collect%sMeta,\n$4", collectorDataNameUpperCamel),
 			)
 			util.ReplaceVarInFile(
-				filepath.Join(`plugins`, pluginName, `plugin_main.go`),
+				filepath.Join(`plugins`, pluginName, fmt.Sprintf(`%s.go`, pluginName)),
 				regexp.MustCompile(`(return +\[]core\.SubTaskMeta ?\{ ?\n?)((\s*[\w.]+,\n)*)(\s*})`),
 				fmt.Sprintf("$1$2\t\ttasks.Collect%sMeta,\n$4", collectorDataNameUpperCamel),
 			)
