@@ -19,6 +19,7 @@ package logger
 
 import (
 	"fmt"
+	"github.com/apache/incubator-devlake/errors"
 	"github.com/apache/incubator-devlake/plugins/core"
 	"github.com/sirupsen/logrus"
 	"regexp"
@@ -32,7 +33,7 @@ type DefaultLogger struct {
 	config *core.LoggerConfig
 }
 
-func NewDefaultLogger(log *logrus.Logger) (core.Logger, error) {
+func NewDefaultLogger(log *logrus.Logger) (core.Logger, errors.Error) {
 	defaultLogger := &DefaultLogger{
 		log:    log,
 		config: &core.LoggerConfig{},
@@ -69,12 +70,12 @@ func (l *DefaultLogger) Info(format string, a ...interface{}) {
 	l.Log(core.LOG_INFO, format, a...)
 }
 
-func (l *DefaultLogger) Warn(format string, a ...interface{}) {
-	l.Log(core.LOG_WARN, format, a...)
+func (l *DefaultLogger) Warn(err error, format string, a ...interface{}) {
+	l.Log(core.LOG_WARN, formatMessage(err, format, a...))
 }
 
-func (l *DefaultLogger) Error(format string, a ...interface{}) {
-	l.Log(core.LOG_ERROR, format, a...)
+func (l *DefaultLogger) Error(err error, format string, a ...interface{}) {
+	l.Log(core.LOG_ERROR, formatMessage(err, format, a...))
 }
 
 func (l *DefaultLogger) SetStream(config *core.LoggerStreamConfig) {
@@ -100,13 +101,13 @@ func (l *DefaultLogger) Nested(newPrefix string) core.Logger {
 	}
 	newLogger, err := l.getLogger(newTotalPrefix)
 	if err != nil {
-		l.Error("error getting a new logger: %v", newLogger)
+		l.Error(err, "error getting a new logger")
 		return l
 	}
 	return newLogger
 }
 
-func (l *DefaultLogger) getLogger(prefix string) (core.Logger, error) {
+func (l *DefaultLogger) getLogger(prefix string) (core.Logger, errors.Error) {
 	newLogrus := logrus.New()
 	newLogrus.SetLevel(l.log.Level)
 	newLogrus.SetFormatter(l.log.Formatter)
@@ -130,4 +131,16 @@ func (l *DefaultLogger) createPrefix(newPrefix string) string {
 	return fmt.Sprintf("%s [%s]", l.config.Prefix, newPrefix)
 }
 
+func formatMessage(err error, msg string, args ...interface{}) string {
+	msg = fmt.Sprintf(msg, args...)
+	if err == nil {
+		return msg
+	}
+	formattedErr := strings.ReplaceAll(err.Error(), "\n", "\n\t")
+	if msg == "" {
+		return formattedErr
+	}
+	return fmt.Sprintf("%s\n\tcaused by: %s", msg, formattedErr)
+}
+
 var _ core.Logger = (*DefaultLogger)(nil)
