@@ -23,6 +23,8 @@ import (
 	"sort"
 	"sync"
 
+	"github.com/apache/incubator-devlake/errors"
+
 	"gorm.io/gorm"
 )
 
@@ -65,42 +67,42 @@ func (m *migrator) register(scripts []Script, comment string) {
 	}
 }
 
-func (m *migrator) bookKeep(script *scriptWithComment) error {
+func (m *migrator) bookKeep(script *scriptWithComment) errors.Error {
 	record := &MigrationHistory{
 		ScriptVersion: script.Version(),
 		ScriptName:    script.Name(),
 		Comment:       script.comment,
 	}
-	return m.db.Create(record).Error
+	return errors.Convert(m.db.Create(record).Error)
 }
 
-func (m *migrator) execute(ctx context.Context) error {
+func (m *migrator) execute(ctx context.Context) errors.Error {
 	sort.Slice(m.pending, func(i, j int) bool {
 		return m.pending[i].Version() < m.pending[j].Version()
 	})
 	for _, script := range m.pending {
 		err := script.Up(ctx, m.db)
 		if err != nil {
-			return err
+			return errors.Default.Wrap(err, fmt.Sprintf("error Up() on script [%s]", script.Name()))
 		}
 		err = m.bookKeep(script)
 		if err != nil {
-			return err
+			return errors.Default.Wrap(err, fmt.Sprintf("error bookKeep() on script [%s]", script.Name()))
 		}
 	}
 	return nil
 }
-func (m *migrator) getExecuted() (map[string]bool, error) {
+func (m *migrator) getExecuted() (map[string]bool, errors.Error) {
 	var err error
 	versions := make(map[string]bool)
 	err = m.db.Migrator().AutoMigrate(&MigrationHistory{})
 	if err != nil {
-		return nil, err
+		return nil, errors.Default.Wrap(err, "error performing migrations")
 	}
 	var records []MigrationHistory
 	err = m.db.Find(&records).Error
 	if err != nil {
-		return nil, err
+		return nil, errors.Default.Wrap(err, "error finding migration history records")
 	}
 	for _, record := range records {
 		versions[fmt.Sprintf("%s:%d", record.ScriptName, record.ScriptVersion)] = true
@@ -112,7 +114,7 @@ func Register(scripts []Script, comment string) {
 	m.register(scripts, comment)
 }
 
-func Execute(ctx context.Context) error {
+func Execute(ctx context.Context) errors.Error {
 	return m.execute(ctx)
 }
 
