@@ -19,6 +19,7 @@ package models
 
 import (
 	"encoding/json"
+	"github.com/apache/incubator-devlake/errors"
 
 	"github.com/apache/incubator-devlake/models/common"
 	"github.com/apache/incubator-devlake/plugins/core"
@@ -42,10 +43,6 @@ type Blueprint struct {
 	common.Model `swaggerignore:"true"`
 }
 
-func (Blueprint) TableName() string {
-	return "_devlake_blueprints"
-}
-
 type BlueprintSettings struct {
 	Version     string          `json:"version" validate:"required,semver,oneof=1.0.0"`
 	Connections json.RawMessage `json:"connections" validate:"required"`
@@ -54,11 +51,28 @@ type BlueprintSettings struct {
 }
 
 // UnmarshalPlan unmarshals Plan in JSON to strong-typed core.PipelinePlan
-func (bp *Blueprint) UnmarshalPlan() (core.PipelinePlan, error) {
+func (bp *Blueprint) UnmarshalPlan() (core.PipelinePlan, errors.Error) {
 	var plan core.PipelinePlan
-	err := json.Unmarshal(bp.Plan, &plan)
+	err := errors.Convert(json.Unmarshal(bp.Plan, &plan))
 	if err != nil {
-		return nil, err
+		return nil, errors.Convert(err)
 	}
 	return plan, nil
 }
+
+// @Description CronConfig
+type DbBlueprint struct {
+	Name   string `json:"name" validate:"required"`
+	Mode   string `json:"mode" gorm:"varchar(20)" validate:"required,oneof=NORMAL ADVANCED"`
+	Plan   string `json:"plan" encrypt:"yes"`
+	Enable bool   `json:"enable"`
+	//please check this https://crontab.guru/ for detail
+	CronConfig   string `json:"cronConfig" format:"* * * * *" example:"0 0 * * 1"`
+	IsManual     bool   `json:"isManual"`
+	Settings     string `json:"settings" encrypt:"yes" swaggertype:"array,string" example:"please check api: /blueprints/<PLUGIN_NAME>/blueprint-setting"`
+	common.Model `swaggerignore:"true"`
+}
+
+func (DbBlueprint) TableName() string {
+	return "_devlake_blueprints"
+}
