@@ -18,9 +18,10 @@ limitations under the License.
 package code
 
 import (
-	"github.com/apache/incubator-devlake/models/domainlayer"
 	"time"
 
+	"github.com/apache/incubator-devlake/models/domainlayer"
+
 	"github.com/apache/incubator-devlake/models/common"
 )
 
@@ -48,7 +49,7 @@ func (Commit) TableName() string {
 type CommitFile struct {
 	domainlayer.DomainEntity
 	CommitSha string `gorm:"type:varchar(40)"`
-	FilePath  string `gorm:"type:varchar(255)"`
+	FilePath  string `gorm:"type:text"`
 	Additions int
 	Deletions int
 }
@@ -66,3 +67,20 @@ type CommitFileComponent struct {
 func (CommitFileComponent) TableName() string {
 	return "commit_file_components"
 }
+
+type CommitLineChange struct {
+	domainlayer.DomainEntity
+	Id          string `gorm:"type:varchar(255);primaryKey"`
+	CommitSha   string `gorm:"type:varchar(40);"`
+	NewFilePath string `gorm:"type:varchar(255);"`
+	LineNoNew   int    `gorm:"type:int"`
+	LineNoOld   int    `gorm:"type:int"`
+	OldFilePath string `gorm:"type:varchar(255)"`
+	HunkNum     int    `gorm:"type:int"`
+	ChangedType string `gorm:"type:varchar(255)"`
+	PrevCommit  string `gorm:"type:varchar(255)"`
+}
+
+func (CommitLineChange) TableName() string {
+	return "commit_line_change"
+}
