@@ -26,7 +26,7 @@ type PullRequestComment struct {
 	domainlayer.DomainEntity
 	PullRequestId string `gorm:"index"`
 	Body          string
-	UserId        string `gorm:"type:varchar(255)"`
+	AccountId     string `gorm:"type:varchar(255)"`
 	CreatedDate   time.Time
 	CommitSha     string `gorm:"type:varchar(255)"`
 	Position      int
