@@ -17,9 +17,12 @@ limitations under the License.
 
 package crossdomain
 
+import "github.com/apache/incubator-devlake/models/common"
+
 type BoardRepo struct {
 	BoardId string `gorm:"primaryKey;type:varchar(255)"`
 	RepoId  string `gorm:"primaryKey;type:varchar(255)"`
+	common.NoPKModel
 }
 
 func (BoardRepo) TableName() string {
