@@ -26,7 +26,7 @@ type IssueComment struct {
 	domainlayer.DomainEntity
 	IssueId     string `gorm:"index"`
 	Body        string
-	UserId      string `gorm:"type:varchar(255)"`
+	AccountId   string `gorm:"type:varchar(255)"`
 	CreatedDate time.Time
 }
 
