@@ -28,7 +28,6 @@ func All() []migration.Script {
 		new(updateBlueprintMode),
 		new(renameTasksToPlan),
 		new(addDomainTables),
-		new(addTypeField),
 		new(commitfileComponent),
 		new(removeNotes),
 		new(addProjectMapping),
@@ -36,5 +35,18 @@ func All() []migration.Script {
 		new(addNoPKModelToCommitParent),
 		new(addSubtasksTable),
 		new(addCICD),
+		new(renameColumnsOfPrCommentIssueComment),
+		new(modifyTablesForDora),
+		new(addTypeFieldInBoard),
+		new(modifyPipeline),
+		new(encryptBLueprint),
+		new(encryptPipeline),
+		new(modifyCICDTasks),
+		new(modifyBoardRepos),
+		new(addOriginChangeValueForPr),
+		new(addCommitFilePathLength),
+		new(renamePipelineCommits),
+		new(commitLineChange),
+		new(modifyLeadTimeMinutes),
 	}
 }
