@@ -18,8 +18,8 @@ limitations under the License.
 package core
 
 import (
-	"errors"
 	"fmt"
+	"github.com/apache/incubator-devlake/errors"
 	"strings"
 )
 
@@ -27,7 +27,7 @@ import (
 
 var plugins map[string]PluginMeta
 
-func RegisterPlugin(name string, plugin PluginMeta) error {
+func RegisterPlugin(name string, plugin PluginMeta) errors.Error {
 	if plugins == nil {
 		plugins = make(map[string]PluginMeta)
 	}
@@ -35,19 +35,19 @@ func RegisterPlugin(name string, plugin PluginMeta) error {
 	return nil
 }
 
-func GetPlugin(name string) (PluginMeta, error) {
+func GetPlugin(name string) (PluginMeta, errors.Error) {
 	if plugins == nil {
-		return nil, errors.New("RegisterPlugin have never been called.")
+		return nil, errors.Default.New("RegisterPlugin have never been called.")
 	}
 	if plugin, ok := plugins[name]; ok {
 		return plugin, nil
 	}
-	return nil, fmt.Errorf("Plugin `%s` doesn't exist", name)
+	return nil, errors.Default.New(fmt.Sprintf("Plugin `%s` doesn't exist", name))
 }
 
-type PluginCallBack func(name string, plugin PluginMeta) error
+type PluginCallBack func(name string, plugin PluginMeta) errors.Error
 
-func TraversalPlugin(handle PluginCallBack) error {
+func TraversalPlugin(handle PluginCallBack) errors.Error {
 	for name, plugin := range plugins {
 		err := handle(name, plugin)
 		if err != nil {
@@ -61,11 +61,11 @@ func AllPlugins() map[string]PluginMeta {
 	return plugins
 }
 
-func FindPluginNameBySubPkgPath(subPkgPath string) (string, error) {
+func FindPluginNameBySubPkgPath(subPkgPath string) (string, errors.Error) {
 	for name, plugin := range plugins {
 		if strings.HasPrefix(subPkgPath, plugin.RootPkgPath()) {
 			return name, nil
 		}
 	}
-	return "", fmt.Errorf("Unable to find plugin for subPkgPath %s", subPkgPath)
+	return "", errors.Default.New(fmt.Sprintf("Unable to find plugin for subPkgPath %s", subPkgPath))
 }
