@@ -18,6 +18,7 @@ limitations under the License.
 package core
 
 import (
+	"github.com/apache/incubator-devlake/errors"
 	"net/http"
 	"net/url"
 )
@@ -43,19 +44,20 @@ type ApiResourceOutput struct {
 	File   *OutputFile
 }
 
-type ApiResourceHandler func(input *ApiResourceInput) (*ApiResourceOutput, error)
+type ApiResourceHandler func(input *ApiResourceInput) (*ApiResourceOutput, errors.Error)
 
 // Implement this interface if plugin offered API
 // Code sample to register a api on `sources/:connectionId`:
-// func (plugin Jira) ApiResources() map[string]map[string]core.ApiResourceHandler {
-// 	return map[string]map[string]core.ApiResourceHandler{
-// 		"connections/:connectionId": {
-// 			"PUT":    api.PutConnection,
-// 			"DELETE": api.DeleteConnection,
-// 			"GET":    api.GetConnection,
-// 		},
-// 	}
-// }
+//
+//	func (plugin Jira) ApiResources() map[string]map[string]core.ApiResourceHandler {
+//		return map[string]map[string]core.ApiResourceHandler{
+//			"connections/:connectionId": {
+//				"PUT":    api.PutConnection,
+//				"DELETE": api.DeleteConnection,
+//				"GET":    api.GetConnection,
+//			},
+//		}
+//	}
 type PluginApi interface {
 	ApiResources() map[string]map[string]ApiResourceHandler
 }
