@@ -18,11 +18,12 @@ limitations under the License.
 package core
 
 import (
+	"github.com/apache/incubator-devlake/errors"
 	"github.com/spf13/viper"
 	"gorm.io/gorm"
 )
 
-// Implement this interface if plugin needed some initialization
+// PluginInit Implement this interface if plugin needed some initialization
 type PluginInit interface {
-	Init(config *viper.Viper, logger Logger, db *gorm.DB) error
+	Init(config *viper.Viper, logger Logger, db *gorm.DB) errors.Error
 }
