@@ -23,3 +23,20 @@ type PluginMeta interface {
 	// PkgPath information lost when compiled as plugin(.so)
 	RootPkgPath() string
 }
+
+type GrafanaDashboard struct {
+	ID                   string
+	Title                string
+	Description          string
+	GrafanaDashboardJson string
+}
+
+// PluginDashboard return it's dashboard which should be display at grafana
+type PluginDashboard interface {
+	Dashboards() []GrafanaDashboard
+}
+
+// PluginIcon return it's icon (.svg text)
+type PluginIcon interface {
+	SvgIcon() string
+}
