@@ -24,6 +24,7 @@ import (
 	"crypto/sha256"
 	"encoding/base64"
 	"fmt"
+	"github.com/apache/incubator-devlake/errors"
 	"math/rand"
 	"time"
 )
@@ -36,7 +37,7 @@ func init() {
 
 // TODO: maybe move encryption/decryption into helper?
 // AES + Base64 encryption using ENCODE_KEY in .env as key
-func Encrypt(encKey, plainText string) (string, error) {
+func Encrypt(encKey, plainText string) (string, errors.Error) {
 	// add suffix to the data part
 	inputBytes := append([]byte(plainText), 123, 110, 100, 100, 116, 102, 125)
 	// perform encryption
@@ -48,18 +49,18 @@ func Encrypt(encKey, plainText string) (string, error) {
 	return base64.StdEncoding.EncodeToString(output), nil
 }
 
-//  Base64 + AES decryption using ENCODE_KEY in .env as key
-func Decrypt(encKey, encryptedText string) (string, error) {
+// Base64 + AES decryption using ENCODE_KEY in .env as key
+func Decrypt(encKey, encryptedText string) (string, errors.Error) {
 	// when encryption key is not set
 	if encKey == "" {
 		// return error message
-		return encryptedText, fmt.Errorf("encKey is required")
+		return encryptedText, errors.Default.New("encKey is required")
 	}
 
 	// Decode Base64
 	decodingFromBase64, err1 := base64.StdEncoding.DecodeString(encryptedText)
 	if err1 != nil {
-		return encryptedText, err1
+		return encryptedText, errors.Convert(err1)
 	}
 	// perform AES decryption
 	output, err2 := AesDecrypt(decodingFromBase64, []byte(encKey))
@@ -78,7 +79,7 @@ func Decrypt(encKey, encryptedText string) (string, error) {
 			return string(output), nil
 		}
 	}
-	return "", fmt.Errorf("invalid encKey")
+	return "", errors.Default.New("invalid encKey")
 }
 
 // PKCS7 padding
@@ -101,14 +102,14 @@ func PKCS7UnPadding(origData []byte) []byte {
 	return origData[:(length - unpadding)]
 }
 
-//AES encryption, CBC
-func AesEncrypt(origData, key []byte) ([]byte, error) {
+// AES encryption, CBC
+func AesEncrypt(origData, key []byte) ([]byte, errors.Error) {
 	// data alignment fill and encryption
 	sha256Key := sha256.Sum256(key)
 	key = sha256Key[:]
 	block, err := aes.NewCipher(key)
 	if err != nil {
-		return nil, err
+		return nil, errors.Convert(err)
 	}
 	// data alignment fill and encryption
 	blockSize := block.BlockSize()
@@ -119,19 +120,19 @@ func AesEncrypt(origData, key []byte) ([]byte, error) {
 	return crypted, nil
 }
 
-//AES decryption
-func AesDecrypt(crypted, key []byte) ([]byte, error) {
+// AES decryption
+func AesDecrypt(crypted, key []byte) ([]byte, errors.Error) {
 	// Uniformly use sha256 to process as 32-bit Byte (256-bit bit)
 	sha256Key := sha256.Sum256(key)
 	key = sha256Key[:]
 	block, err := aes.NewCipher(key)
 	if err != nil {
-		return nil, err
+		return nil, errors.Convert(err)
 	}
 	// Get the block size and check whether the ciphertext length is legal
 	blockSize := block.BlockSize()
 	if len(crypted)%blockSize != 0 {
-		return nil, fmt.Errorf("The length of the data to be decrypted is [%d], so cannot match the required block size [%d]", len(crypted), blockSize)
+		return nil, errors.Default.New(fmt.Sprintf("The length of the data to be decrypted is [%d], so cannot match the required block size [%d]", len(crypted), blockSize))
 	}
 
 	// Decrypt and unalign data
