@@ -18,12 +18,12 @@ limitations under the License.
 package main
 
 import (
-	"fmt"
+	"github.com/apache/incubator-devlake/errors"
+	"github.com/apache/incubator-devlake/plugins/helper"
 
 	"github.com/apache/incubator-devlake/plugins/core"
 	"github.com/apache/incubator-devlake/plugins/dbt/tasks"
 	"github.com/apache/incubator-devlake/runner"
-	"github.com/mitchellh/mapstructure"
 	"github.com/spf13/cobra"
 )
 
@@ -46,23 +46,23 @@ func (plugin Dbt) GetTablesInfo() []core.Tabler {
 	return []core.Tabler{}
 }
 
-func (plugin Dbt) PrepareTaskData(taskCtx core.TaskContext, options map[string]interface{}) (interface{}, error) {
+func (plugin Dbt) PrepareTaskData(taskCtx core.TaskContext, options map[string]interface{}) (interface{}, errors.Error) {
 	var op tasks.DbtOptions
-	err := mapstructure.Decode(options, &op)
+	err := helper.Decode(options, &op, nil)
 	if err != nil {
 		return nil, err
 	}
 	if op.ProjectPath == "" {
-		return nil, fmt.Errorf("projectPath is required for dbt plugin")
+		return nil, errors.Default.New("projectPath is required for dbt plugin")
 	}
 	if op.ProjectName == "" {
-		return nil, fmt.Errorf("projectName is required for dbt plugin")
+		return nil, errors.Default.New("projectName is required for dbt plugin")
 	}
 	if op.ProjectTarget == "" {
 		op.ProjectTarget = "dev"
 	}
 	if op.SelectedModels == nil {
-		return nil, fmt.Errorf("selectedModels is required for dbt plugin")
+		return nil, errors.Default.New("selectedModels is required for dbt plugin")
 	}
 
 	return &tasks.DbtTaskData{
