@@ -19,6 +19,7 @@ package impl
 
 import (
 	"fmt"
+	"github.com/apache/incubator-devlake/errors"
 
 	"github.com/apache/incubator-devlake/migration"
 	"github.com/apache/incubator-devlake/plugins/core"
@@ -27,7 +28,6 @@ import (
 	"github.com/apache/incubator-devlake/plugins/gitee/models/migrationscripts"
 	"github.com/apache/incubator-devlake/plugins/gitee/tasks"
 	"github.com/apache/incubator-devlake/plugins/helper"
-	"github.com/mitchellh/mapstructure"
 	"github.com/spf13/viper"
 	"gorm.io/gorm"
 )
@@ -41,7 +41,7 @@ var _ core.CloseablePluginTask = (*Gitee)(nil)
 
 type Gitee string
 
-func (plugin Gitee) Init(config *viper.Viper, logger core.Logger, db *gorm.DB) error {
+func (plugin Gitee) Init(config *viper.Viper, logger core.Logger, db *gorm.DB) errors.Error {
 	api.Init(config, logger, db)
 	return nil
 }
@@ -105,20 +105,20 @@ func (plugin Gitee) SubTaskMetas() []core.SubTaskMeta {
 	}
 }
 
-func (plugin Gitee) PrepareTaskData(taskCtx core.TaskContext, options map[string]interface{}) (interface{}, error) {
+func (plugin Gitee) PrepareTaskData(taskCtx core.TaskContext, options map[string]interface{}) (interface{}, errors.Error) {
 	var op tasks.GiteeOptions
-	var err error
-	err = mapstructure.Decode(options, &op)
+	var err errors.Error
+	err = helper.Decode(options, &op, nil)
 	if err != nil {
 		return nil, err
 	}
 
 	if op.Owner == "" {
-		return nil, fmt.Errorf("owner is required for Gitee execution")
+		return nil, errors.BadInput.New("owner is required for Gitee execution")
 	}
 
 	if op.Repo == "" {
-		return nil, fmt.Errorf("repo is required for Gitee execution")
+		return nil, errors.BadInput.New("repo is required for Gitee execution")
 	}
 
 	if op.PrType == "" {
@@ -154,7 +154,7 @@ func (plugin Gitee) PrepareTaskData(taskCtx core.TaskContext, options map[string
 	}
 
 	if op.ConnectionId == 0 {
-		return nil, fmt.Errorf("connectionId is invalid")
+		return nil, errors.BadInput.New("connectionId is invalid")
 	}
 
 	connection := &models.GiteeConnection{}
@@ -209,10 +209,10 @@ func (plugin Gitee) ApiResources() map[string]map[string]core.ApiResourceHandler
 	}
 }
 
-func (plugin Gitee) Close(taskCtx core.TaskContext) error {
+func (plugin Gitee) Close(taskCtx core.TaskContext) errors.Error {
 	data, ok := taskCtx.GetData().(*tasks.GiteeTaskData)
 	if !ok {
-		return fmt.Errorf("GetData failed when try to close %+v", taskCtx)
+		return errors.Default.New(fmt.Sprintf("GetData failed when try to close %+v", taskCtx))
 	}
 	data.ApiClient.Release()
 	return nil
