@@ -20,10 +20,10 @@ package parser
 import (
 	"encoding/base64"
 	"fmt"
-	"io/ioutil"
 	"net"
 	"os"
 
+	"github.com/apache/incubator-devlake/errors"
 	gogit "github.com/go-git/go-git/v5"
 	"github.com/go-git/go-git/v5/plumbing/transport/ssh"
 	git "github.com/libgit2/git2go/v33"
@@ -32,10 +32,10 @@ import (
 
 const DefaultUser = "git"
 
-func cloneOverSSH(url, dir, passphrase string, pk []byte) error {
+func cloneOverSSH(url, dir, passphrase string, pk []byte) errors.Error {
 	key, err := ssh.NewPublicKeys(DefaultUser, pk, passphrase)
 	if err != nil {
-		return err
+		return errors.Convert(err)
 	}
 	key.HostKeyCallbackHelper = ssh.HostKeyCallbackHelper{
 		HostKeyCallback: func(hostname string, remote net.Addr, key ssh2.PublicKey) error {
@@ -47,16 +47,16 @@ func cloneOverSSH(url, dir, passphrase string, pk []byte) error {
 		Auth: key,
 	})
 	if err != nil {
-		return err
+		return errors.Convert(err)
 	}
 	return nil
 }
 
-func (l *GitRepoCreator) CloneOverHTTP(repoId, url, user, password, proxy string) (*GitRepo, error) {
+func (l *GitRepoCreator) CloneOverHTTP(repoId, url, user, password, proxy string) (*GitRepo, errors.Error) {
 	return withTempDirectory(func(dir string) (*GitRepo, error) {
 		cloneOptions := &git.CloneOptions{Bare: true}
 		if proxy != "" {
-			cloneOptions.FetchOptions.ProxyOptions.Type = git.ProxyTypeSpecified
+			cloneOptions.FetchOptions.ProxyOptions.Type = git.ProxyTypeAuto
 			cloneOptions.FetchOptions.ProxyOptions.Url = proxy
 		}
 		if user != "" {
@@ -71,7 +71,7 @@ func (l *GitRepoCreator) CloneOverHTTP(repoId, url, user, password, proxy string
 	})
 }
 
-func (l *GitRepoCreator) CloneOverSSH(repoId, url, privateKey, passphrase string) (*GitRepo, error) {
+func (l *GitRepoCreator) CloneOverSSH(repoId, url, privateKey, passphrase string) (*GitRepo, errors.Error) {
 	return withTempDirectory(func(dir string) (*GitRepo, error) {
 		pk, err := base64.StdEncoding.DecodeString(privateKey)
 		if err != nil {
@@ -85,10 +85,10 @@ func (l *GitRepoCreator) CloneOverSSH(repoId, url, privateKey, passphrase string
 	})
 }
 
-func withTempDirectory(f func(tempDir string) (*GitRepo, error)) (*GitRepo, error) {
-	dir, err := ioutil.TempDir("", "gitextractor")
+func withTempDirectory(f func(tempDir string) (*GitRepo, error)) (*GitRepo, errors.Error) {
+	dir, err := os.MkdirTemp("", "gitextractor")
 	if err != nil {
-		return nil, err
+		return nil, errors.Convert(err)
 	}
 	cleanup := func() {
 		_ = os.RemoveAll(dir)
@@ -100,8 +100,8 @@ func withTempDirectory(f func(tempDir string) (*GitRepo, error)) (*GitRepo, erro
 	}()
 	repo, err := f(dir)
 	if err != nil {
-		return nil, err
+		return nil, errors.Convert(err)
 	}
 	repo.cleanup = cleanup
-	return repo, err
+	return repo, errors.Convert(err)
 }
