@@ -19,14 +19,20 @@ package parser
 
 import (
 	"context"
+	"crypto/sha256"
+	"encoding/hex"
 	"fmt"
+	"regexp"
+	"sort"
+	"strconv"
+
+	"github.com/apache/incubator-devlake/errors"
 	"github.com/apache/incubator-devlake/models/domainlayer"
 	"github.com/apache/incubator-devlake/models/domainlayer/code"
 	"github.com/apache/incubator-devlake/plugins/core"
 	"github.com/apache/incubator-devlake/plugins/core/dal"
 	"github.com/apache/incubator-devlake/plugins/gitextractor/models"
 	git "github.com/libgit2/git2go/v33"
-	"regexp"
 )
 
 type GitRepo struct {
@@ -37,7 +43,8 @@ type GitRepo struct {
 	cleanup func()
 }
 
-func (r *GitRepo) CollectAll(subtaskCtx core.SubTaskContext) error {
+// CollectAll The main parser subtask
+func (r *GitRepo) CollectAll(subtaskCtx core.SubTaskContext) errors.Error {
 	subtaskCtx.SetProgress(0, -1)
 	err := r.CollectTags(subtaskCtx)
 	if err != nil {
@@ -47,10 +54,15 @@ func (r *GitRepo) CollectAll(subtaskCtx core.SubTaskContext) error {
 	if err != nil {
 		return err
 	}
-	return r.CollectCommits(subtaskCtx)
+	err = r.CollectCommits(subtaskCtx)
+	if err != nil {
+		return err
+	}
+	return r.CollectDiffLine(subtaskCtx)
 }
 
-func (r *GitRepo) Close() error {
+// Close resources
+func (r *GitRepo) Close() errors.Error {
 	defer func() {
 		if r.cleanup != nil {
 			r.cleanup()
@@ -59,19 +71,21 @@ func (r *GitRepo) Close() error {
 	return r.store.Close()
 }
 
-func (r *GitRepo) CountTags() (int, error) {
+// CountTags Count git tags subtask
+func (r *GitRepo) CountTags() (int, errors.Error) {
 	tags, err := r.repo.Tags.List()
 	if err != nil {
-		return 0, err
+		return 0, errors.Convert(err)
 	}
 	return len(tags), nil
 }
 
-func (r *GitRepo) CountBranches(ctx context.Context) (int, error) {
+// CountBranches count the number of branches in a git repo
+func (r *GitRepo) CountBranches(ctx context.Context) (int, errors.Error) {
 	var branchIter *git.BranchIterator
 	branchIter, err := r.repo.NewBranchIterator(git.BranchAll)
 	if err != nil {
-		return 0, err
+		return 0, errors.Convert(err)
 	}
 	count := 0
 	err = branchIter.ForEach(func(branch *git.Branch, branchType git.BranchType) error {
@@ -85,13 +99,14 @@ func (r *GitRepo) CountBranches(ctx context.Context) (int, error) {
 		}
 		return nil
 	})
-	return count, err
+	return count, errors.Convert(err)
 }
 
-func (r *GitRepo) CountCommits(ctx context.Context) (int, error) {
+// CountCommits count the number of commits in a git repo
+func (r *GitRepo) CountCommits(ctx context.Context) (int, errors.Error) {
 	odb, err := r.repo.Odb()
 	if err != nil {
-		return 0, err
+		return 0, errors.Convert(err)
 	}
 	count := 0
 	err = odb.ForEach(func(id *git.Oid) error {
@@ -106,11 +121,12 @@ func (r *GitRepo) CountCommits(ctx context.Context) (int, error) {
 		}
 		return nil
 	})
-	return count, err
+	return count, errors.Convert(err)
 }
 
-func (r *GitRepo) CollectTags(subtaskCtx core.SubTaskContext) error {
-	return r.repo.Tags.Foreach(func(name string, id *git.Oid) error {
+// CollectTags Collect Tags data
+func (r *GitRepo) CollectTags(subtaskCtx core.SubTaskContext) errors.Error {
+	return errors.Convert(r.repo.Tags.Foreach(func(name string, id *git.Oid) error {
 		select {
 		case <-subtaskCtx.GetContext().Done():
 			return subtaskCtx.GetContext().Err()
@@ -141,16 +157,17 @@ func (r *GitRepo) CollectTags(subtaskCtx core.SubTaskContext) error {
 			subtaskCtx.IncProgress(1)
 		}
 		return nil
-	})
+	}))
 }
 
-func (r *GitRepo) CollectBranches(subtaskCtx core.SubTaskContext) error {
+// CollectBranches Collect branch data
+func (r *GitRepo) CollectBranches(subtaskCtx core.SubTaskContext) errors.Error {
 	var repoInter *git.BranchIterator
 	repoInter, err := r.repo.NewBranchIterator(git.BranchAll)
 	if err != nil {
-		return err
+		return errors.Convert(err)
 	}
-	return repoInter.ForEach(func(branch *git.Branch, branchType git.BranchType) error {
+	return errors.Convert(repoInter.ForEach(func(branch *git.Branch, branchType git.BranchType) error {
 		select {
 		case <-subtaskCtx.GetContext().Done():
 			return subtaskCtx.GetContext().Err()
@@ -181,12 +198,12 @@ func (r *GitRepo) CollectBranches(subtaskCtx core.SubTaskContext) error {
 			return nil
 		}
 		return nil
-	})
+	}))
 }
 
-func (r *GitRepo) CollectCommits(subtaskCtx core.SubTaskContext) error {
+// CollectCommits Collect data from each commit, we can also get the diff line
+func (r *GitRepo) CollectCommits(subtaskCtx core.SubTaskContext) errors.Error {
 	opts, err := getDiffOpts()
-
 	if err != nil {
 		return err
 	}
@@ -200,12 +217,11 @@ func (r *GitRepo) CollectCommits(subtaskCtx core.SubTaskContext) error {
 	for _, component := range components {
 		componentMap[component.Name] = regexp.MustCompile(component.PathRegex)
 	}
-	odb, err := r.repo.Odb()
+	odb, err := errors.Convert01(r.repo.Odb())
 	if err != nil {
 		return err
 	}
-
-	return odb.ForEach(func(id *git.Oid) error {
+	return errors.Convert(odb.ForEach(func(id *git.Oid) error {
 		select {
 		case <-subtaskCtx.GetContext().Done():
 			return subtaskCtx.GetContext().Err()
@@ -264,10 +280,10 @@ func (r *GitRepo) CollectCommits(subtaskCtx core.SubTaskContext) error {
 		}
 		subtaskCtx.IncProgress(1)
 		return nil
-	})
+	}))
 }
 
-func (r *GitRepo) storeParentCommits(commitSha string, commit *git.Commit) error {
+func (r *GitRepo) storeParentCommits(commitSha string, commit *git.Commit) errors.Error {
 	var commitParents []*code.CommitParent
 	for i := uint(0); i < commit.ParentCount(); i++ {
 		parent := commit.Parent(i)
@@ -283,35 +299,35 @@ func (r *GitRepo) storeParentCommits(commitSha string, commit *git.Commit) error
 	return r.store.CommitParents(commitParents)
 }
 
-func (r *GitRepo) getDiffComparedToParent(commitSha string, commit *git.Commit, parent *git.Commit, opts *git.DiffOptions, componentMap map[string]*regexp.Regexp) (*git.DiffStats, error) {
+func (r *GitRepo) getDiffComparedToParent(commitSha string, commit *git.Commit, parent *git.Commit, opts *git.DiffOptions, componentMap map[string]*regexp.Regexp) (*git.DiffStats, errors.Error) {
 	var err error
 	var parentTree, tree *git.Tree
 	parentTree, err = parent.Tree()
 	if err != nil {
-		return nil, err
+		return nil, errors.Convert(err)
 	}
 	tree, err = commit.Tree()
 	if err != nil {
-		return nil, err
+		return nil, errors.Convert(err)
 	}
 	var diff *git.Diff
 	diff, err = r.repo.DiffTreeToTree(parentTree, tree, opts)
 	if err != nil {
-		return nil, err
+		return nil, errors.Convert(err)
 	}
 	err = r.storeCommitFilesFromDiff(commitSha, diff, componentMap)
 	if err != nil {
-		return nil, err
+		return nil, errors.Convert(err)
 	}
 	var stats *git.DiffStats
 	stats, err = diff.Stats()
 	if err != nil {
-		return nil, err
+		return nil, errors.Convert(err)
 	}
 	return stats, nil
 }
 
-func (r *GitRepo) storeCommitFilesFromDiff(commitSha string, diff *git.Diff, componentMap map[string]*regexp.Regexp) error {
+func (r *GitRepo) storeCommitFilesFromDiff(commitSha string, diff *git.Diff, componentMap map[string]*regexp.Regexp) errors.Error {
 	var commitFile *code.CommitFile
 	var commitFileComponent *code.CommitFileComponent
 	var err error
@@ -320,7 +336,7 @@ func (r *GitRepo) storeCommitFilesFromDiff(commitSha string, diff *git.Diff, com
 		if commitFile != nil {
 			err = r.store.CommitFiles(commitFile)
 			if err != nil {
-				r.logger.Error("CommitFiles error:", err)
+				r.logger.Error(err, "CommitFiles error")
 				return nil, err
 			}
 		}
@@ -328,7 +344,14 @@ func (r *GitRepo) storeCommitFilesFromDiff(commitSha string, diff *git.Diff, com
 		commitFile = new(code.CommitFile)
 		commitFile.CommitSha = commitSha
 		commitFile.FilePath = file.NewFile.Path
-		commitFile.Id = commitSha + ":" + file.NewFile.Path
+
+		// With some long path,the varchar(255) was not enough both ID and file_path
+		// So we use the hash to compress the path in ID and add length of file_path.
+		// Use commitSha and the sha256 of FilePath to create id
+		shaFilePath := sha256.New()
+		shaFilePath.Write([]byte(file.NewFile.Path))
+		commitFile.Id = commitSha + ":" + hex.EncodeToString(shaFilePath.Sum(nil))
+
 		commitFileComponent = new(code.CommitFileComponent)
 		for component, reg := range componentMap {
 			if reg.MatchString(commitFile.FilePath) {
@@ -336,9 +359,7 @@ func (r *GitRepo) storeCommitFilesFromDiff(commitSha string, diff *git.Diff, com
 				break
 			}
 		}
-		commitFileComponent.CommitFileId = commitSha + ":" + file.NewFile.Path
-		//commitFileComponent.FilePath = file.NewFile.Path
-		//commitFileComponent.CommitSha = commitSha
+		commitFileComponent.CommitFileId = commitFile.Id
 		if commitFileComponent.ComponentName == "" {
 			commitFileComponent.ComponentName = "Default"
 		}
@@ -357,22 +378,153 @@ func (r *GitRepo) storeCommitFilesFromDiff(commitSha string, diff *git.Diff, com
 	if commitFileComponent != nil {
 		err = r.store.CommitFileComponents(commitFileComponent)
 		if err != nil {
-			r.logger.Error("CommitFileComponents error:", err)
+			r.logger.Error(err, "CommitFileComponents error")
 		}
 	}
 	if commitFile != nil {
 		err = r.store.CommitFiles(commitFile)
 		if err != nil {
-			r.logger.Error("CommitFiles error:", err)
+			r.logger.Error(err, "CommitFiles error")
 		}
 	}
-	return err
+	return errors.Convert(err)
 }
 
-func getDiffOpts() (*git.DiffOptions, error) {
+// CollectDiffLine get line diff data from a specific branch
+func (r *GitRepo) CollectDiffLine(subtaskCtx core.SubTaskContext) errors.Error {
+	//Using this subtask,we can get every line change in every commit.
+	//We maintain a snapshot structure to get which commit each deleted line belongs to
+	snapshot := make(map[string] /*file path*/ *models.FileBlame)
+	repo := r.repo
+	//step 1. get the reverse commit list
+	commitList := make([]git.Commit, 0)
+	//get currently head commitsha, dafault is master branch
+	// check branch, if not master, checkout to branch's head
+	commitOid, _ := repo.Head()
+	//get head commit object and add into commitList
+	commit, _ := repo.LookupCommit(commitOid.Target())
+	commitList = append(commitList, *commit)
+	// if current head has parents, get parent commitsha
+	for commit != nil && commit.ParentCount() > 0 {
+		pid := commit.ParentId(0)
+		commit, _ = repo.LookupCommit(pid)
+		commitList = append(commitList, *commit)
+	}
+	// reverse commitList
+	for i, j := 0, len(commitList)-1; i < j; i, j = i+1, j-1 {
+		commitList[i], commitList[j] = commitList[j], commitList[i]
+	}
+	//step 2. get the diff of each commit
+	// for each commit, get the diff
+	for _, commitsha := range commitList {
+		curcommit, err := repo.LookupCommit(commitsha.Id())
+		if err != nil {
+			return errors.Convert(err)
+		}
+		if curcommit.ParentCount() == 0 || curcommit.ParentCount() > 0 {
+			var parentTree, tree *git.Tree
+			tree, err = curcommit.Tree()
+			if err != nil {
+				return errors.Convert(err)
+			}
+			var diff *git.Diff
+			//FIXME error type convert
+			opts, err := git.DefaultDiffOptions()
+			opts.NotifyCallback = func(diffSoFar *git.Diff, delta git.DiffDelta, matchedPathSpec string) error {
+				return nil
+			}
+			if err != nil {
+				return errors.Convert(err)
+			}
+			if curcommit.ParentCount() > 0 {
+				parent := curcommit.Parent(0)
+				parentTree, err = parent.Tree()
+			}
+			diff, err = repo.DiffTreeToTree(parentTree, tree, &opts)
+			if err != nil {
+				return errors.Convert(err)
+			}
+			deleted := make(models.DiffLines, 0)
+			added := make(models.DiffLines, 0)
+			var lastFile string
+			lastFile = ""
+			err = diff.ForEach(func(file git.DiffDelta, progress float64) (git.DiffForEachHunkCallback, error) {
+				//if doesn't exist in snapshot, create a new one
+				if _, ok := snapshot[file.OldFile.Path]; !ok {
+					fileBlame, err := models.NewFileBlame()
+					if err != nil {
+						r.logger.Info("Create FileBlame Error")
+						return nil, err
+					}
+					snapshot[file.OldFile.Path] = (*models.FileBlame)(fileBlame)
+				}
+				if lastFile == "" {
+					lastFile = file.NewFile.Path
+				} else if lastFile != file.NewFile.Path {
+					updateSnapshotFileBlame(curcommit, deleted, added, lastFile, snapshot)
+					//reset the deleted and added,last_file now is current file
+					deleted = make([]git.DiffLine, 0)
+					added = make([]git.DiffLine, 0)
+					lastFile = file.NewFile.Path
+				}
+				hunkNum := 0
+				return func(hunk git.DiffHunk) (git.DiffForEachLineCallback, error) {
+					hunkNum++
+					return func(line git.DiffLine) error {
+						commitLineChange := &code.CommitLineChange{}
+						commitLineChange.CommitSha = curcommit.Id().String()
+						commitLineChange.ChangedType = line.Origin.String()
+						commitLineChange.LineNoNew = line.NewLineno
+						commitLineChange.LineNoOld = line.OldLineno
+						commitLineChange.OldFilePath = file.OldFile.Path
+						commitLineChange.NewFilePath = file.NewFile.Path
+						commitLineChange.HunkNum = hunkNum
+						commitLineChange.Id = curcommit.Id().String() + ":" + file.NewFile.Path + ":" + strconv.Itoa(line.OldLineno) + ":" + strconv.Itoa(line.NewLineno)
+						if line.Origin == git.DiffLineAddition {
+							added = append(added, line)
+						} else if line.Origin == git.DiffLineDeletion {
+							fb := snapshot[file.OldFile.Path]
+							l := fb.Find(line.OldLineno)
+							if l != nil && l.Value != nil {
+								temp := snapshot[file.OldFile.Path].Find(line.OldLineno)
+								commitLineChange.PrevCommit = temp.Value.(string)
+							} else {
+								r.logger.Info("err", file.OldFile.Path, line.OldLineno, curcommit.Id().String())
+							}
+							deleted = append(deleted, line)
+						}
+						err = r.store.CommitLineChange(commitLineChange)
+						if err != nil {
+							return errors.Convert(err)
+						}
+						return nil
+					}, nil
+				}, nil
+			}, git.DiffDetailLines)
+			if err != nil {
+				return errors.Convert(err)
+			}
+			//finally,process the last file in diff
+			updateSnapshotFileBlame(curcommit, deleted, added, lastFile, snapshot)
+		}
+	}
+	return nil
+}
+
+func updateSnapshotFileBlame(currentCommit *git.Commit, deleted models.DiffLines, added models.DiffLines, lastFile string, snapshot map[string]*models.FileBlame) {
+	sort.Sort(deleted)
+	for _, line := range deleted {
+		snapshot[lastFile].RemoveLine(line.OldLineno)
+	}
+	for _, line := range added {
+		snapshot[lastFile].AddLine(line.NewLineno, currentCommit.Id().String())
+	}
+}
+
+func getDiffOpts() (*git.DiffOptions, errors.Error) {
 	opts, err := git.DefaultDiffOptions()
 	if err != nil {
-		return nil, err
+		return nil, errors.Convert(err)
 	}
 	opts.NotifyCallback = func(diffSoFar *git.Diff, delta git.DiffDelta, matchedPathSpec string) error {
 		return nil
