@@ -18,11 +18,11 @@ limitations under the License.
 package tasks
 
 import (
-	"errors"
-	"github.com/apache/incubator-devlake/plugins/gitextractor/parser"
 	"strings"
 
+	"github.com/apache/incubator-devlake/errors"
 	"github.com/apache/incubator-devlake/plugins/core"
+	"github.com/apache/incubator-devlake/plugins/gitextractor/parser"
 )
 
 type GitExtractorOptions struct {
@@ -35,27 +35,24 @@ type GitExtractorOptions struct {
 	Proxy      string `json:"proxy"`
 }
 
-func (o GitExtractorOptions) Valid() error {
+func (o GitExtractorOptions) Valid() errors.Error {
 	if o.RepoId == "" {
-		return errors.New("empty repoId")
+		return errors.BadInput.New("empty repoId")
 	}
 	if o.Url == "" {
-		return errors.New("empty url")
+		return errors.BadInput.New("empty url")
 	}
 	url := strings.TrimPrefix(o.Url, "ssh://")
 	if !(strings.HasPrefix(o.Url, "http") || strings.HasPrefix(url, "git@") || strings.HasPrefix(o.Url, "/")) {
-		return errors.New("wrong url")
-	}
-	if o.Proxy != "" && !strings.HasPrefix(o.Proxy, "http://") {
-		return errors.New("only support http proxy")
+		return errors.BadInput.New("wrong url")
 	}
 	return nil
 }
 
-func CollectGitCommits(subTaskCtx core.SubTaskContext) error {
+func CollectGitCommits(subTaskCtx core.SubTaskContext) errors.Error {
 	repo := getGitRepo(subTaskCtx)
 	if count, err := repo.CountCommits(subTaskCtx.GetContext()); err != nil {
-		subTaskCtx.GetLogger().Error("unable to get commit count: %v", err)
+		subTaskCtx.GetLogger().Error(err, "unable to get commit count")
 		subTaskCtx.SetProgress(0, -1)
 	} else {
 		subTaskCtx.SetProgress(0, count)
@@ -63,10 +60,10 @@ func CollectGitCommits(subTaskCtx core.SubTaskContext) error {
 	return repo.CollectCommits(subTaskCtx)
 }
 
-func CollectGitBranches(subTaskCtx core.SubTaskContext) error {
+func CollectGitBranches(subTaskCtx core.SubTaskContext) errors.Error {
 	repo := getGitRepo(subTaskCtx)
 	if count, err := repo.CountBranches(subTaskCtx.GetContext()); err != nil {
-		subTaskCtx.GetLogger().Error("unable to get branch count: %v", err)
+		subTaskCtx.GetLogger().Error(err, "unable to get branch count")
 		subTaskCtx.SetProgress(0, -1)
 	} else {
 		subTaskCtx.SetProgress(0, count)
@@ -74,10 +71,10 @@ func CollectGitBranches(subTaskCtx core.SubTaskContext) error {
 	return repo.CollectBranches(subTaskCtx)
 }
 
-func CollectGitTags(subTaskCtx core.SubTaskContext) error {
+func CollectGitTags(subTaskCtx core.SubTaskContext) errors.Error {
 	repo := getGitRepo(subTaskCtx)
 	if count, err := repo.CountTags(); err != nil {
-		subTaskCtx.GetLogger().Error("unable to get tag count: %v", err)
+		subTaskCtx.GetLogger().Error(err, "unable to get tag count")
 		subTaskCtx.SetProgress(0, -1)
 	} else {
 		subTaskCtx.SetProgress(0, count)
@@ -85,6 +82,17 @@ func CollectGitTags(subTaskCtx core.SubTaskContext) error {
 	return repo.CollectTags(subTaskCtx)
 }
 
+func CollectGitDiffLines(subTaskCtx core.SubTaskContext) errors.Error {
+	repo := getGitRepo(subTaskCtx)
+	if count, err := repo.CountTags(); err != nil {
+		subTaskCtx.GetLogger().Error(err, "unable to get line content")
+		subTaskCtx.SetProgress(0, -1)
+	} else {
+		subTaskCtx.SetProgress(0, count)
+	}
+	return repo.CollectDiffLine(subTaskCtx)
+}
+
 func getGitRepo(subTaskCtx core.SubTaskContext) *parser.GitRepo {
 	repo, ok := subTaskCtx.GetData().(*parser.GitRepo)
 	if !ok {
@@ -93,6 +101,14 @@ func getGitRepo(subTaskCtx core.SubTaskContext) *parser.GitRepo {
 	return repo
 }
 
+var CollectGitDiffLineMeta = core.SubTaskMeta{
+	Name:             "collectDiffLine",
+	EntryPoint:       CollectGitDiffLines,
+	EnabledByDefault: false,
+	Description:      "collect git commit diff line into Domain Layer Tables",
+	DomainTypes:      []string{core.DOMAIN_TYPE_CODE},
+}
+
 var CollectGitCommitMeta = core.SubTaskMeta{
 	Name:             "collectGitCommits",
 	EntryPoint:       CollectGitCommits,
