@@ -45,6 +45,7 @@ func main() {
 	issueTypeBug := cmd.Flags().String("issueTypeBug", "^(bug|failure|error)$", "issue type bug")
 	issueTypeIncident := cmd.Flags().String("issueTypeIncident", "", "issue type incident")
 	issueTypeRequirement := cmd.Flags().String("issueTypeRequirement", "^(feat|feature|proposal|requirement)$", "issue type requirement")
+	deployTagPattern := cmd.Flags().String("deployTagPattern", "(?i)deploy", "deploy tag name")
 
 	cmd.Run = func(cmd *cobra.Command, args []string) {
 		runner.DirectRun(cmd, args, PluginEntry, map[string]interface{}{
@@ -60,6 +61,7 @@ func main() {
 			"issueTypeBug":         *issueTypeBug,
 			"issueTypeIncident":    *issueTypeIncident,
 			"issueTypeRequirement": *issueTypeRequirement,
+			"deployTagPattern":     *deployTagPattern,
 		})
 	}
 	runner.RunCmd(cmd)
