@@ -21,6 +21,7 @@ import (
 	"fmt"
 	"time"
 
+	"github.com/apache/incubator-devlake/errors"
 	"github.com/apache/incubator-devlake/migration"
 	"github.com/apache/incubator-devlake/plugins/core"
 	"github.com/apache/incubator-devlake/plugins/github/api"
@@ -42,7 +43,7 @@ var _ core.CloseablePluginTask = (*Github)(nil)
 
 type Github struct{}
 
-func (plugin Github) Init(config *viper.Viper, logger core.Logger, db *gorm.DB) error {
+func (plugin Github) Init(config *viper.Viper, logger core.Logger, db *gorm.DB) errors.Error {
 	api.Init(config, logger, db)
 	return nil
 }
@@ -60,7 +61,6 @@ func (plugin Github) GetTablesInfo() []core.Tabler {
 		&models.GithubIssueLabel{},
 		&models.GithubJob{},
 		&models.GithubMilestone{},
-		&models.GithubPipeline{},
 		&models.GithubPrComment{},
 		&models.GithubPrCommit{},
 		&models.GithubPrIssue{},
@@ -111,7 +111,6 @@ func (plugin Github) SubTaskMetas() []core.SubTaskMeta {
 		tasks.ExtractRunsMeta,
 		tasks.CollectJobsMeta,
 		tasks.ExtractJobsMeta,
-		tasks.EnrichPipelinesMeta,
 		tasks.ConvertPipelinesMeta,
 		tasks.ConvertTasksMeta,
 		tasks.EnrichPullRequestIssuesMeta,
@@ -131,7 +130,7 @@ func (plugin Github) SubTaskMetas() []core.SubTaskMeta {
 	}
 }
 
-func (plugin Github) PrepareTaskData(taskCtx core.TaskContext, options map[string]interface{}) (interface{}, error) {
+func (plugin Github) PrepareTaskData(taskCtx core.TaskContext, options map[string]interface{}) (interface{}, errors.Error) {
 	logger := taskCtx.GetLogger()
 	logger.Debug("%v", options)
 	op, err := tasks.DecodeAndValidateTaskOptions(options)
@@ -145,20 +144,20 @@ func (plugin Github) PrepareTaskData(taskCtx core.TaskContext, options map[strin
 	connection := &models.GithubConnection{}
 	err = connectionHelper.FirstById(connection, op.ConnectionId)
 	if err != nil {
-		return nil, fmt.Errorf("unable to get github connection by the given connection ID: %v", err)
+		return nil, errors.Default.Wrap(err, "unable to get github connection by the given connection ID")
 	}
 
 	var since time.Time
 	if op.Since != "" {
-		since, err = time.Parse("2006-01-02T15:04:05Z", op.Since)
+		since, err = errors.Convert01(time.Parse("2006-01-02T15:04:05Z", op.Since))
 		if err != nil {
-			return nil, fmt.Errorf("invalid value for `since`: %w", err)
+			return nil, errors.BadInput.Wrap(err, "invalid value for `since`")
 		}
 	}
 
 	apiClient, err := tasks.CreateApiClient(taskCtx, connection)
 	if err != nil {
-		return nil, fmt.Errorf("unable to get github API client instance: %v", err)
+		return nil, errors.Default.Wrap(err, "unable to get github API client instance")
 	}
 	taskData := &tasks.GithubTaskData{
 		Options:   op,
@@ -197,14 +196,14 @@ func (plugin Github) ApiResources() map[string]map[string]core.ApiResourceHandle
 	}
 }
 
-func (plugin Github) MakePipelinePlan(connectionId uint64, scope []*core.BlueprintScopeV100) (core.PipelinePlan, error) {
+func (plugin Github) MakePipelinePlan(connectionId uint64, scope []*core.BlueprintScopeV100) (core.PipelinePlan, errors.Error) {
 	return api.MakePipelinePlan(plugin.SubTaskMetas(), connectionId, scope)
 }
 
-func (plugin Github) Close(taskCtx core.TaskContext) error {
+func (plugin Github) Close(taskCtx core.TaskContext) errors.Error {
 	data, ok := taskCtx.GetData().(*tasks.GithubTaskData)
 	if !ok {
-		return fmt.Errorf("GetData failed when try to close %+v", taskCtx)
+		return errors.Default.New(fmt.Sprintf("GetData failed when try to close %+v", taskCtx))
 	}
 	data.ApiClient.Release()
 	return nil
