@@ -24,9 +24,10 @@ import (
 )
 
 type GithubRepo struct {
-	GithubId       int `gorm:"primaryKey"`
-	Name           string
-	HTMLUrl        string
+	ConnectionId   uint64 `gorm:"primaryKey"`
+	GithubId       int    `gorm:"primaryKey"`
+	Name           string `gorm:"type:varchar(255)"`
+	HTMLUrl        string `gorm:"type:varchar(255)"`
 	Description    string
 	OwnerId        int        `json:"ownerId"`
 	OwnerLogin     string     `json:"ownerLogin" gorm:"type:varchar(255)"`
