@@ -28,5 +28,7 @@ func All() []migration.Script {
 		new(addGithubRunsTable),
 		new(addGithubJobsTable),
 		new(addGithubPipelineTable),
+		new(deleteGithubPipelineTable),
+		new(addHeadRepoIdFieldInGithubPr),
 	}
 }
