@@ -21,12 +21,13 @@ import (
 	"github.com/apache/incubator-devlake/models/common"
 )
 
-type GithubPullRequestCommit struct {
+type GithubPrCommit struct {
+	ConnectionId  uint64 `gorm:"primaryKey"`
 	CommitSha     string `gorm:"primaryKey;type:varchar(40)"`
 	PullRequestId int    `gorm:"primaryKey;autoIncrement:false"`
 	common.NoPKModel
 }
 
-func (GithubPullRequestCommit) TableName() string {
+func (GithubPrCommit) TableName() string {
 	return "_tool_github_pull_request_commits"
 }
