@@ -22,6 +22,9 @@ import (
 	"fmt"
 	"net/http"
 	"net/url"
+	"time"
+
+	"github.com/apache/incubator-devlake/errors"
 
 	"github.com/apache/incubator-devlake/plugins/core/dal"
 
@@ -33,53 +36,22 @@ import (
 
 const RAW_COMMENTS_TABLE = "github_api_comments"
 
-func CollectApiComments(taskCtx core.SubTaskContext) error {
+func CollectApiComments(taskCtx core.SubTaskContext) errors.Error {
 	db := taskCtx.GetDal()
 	data := taskCtx.GetData().(*GithubTaskData)
 
 	since := data.Since
 	incremental := false
+	var err errors.Error
 	if since == nil {
-		var latestUpdatedIssueComt models.GithubIssueComment
-		err := db.All(
-			&latestUpdatedIssueComt,
-			dal.Join("left join _tool_github_issues on _tool_github_issues.github_id = _tool_github_issue_comments.issue_id"),
-			dal.Where(
-				"_tool_github_issues.repo_id = ? AND _tool_github_issues.connection_id = ?", data.Repo.GithubId, data.Repo.ConnectionId,
-			),
-			dal.Orderby("github_updated_at DESC"),
-			dal.Limit(1),
-		)
+		since, incremental, err = calculateSince(data, db)
 		if err != nil {
-			return fmt.Errorf("failed to get latest github issue record: %w", err)
-		}
-		var latestUpdatedPrComt models.GithubPrComment
-		err = db.All(
-			&latestUpdatedPrComt,
-			dal.Join("left join _tool_github_pull_requests on _tool_github_pull_requests.github_id = _tool_github_pull_request_comments.pull_request_id"),
-			dal.Where("_tool_github_pull_requests.repo_id = ? AND _tool_github_pull_requests.connection_id = ?", data.Repo.GithubId, data.Repo.ConnectionId),
-			dal.Orderby("github_updated_at DESC"),
-			dal.Limit(1),
-		)
-		if err != nil {
-			return fmt.Errorf("failed to get latest github issue record: %w", err)
-		}
-		if latestUpdatedIssueComt.GithubId > 0 && latestUpdatedPrComt.GithubId > 0 {
-			if latestUpdatedIssueComt.GithubUpdatedAt.Before(latestUpdatedPrComt.GithubUpdatedAt) {
-				since = &latestUpdatedPrComt.GithubUpdatedAt
-			} else {
-				since = &latestUpdatedIssueComt.GithubUpdatedAt
-			}
-			incremental = true
-		} else if latestUpdatedIssueComt.GithubId > 0 {
-			since = &latestUpdatedIssueComt.GithubUpdatedAt
-			incremental = true
-		} else if latestUpdatedPrComt.GithubId > 0 {
-			since = &latestUpdatedPrComt.GithubUpdatedAt
-			incremental = true
+			return err
 		}
 	}
-
+	if err != nil {
+		return err
+	}
 	collector, err := helper.NewApiCollector(helper.ApiCollectorArgs{
 		RawDataSubTaskArgs: helper.RawDataSubTaskArgs{
 			Ctx: taskCtx,
@@ -95,7 +67,7 @@ func CollectApiComments(taskCtx core.SubTaskContext) error {
 		Incremental: incremental,
 
 		UrlTemplate: "repos/{{ .Params.Owner }}/{{ .Params.Repo }}/issues/comments",
-		Query: func(reqData *helper.RequestData) (url.Values, error) {
+		Query: func(reqData *helper.RequestData) (url.Values, errors.Error) {
 			query := url.Values{}
 			query.Set("state", "all")
 			if since != nil {
@@ -108,7 +80,7 @@ func CollectApiComments(taskCtx core.SubTaskContext) error {
 			return query, nil
 		},
 		GetTotalPages: GetTotalPagesFromResponse,
-		ResponseParser: func(res *http.Response) ([]json.RawMessage, error) {
+		ResponseParser: func(res *http.Response) ([]json.RawMessage, errors.Error) {
 			var items []json.RawMessage
 			err := helper.UnmarshalResponse(res, &items)
 			if err != nil {
@@ -119,7 +91,7 @@ func CollectApiComments(taskCtx core.SubTaskContext) error {
 	})
 
 	if err != nil {
-		return err
+		return errors.Default.Wrap(err, "error collecting github comments")
 	}
 
 	return collector.Execute()
@@ -132,3 +104,49 @@ var CollectApiCommentsMeta = core.SubTaskMeta{
 	Description:      "Collect comments data from Github api",
 	DomainTypes:      []string{core.DOMAIN_TYPE_CODE_REVIEW, core.DOMAIN_TYPE_TICKET},
 }
+
+func calculateSince(data *GithubTaskData, db dal.Dal) (*time.Time, bool, errors.Error) {
+	var since *time.Time
+	var latestUpdatedIssueComt models.GithubIssueComment
+	var latestUpdatedPrComt models.GithubPrComment
+
+	incremental := false
+	err := db.All(
+		&latestUpdatedIssueComt,
+		dal.Join("left join _tool_github_issues on _tool_github_issues.github_id = _tool_github_issue_comments.issue_id"),
+		dal.Where(
+			"_tool_github_issues.repo_id = ? AND _tool_github_issues.connection_id = ?", data.Repo.GithubId, data.Repo.ConnectionId,
+		),
+		dal.Orderby("github_updated_at DESC"),
+		dal.Limit(1),
+	)
+	if err != nil {
+		return nil, false, errors.Default.Wrap(err, "failed to get latest github issue record")
+	}
+
+	err = db.All(
+		&latestUpdatedPrComt,
+		dal.Join("left join _tool_github_pull_requests on _tool_github_pull_requests.github_id = _tool_github_pull_request_comments.pull_request_id"),
+		dal.Where("_tool_github_pull_requests.repo_id = ? AND _tool_github_pull_requests.connection_id = ?", data.Repo.GithubId, data.Repo.ConnectionId),
+		dal.Orderby("github_updated_at DESC"),
+		dal.Limit(1),
+	)
+	if err != nil {
+		return nil, false, errors.Default.Wrap(err, "failed to get latest github issue record")
+	}
+	if latestUpdatedIssueComt.GithubId > 0 && latestUpdatedPrComt.GithubId > 0 {
+		if latestUpdatedIssueComt.GithubUpdatedAt.Before(latestUpdatedPrComt.GithubUpdatedAt) {
+			since = &latestUpdatedPrComt.GithubUpdatedAt
+		} else {
+			since = &latestUpdatedIssueComt.GithubUpdatedAt
+		}
+		incremental = true
+	} else if latestUpdatedIssueComt.GithubId > 0 {
+		since = &latestUpdatedIssueComt.GithubUpdatedAt
+		incremental = true
+	} else if latestUpdatedPrComt.GithubId > 0 {
+		since = &latestUpdatedPrComt.GithubUpdatedAt
+		incremental = true
+	}
+	return since, incremental, nil
+}
