@@ -20,6 +20,7 @@ package tasks
 import (
 	"encoding/json"
 	"fmt"
+	"github.com/apache/incubator-devlake/errors"
 	"net/http"
 	"net/url"
 
@@ -41,7 +42,7 @@ var CollectApiCommitsMeta = core.SubTaskMeta{
 	DomainTypes:      []string{core.DOMAIN_TYPE_CODE},
 }
 
-func CollectApiCommits(taskCtx core.SubTaskContext) error {
+func CollectApiCommits(taskCtx core.SubTaskContext) errors.Error {
 	db := taskCtx.GetDal()
 	data := taskCtx.GetData().(*GithubTaskData)
 
@@ -59,7 +60,7 @@ func CollectApiCommits(taskCtx core.SubTaskContext) error {
 			dal.Limit(1),
 		)
 		if err != nil {
-			return fmt.Errorf("failed to get latest github commit record: %w", err)
+			return errors.Default.Wrap(err, "failed to get latest github commit record")
 		}
 		if latestUpdated.Sha != "" {
 			since = &latestUpdated.CommittedDate
@@ -100,7 +101,7 @@ func CollectApiCommits(taskCtx core.SubTaskContext) error {
 		/*
 			(Optional) Return query string for request, or you can plug them into UrlTemplate directly
 		*/
-		Query: func(reqData *helper.RequestData) (url.Values, error) {
+		Query: func(reqData *helper.RequestData) (url.Values, errors.Error) {
 			query := url.Values{}
 			query.Set("state", "all")
 			if since != nil {
@@ -130,7 +131,7 @@ func CollectApiCommits(taskCtx core.SubTaskContext) error {
 			or other techniques are required if this information was missing.
 		*/
 		GetTotalPages: GetTotalPagesFromResponse,
-		ResponseParser: func(res *http.Response) ([]json.RawMessage, error) {
+		ResponseParser: func(res *http.Response) ([]json.RawMessage, errors.Error) {
 			var items []json.RawMessage
 			err := helper.UnmarshalResponse(res, &items)
 			if err != nil {
