@@ -18,6 +18,7 @@ limitations under the License.
 package tasks
 
 import (
+	"github.com/apache/incubator-devlake/errors"
 	"reflect"
 
 	"github.com/apache/incubator-devlake/plugins/core/dal"
@@ -37,7 +38,7 @@ var ConvertCommitsMeta = core.SubTaskMeta{
 	DomainTypes:      []string{core.DOMAIN_TYPE_CODE},
 }
 
-func ConvertCommits(taskCtx core.SubTaskContext) error {
+func ConvertCommits(taskCtx core.SubTaskContext) errors.Error {
 	db := taskCtx.GetDal()
 	data := taskCtx.GetData().(*GithubTaskData)
 	repoId := data.Repo.GithubId
@@ -71,7 +72,7 @@ func ConvertCommits(taskCtx core.SubTaskContext) error {
 		InputRowType: reflect.TypeOf(githubModels.GithubCommit{}),
 		Input:        cursor,
 
-		Convert: func(inputRow interface{}) ([]interface{}, error) {
+		Convert: func(inputRow interface{}) ([]interface{}, errors.Error) {
 			githubCommit := inputRow.(*githubModels.GithubCommit)
 			domainCommit := &code.Commit{
 				Sha:            githubCommit.Sha,
