@@ -19,7 +19,7 @@ package tasks
 
 import (
 	"encoding/json"
-
+	"github.com/apache/incubator-devlake/errors"
 	"github.com/apache/incubator-devlake/plugins/core"
 	"github.com/apache/incubator-devlake/plugins/github/models"
 	"github.com/apache/incubator-devlake/plugins/helper"
@@ -55,7 +55,7 @@ type Commit struct {
 	Message string
 }
 
-func ExtractApiCommits(taskCtx core.SubTaskContext) error {
+func ExtractApiCommits(taskCtx core.SubTaskContext) errors.Error {
 	data := taskCtx.GetData().(*GithubTaskData)
 
 	extractor, err := helper.NewApiExtractor(helper.ApiExtractorArgs{
@@ -75,9 +75,9 @@ func ExtractApiCommits(taskCtx core.SubTaskContext) error {
 			*/
 			Table: RAW_COMMIT_TABLE,
 		},
-		Extract: func(row *helper.RawData) ([]interface{}, error) {
+		Extract: func(row *helper.RawData) ([]interface{}, errors.Error) {
 			commit := &CommitsResponse{}
-			err := json.Unmarshal(row.Data, commit)
+			err := errors.Convert(json.Unmarshal(row.Data, commit))
 			if err != nil {
 				return nil, err
 			}
