@@ -19,14 +19,12 @@ package tasks
 
 import (
 	"encoding/json"
-	"fmt"
-	"regexp"
-	"runtime/debug"
-
+	"github.com/apache/incubator-devlake/errors"
 	"github.com/apache/incubator-devlake/models/domainlayer/ticket"
 	"github.com/apache/incubator-devlake/plugins/core"
 	"github.com/apache/incubator-devlake/plugins/github/models"
 	"github.com/apache/incubator-devlake/plugins/helper"
+	"regexp"
 )
 
 var ExtractApiIssuesMeta = core.SubTaskMeta{
@@ -70,7 +68,7 @@ type IssueRegexes struct {
 	TypeIncidentRegex    *regexp.Regexp
 }
 
-func ExtractApiIssues(taskCtx core.SubTaskContext) error {
+func ExtractApiIssues(taskCtx core.SubTaskContext) errors.Error {
 	data := taskCtx.GetData().(*GithubTaskData)
 
 	config := data.Options.TransformationRules
@@ -95,9 +93,9 @@ func ExtractApiIssues(taskCtx core.SubTaskContext) error {
 			*/
 			Table: RAW_ISSUE_TABLE,
 		},
-		Extract: func(row *helper.RawData) ([]interface{}, error) {
+		Extract: func(row *helper.RawData) ([]interface{}, errors.Error) {
 			body := &IssuesResponse{}
-			err := json.Unmarshal(row.Data, body)
+			err := errors.Convert(json.Unmarshal(row.Data, body))
 			if err != nil {
 				return nil, err
 			}
@@ -149,7 +147,7 @@ func ExtractApiIssues(taskCtx core.SubTaskContext) error {
 	return extractor.Execute()
 }
 
-func convertGithubIssue(issue *IssuesResponse, connectionId uint64, repositoryId int) (*models.GithubIssue, error) {
+func convertGithubIssue(issue *IssuesResponse, connectionId uint64, repositoryId int) (*models.GithubIssue, errors.Error) {
 	githubIssue := &models.GithubIssue{
 		ConnectionId:    connectionId,
 		GithubId:        issue.GithubId,
@@ -180,7 +178,7 @@ func convertGithubIssue(issue *IssuesResponse, connectionId uint64, repositoryId
 	return githubIssue, nil
 }
 
-func convertGithubLabels(issueRegexes *IssueRegexes, issue *IssuesResponse, githubIssue *models.GithubIssue) ([]interface{}, error) {
+func convertGithubLabels(issueRegexes *IssueRegexes, issue *IssuesResponse, githubIssue *models.GithubIssue) ([]interface{}, errors.Error) {
 	var results []interface{}
 	for _, label := range issue.Labels {
 		results = append(results, &models.GithubIssueLabel{
@@ -225,49 +223,49 @@ func convertGithubLabels(issueRegexes *IssueRegexes, issue *IssuesResponse, gith
 	return results, nil
 }
 
-func NewIssueRegexes(config models.TransformationRules) (*IssueRegexes, error) {
+func NewIssueRegexes(config models.TransformationRules) (*IssueRegexes, errors.Error) {
 	var issueRegexes IssueRegexes
 	var issueSeverity = config.IssueSeverity
 	var err error
 	if len(issueSeverity) > 0 {
 		issueRegexes.SeverityRegex, err = regexp.Compile(issueSeverity)
 		if err != nil {
-			return nil, fmt.Errorf("regexp Compile issueSeverity failed:[%s] stack:[%s]", err.Error(), debug.Stack())
+			return nil, errors.Default.Wrap(err, "regexp Compile issueSeverity failed")
 		}
 	}
 	var issueComponent = config.IssueComponent
 	if len(issueComponent) > 0 {
 		issueRegexes.ComponentRegex, err = regexp.Compile(issueComponent)
 		if err != nil {
-			return nil, fmt.Errorf("regexp Compile issueComponent failed:[%s] stack:[%s]", err.Error(), debug.Stack())
+			return nil, errors.Default.Wrap(err, "regexp Compile issueComponent failed")
 		}
 	}
 	var issuePriority = config.IssuePriority
 	if len(issuePriority) > 0 {
 		issueRegexes.PriorityRegex, err = regexp.Compile(issuePriority)
 		if err != nil {
-			return nil, fmt.Errorf("regexp Compile issuePriority failed:[%s] stack:[%s]", err.Error(), debug.Stack())
+			return nil, errors.Default.Wrap(err, "regexp Compile issuePriority failed")
 		}
 	}
 	var issueTypeBug = config.IssueTypeBug
 	if len(issueTypeBug) > 0 {
 		issueRegexes.TypeBugRegex, err = regexp.Compile(issueTypeBug)
 		if err != nil {
-			return nil, fmt.Errorf("regexp Compile issueTypeBug failed:[%s] stack:[%s]", err.Error(), debug.Stack())
+			return nil, errors.Default.Wrap(err, "regexp Compile issueTypeBug failed")
 		}
 	}
 	var issueTypeRequirement = config.IssueTypeRequirement
 	if len(issueTypeRequirement) > 0 {
 		issueRegexes.TypeRequirementRegex, err = regexp.Compile(issueTypeRequirement)
 		if err != nil {
-			return nil, fmt.Errorf("regexp Compile issueTypeRequirement failed:[%s] stack:[%s]", err.Error(), debug.Stack())
+			return nil, errors.Default.Wrap(err, "regexp Compile issueTypeRequirement failed")
 		}
 	}
 	var issueTypeIncident = config.IssueTypeIncident
 	if len(issueTypeIncident) > 0 {
 		issueRegexes.TypeIncidentRegex, err = regexp.Compile(issueTypeIncident)
 		if err != nil {
-			return nil, fmt.Errorf("regexp Compile issueTypeIncident failed:[%s] stack:[%s]", err.Error(), debug.Stack())
+			return nil, errors.Default.Wrap(err, "regexp Compile issueTypeIncident failed")
 		}
 	}
 	return &issueRegexes, nil
