@@ -19,6 +19,7 @@ package tasks
 
 import (
 	"encoding/json"
+	"github.com/apache/incubator-devlake/errors"
 	"strings"
 
 	"github.com/apache/incubator-devlake/plugins/core"
@@ -55,8 +56,9 @@ type PullRequestCommit struct {
 	Message json.RawMessage
 }
 
-func ExtractApiPullRequestCommits(taskCtx core.SubTaskContext) error {
+func ExtractApiPullRequestCommits(taskCtx core.SubTaskContext) errors.Error {
 	data := taskCtx.GetData().(*GithubTaskData)
+	repoId := data.Repo.GithubId
 	extractor, err := helper.NewApiExtractor(helper.ApiExtractorArgs{
 		RawDataSubTaskArgs: helper.RawDataSubTaskArgs{
 			Ctx: taskCtx,
@@ -74,22 +76,28 @@ func ExtractApiPullRequestCommits(taskCtx core.SubTaskContext) error {
 			*/
 			Table: RAW_PR_COMMIT_TABLE,
 		},
-		Extract: func(row *helper.RawData) ([]interface{}, error) {
+		Extract: func(row *helper.RawData) ([]interface{}, errors.Error) {
 			apiPullRequestCommit := &PrCommitsResponse{}
 			if strings.HasPrefix(string(row.Data), "{\"message\": \"Not Found\"") {
 				return nil, nil
 			}
-			err := json.Unmarshal(row.Data, apiPullRequestCommit)
+			err := errors.Convert(json.Unmarshal(row.Data, apiPullRequestCommit))
 			if err != nil {
 				return nil, err
 			}
 			pull := &SimplePr{}
-			err = json.Unmarshal(row.Input, pull)
+			err = errors.Convert(json.Unmarshal(row.Input, pull))
 			if err != nil {
 				return nil, err
 			}
 			// need to extract 2 kinds of entities here
-			results := make([]interface{}, 0, 2)
+			results := make([]interface{}, 0, 3)
+			githubRepoCommit := &models.GithubRepoCommit{
+				ConnectionId: data.Options.ConnectionId,
+				RepoId:       repoId,
+				CommitSha:    apiPullRequestCommit.Sha,
+			}
+			results = append(results, githubRepoCommit)
 
 			githubCommit, err := convertPullRequestCommit(apiPullRequestCommit, data.Options.ConnectionId)
 			if err != nil {
@@ -117,7 +125,7 @@ func ExtractApiPullRequestCommits(taskCtx core.SubTaskContext) error {
 	return extractor.Execute()
 }
 
-func convertPullRequestCommit(prCommit *PrCommitsResponse, connId uint64) (*models.GithubCommit, error) {
+func convertPullRequestCommit(prCommit *PrCommitsResponse, connId uint64) (*models.GithubCommit, errors.Error) {
 	githubCommit := &models.GithubCommit{
 		Sha:            prCommit.Sha,
 		Message:        string(prCommit.Commit.Message),
