@@ -19,13 +19,11 @@ package tasks
 
 import (
 	"encoding/json"
-	"fmt"
-	"regexp"
-	"runtime/debug"
-
+	"github.com/apache/incubator-devlake/errors"
 	"github.com/apache/incubator-devlake/plugins/core"
 	"github.com/apache/incubator-devlake/plugins/github/models"
 	"github.com/apache/incubator-devlake/plugins/helper"
+	"regexp"
 )
 
 var ExtractApiPullRequestsMeta = core.SubTaskMeta{
@@ -37,33 +35,35 @@ var ExtractApiPullRequestsMeta = core.SubTaskMeta{
 }
 
 type GithubApiPullRequest struct {
-	GithubId int `json:"id"`
-	Number   int
-	State    string
-	Title    string
-	Body     json.RawMessage
-	HtmlUrl  string `json:"html_url"`
+	GithubId int             `json:"id"`
+	Number   int             `json:"number"`
+	State    string          `json:"state"`
+	Title    string          `json:"title"`
+	Body     json.RawMessage `json:"body"`
+	HtmlUrl  string          `json:"html_url"`
 	Labels   []struct {
 		Name string `json:"name"`
 	} `json:"labels"`
-	Assignee        *GithubAccountResponse
-	User            *GithubAccountResponse
-	ClosedAt        *helper.Iso8601Time `json:"closed_at"`
-	MergedAt        *helper.Iso8601Time `json:"merged_at"`
-	GithubCreatedAt helper.Iso8601Time  `json:"created_at"`
-	GithubUpdatedAt helper.Iso8601Time  `json:"updated_at"`
-	MergeCommitSha  string              `json:"merge_commit_sha"`
+	Assignee        *GithubAccountResponse `json:"assignee"`
+	User            *GithubAccountResponse `json:"user"`
+	ClosedAt        *helper.Iso8601Time    `json:"closed_at"`
+	MergedAt        *helper.Iso8601Time    `json:"merged_at"`
+	GithubCreatedAt helper.Iso8601Time     `json:"created_at"`
+	GithubUpdatedAt helper.Iso8601Time     `json:"updated_at"`
+	MergeCommitSha  string                 `json:"merge_commit_sha"`
 	Head            struct {
-		Ref string
-		Sha string
-	}
+		Ref  string         `json:"ref"`
+		Sha  string         `json:"sha"`
+		Repo *GithubApiRepo `json:"repo"`
+	} `json:"head"`
 	Base struct {
-		Ref string
-		Sha string
-	}
+		Ref  string         `json:"ref"`
+		Sha  string         `json:"sha"`
+		Repo *GithubApiRepo `json:"repo"`
+	} `json:"base"`
 }
 
-func ExtractApiPullRequests(taskCtx core.SubTaskContext) error {
+func ExtractApiPullRequests(taskCtx core.SubTaskContext) errors.Error {
 	data := taskCtx.GetData().(*GithubTaskData)
 	config := data.Options.TransformationRules
 	var labelTypeRegex *regexp.Regexp
@@ -73,14 +73,14 @@ func ExtractApiPullRequests(taskCtx core.SubTaskContext) error {
 	if len(prType) > 0 {
 		labelTypeRegex, err = regexp.Compile(prType)
 		if err != nil {
-			return fmt.Errorf("regexp Compile prType failed:[%s] stack:[%s]", err.Error(), debug.Stack())
+			return errors.Default.Wrap(err, "regexp Compile prType failed")
 		}
 	}
 	var prComponent = config.PrComponent
 	if len(prComponent) > 0 {
 		labelComponentRegex, err = regexp.Compile(prComponent)
 		if err != nil {
-			return fmt.Errorf("regexp Compile prComponent failed:[%s] stack:[%s]", err.Error(), debug.Stack())
+			return errors.Default.Wrap(err, "regexp Compile prComponent failed")
 		}
 	}
 
@@ -101,9 +101,9 @@ func ExtractApiPullRequests(taskCtx core.SubTaskContext) error {
 			*/
 			Table: RAW_PULL_REQUEST_TABLE,
 		},
-		Extract: func(row *helper.RawData) ([]interface{}, error) {
+		Extract: func(row *helper.RawData) ([]interface{}, errors.Error) {
 			rawL := &GithubApiPullRequest{}
-			err := json.Unmarshal(row.Data, rawL)
+			err := errors.Convert(json.Unmarshal(row.Data, rawL))
 			if err != nil {
 				return nil, err
 			}
@@ -155,12 +155,12 @@ func ExtractApiPullRequests(taskCtx core.SubTaskContext) error {
 	})
 
 	if err != nil {
-		return err
+		return errors.Default.Wrap(err, "error initializing Github PR extractor")
 	}
 
 	return extractor.Execute()
 }
-func convertGithubPullRequest(pull *GithubApiPullRequest, connId uint64, repoId int) (*models.GithubPullRequest, error) {
+func convertGithubPullRequest(pull *GithubApiPullRequest, connId uint64, repoId int) (*models.GithubPullRequest, errors.Error) {
 	githubPull := &models.GithubPullRequest{
 		ConnectionId:    connId,
 		GithubId:        pull.GithubId,
@@ -180,5 +180,9 @@ func convertGithubPullRequest(pull *GithubApiPullRequest, connId uint64, repoId
 		HeadRef:         pull.Head.Ref,
 		HeadCommitSha:   pull.Head.Sha,
 	}
+	if pull.Head.Repo != nil {
+		githubPull.HeadRepoId = pull.Head.Repo.GithubId
+	}
+
 	return githubPull, nil
 }
