@@ -18,13 +18,15 @@ limitations under the License.
 package tasks
 
 import (
-	"github.com/apache/incubator-devlake/plugins/github/utils"
 	"net/http"
 
+	"github.com/apache/incubator-devlake/errors"
+	"github.com/apache/incubator-devlake/plugins/github/utils"
+
 	"github.com/apache/incubator-devlake/plugins/helper"
 )
 
-func GetTotalPagesFromResponse(res *http.Response, args *helper.ApiCollectorArgs) (int, error) {
+func GetTotalPagesFromResponse(res *http.Response, args *helper.ApiCollectorArgs) (int, errors.Error) {
 	link := res.Header.Get("link")
 	pageInfo, err := utils.GetPagingFromLinkHeader(link)
 	if err != nil {
@@ -32,3 +34,13 @@ func GetTotalPagesFromResponse(res *http.Response, args *helper.ApiCollectorArgs
 	}
 	return pageInfo.Last, nil
 }
+
+func ignoreHTTPStatus404(res *http.Response) errors.Error {
+	if res.StatusCode == http.StatusUnauthorized {
+		return errors.Unauthorized.New("authentication failed, please check your AccessToken")
+	}
+	if res.StatusCode == http.StatusNotFound {
+		return helper.ErrIgnoreAndContinue
+	}
+	return nil
+}
