@@ -18,12 +18,12 @@ limitations under the License.
 package tasks
 
 import (
-	"fmt"
 	"time"
 
+	"github.com/apache/incubator-devlake/errors"
+
 	"github.com/apache/incubator-devlake/plugins/github/models"
 	"github.com/apache/incubator-devlake/plugins/helper"
-	"github.com/mitchellh/mapstructure"
 )
 
 type GithubOptions struct {
@@ -43,17 +43,17 @@ type GithubTaskData struct {
 	Repo          *models.GithubRepo
 }
 
-func DecodeAndValidateTaskOptions(options map[string]interface{}) (*GithubOptions, error) {
+func DecodeAndValidateTaskOptions(options map[string]interface{}) (*GithubOptions, errors.Error) {
 	var op GithubOptions
-	err := mapstructure.Decode(options, &op)
+	err := helper.Decode(options, &op, nil)
 	if err != nil {
 		return nil, err
 	}
 	if op.Owner == "" {
-		return nil, fmt.Errorf("owner is required for GitHub execution")
+		return nil, errors.BadInput.New("owner is required for GitHub execution")
 	}
 	if op.Repo == "" {
-		return nil, fmt.Errorf("repo is required for GitHub execution")
+		return nil, errors.BadInput.New("repo is required for GitHub execution")
 	}
 	if op.PrType == "" {
 		op.PrType = "type/(.*)$"
@@ -82,10 +82,13 @@ func DecodeAndValidateTaskOptions(options map[string]interface{}) (*GithubOption
 	if op.IssueTypeRequirement == "" {
 		op.IssueTypeRequirement = "^(feat|feature|proposal|requirement)$"
 	}
+	if op.DeploymentPattern == "" {
+		op.DeploymentPattern = "(?i)deploy"
+	}
 
 	// find the needed GitHub now
 	if op.ConnectionId == 0 {
-		return nil, fmt.Errorf("connectionId is invalid")
+		return nil, errors.BadInput.New("connectionId is invalid")
 	}
 	return &op, nil
 }
