@@ -18,7 +18,8 @@ limitations under the License.
 package utils
 
 import (
-	"errors"
+	//"errors"
+	"github.com/apache/incubator-devlake/errors"
 	"net/http"
 	"regexp"
 	"strconv"
@@ -39,33 +40,33 @@ type RateLimitInfo struct {
 	Remaining int
 }
 
-func ConvertRateLimitInfo(date string, resetTime string, remaining string) (RateLimitInfo, error) {
+func ConvertRateLimitInfo(date string, resetTime string, remaining string) (RateLimitInfo, errors.Error) {
 	var rateLimitInfo RateLimitInfo
-	var err error
+	var err errors.Error
 	if date != "" {
-		rateLimitInfo.Date, err = http.ParseTime(date)
+		rateLimitInfo.Date, err = errors.Convert01(http.ParseTime(date))
 		if err != nil {
 			return rateLimitInfo, err
 		}
 	} else {
-		return rateLimitInfo, errors.New("rate limit date was an empty string")
+		return rateLimitInfo, errors.Default.New("rate limit date was an empty string")
 	}
 	if resetTime != "" {
-		resetInt, err := strconv.ParseInt(resetTime, 10, 64)
+		resetInt, err := errors.Convert01(strconv.ParseInt(resetTime, 10, 64))
 		if err != nil {
 			return rateLimitInfo, err
 		}
 		rateLimitInfo.ResetTime = time.Unix(resetInt, 0)
 	} else {
-		return rateLimitInfo, errors.New("rate limit reset time was an empty string")
+		return rateLimitInfo, errors.Default.New("rate limit reset time was an empty string")
 	}
 	if remaining != "" {
-		rateLimitInfo.Remaining, err = strconv.Atoi(remaining)
+		rateLimitInfo.Remaining, err = ConvertStringToInt(remaining)
 		if err != nil {
 			return rateLimitInfo, err
 		}
 	} else {
-		return rateLimitInfo, errors.New("rate remaining was an empty string")
+		return rateLimitInfo, errors.Default.New("rate remaining was an empty string")
 	}
 	return rateLimitInfo, nil
 }
@@ -79,10 +80,10 @@ func GetRateLimitPerSecond(info RateLimitInfo) int {
 	adjustedRemaining := float64(info.Remaining) * multiplier
 	return int(adjustedRemaining / float64(timeBetweenNowAndReset)) //* multiplier
 }
-func ConvertStringToInt(input string) (int, error) {
-	return strconv.Atoi(input)
+func ConvertStringToInt(input string) (int, errors.Error) {
+	return errors.Convert01(strconv.Atoi(input))
 }
-func GetPagingFromLinkHeader(link string) (PagingInfo, error) {
+func GetPagingFromLinkHeader(link string) (PagingInfo, errors.Error) {
 	result := PagingInfo{
 		Next:  1,
 		Last:  1,
@@ -93,7 +94,7 @@ func GetPagingFromLinkHeader(link string) (PagingInfo, error) {
 	pattern1 := regexp.MustCompile(`page=*[0-9]+`)
 	pattern2 := regexp.MustCompile(`rel="*[a-z]+`)
 	if len(linksArray) < 2 {
-		return result, errors.New("the link string provided is invalid. There is likely no next page of data to fetch")
+		return result, errors.Default.New("the link string provided is invalid. There is likely no next page of data to fetch")
 	}
 	for i := 0; i < len(linksArray); i++ {
 		content := []byte(linksArray[i])
@@ -120,17 +121,17 @@ func GetPagingFromLinkHeader(link string) (PagingInfo, error) {
 				result.Prev = pageNumberInt
 			}
 		} else {
-			return result, errors.New("parsed string values aren't long enough")
+			return result, errors.Default.New("parsed string values aren't long enough")
 		}
 	}
 	return result, nil
 }
 
-func GetIssueIdByIssueUrl(s string) (int, error) {
+func GetIssueIdByIssueUrl(s string) (int, errors.Error) {
 	regex := regexp.MustCompile(`.*/issues/(\d+)`)
 	groups := regex.FindStringSubmatch(s)
 	if len(groups) == 0 {
-		return 0, errors.New("invalid issue url")
+		return 0, errors.Default.New("invalid issue url")
 	}
-	return strconv.Atoi(groups[1])
+	return ConvertStringToInt(groups[1])
 }
