@@ -18,7 +18,8 @@ limitations under the License.
 package e2e
 
 import (
-	"fmt"
+	"github.com/apache/incubator-devlake/models/domainlayer/crossdomain"
+	"github.com/apache/incubator-devlake/models/domainlayer/ticket"
 	"testing"
 
 	"github.com/apache/incubator-devlake/helpers/e2ehelper"
@@ -49,7 +50,7 @@ func TestGitlabProjectDataFlow(t *testing.T) {
 	dataflowTester.Subtask(tasks.ExtractProjectMeta, taskData)
 	dataflowTester.VerifyTable(
 		models.GitlabProject{},
-		fmt.Sprintf("./snapshot_tables/%s.csv", models.GitlabProject{}.TableName()),
+		"./snapshot_tables/_tool_gitlab_projects.csv",
 		[]string{
 			"connection_id",
 			"gitlab_id",
@@ -75,10 +76,12 @@ func TestGitlabProjectDataFlow(t *testing.T) {
 
 	// verify conversion
 	dataflowTester.FlushTabler(&code.Repo{})
+	dataflowTester.FlushTabler(&ticket.Board{})
+	dataflowTester.FlushTabler(&crossdomain.BoardRepo{})
 	dataflowTester.Subtask(tasks.ConvertProjectMeta, taskData)
 	dataflowTester.VerifyTable(
 		code.Repo{},
-		fmt.Sprintf("./snapshot_tables/%s.csv", code.Repo{}.TableName()),
+		"./snapshot_tables/repos.csv",
 		[]string{
 			"id",
 			"_raw_data_params",
@@ -96,4 +99,23 @@ func TestGitlabProjectDataFlow(t *testing.T) {
 			"deleted",
 		},
 	)
+	dataflowTester.VerifyTable(
+		ticket.Board{},
+		"./snapshot_tables/boards.csv",
+		[]string{
+			"id",
+			"name",
+			"description",
+			"url",
+			"created_date",
+		},
+	)
+	dataflowTester.VerifyTable(
+		crossdomain.BoardRepo{},
+		"./snapshot_tables/board_repos.csv",
+		[]string{
+			"board_id",
+			"repo_id",
+		},
+	)
 }
