@@ -27,5 +27,7 @@ func All() []migration.Script {
 		new(addInitTables),
 		new(modifyGitlabCI),
 		new(addPipelineID),
+		new(addPipelineProjects),
+		new(fixDurationToFloat8),
 	}
 }
