@@ -18,6 +18,7 @@ limitations under the License.
 package tasks
 
 import (
+	"github.com/apache/incubator-devlake/errors"
 	"github.com/apache/incubator-devlake/plugins/core"
 	"github.com/apache/incubator-devlake/plugins/helper"
 )
@@ -52,7 +53,7 @@ type GitlabApiCommit struct {
 	}
 }
 
-func CollectApiCommits(taskCtx core.SubTaskContext) error {
+func CollectApiCommits(taskCtx core.SubTaskContext) errors.Error {
 	rawDataSubTaskArgs, data := CreateRawDataSubTaskArgs(taskCtx, RAW_COMMIT_TABLE)
 
 	collector, err := helper.NewApiCollector(helper.ApiCollectorArgs{
