@@ -19,11 +19,9 @@ package tasks
 
 import (
 	"encoding/json"
-	"fmt"
-	"regexp"
-	"runtime/debug"
-
+	"github.com/apache/incubator-devlake/errors"
 	"github.com/apache/incubator-devlake/models/domainlayer/ticket"
+	"regexp"
 
 	"github.com/apache/incubator-devlake/plugins/core"
 
@@ -129,7 +127,7 @@ type IssuesResponse struct {
 	}
 }
 
-func ExtractApiIssues(taskCtx core.SubTaskContext) error {
+func ExtractApiIssues(taskCtx core.SubTaskContext) errors.Error {
 	rawDataSubTaskArgs, data := CreateRawDataSubTaskArgs(taskCtx, RAW_ISSUE_TABLE)
 	config := data.Options.TransformationRules
 	var issueSeverityRegex *regexp.Regexp
@@ -143,49 +141,49 @@ func ExtractApiIssues(taskCtx core.SubTaskContext) error {
 	if len(issueSeverity) > 0 {
 		issueSeverityRegex, err = regexp.Compile(issueSeverity)
 		if err != nil {
-			return fmt.Errorf("regexp Compile issueSeverity failed:[%s] stack:[%s]", err.Error(), debug.Stack())
+			return errors.Default.Wrap(err, "regexp Compile issueSeverity failed")
 		}
 	}
 	var issueComponent = config.IssueComponent
 	if len(issueComponent) > 0 {
 		issueComponentRegex, err = regexp.Compile(issueComponent)
 		if err != nil {
-			return fmt.Errorf("regexp Compile issueComponent failed:[%s] stack:[%s]", err.Error(), debug.Stack())
+			return errors.Default.Wrap(err, "regexp Compile issueComponent failed")
 		}
 	}
 	var issuePriority = config.IssuePriority
 	if len(issuePriority) > 0 {
 		issuePriorityRegex, err = regexp.Compile(issuePriority)
 		if err != nil {
-			return fmt.Errorf("regexp Compile issuePriority failed:[%s] stack:[%s]", err.Error(), debug.Stack())
+			return errors.Default.Wrap(err, "regexp Compile issuePriority failed")
 		}
 	}
 	var issueTypeBug = config.IssueTypeBug
 	if len(issueTypeBug) > 0 {
 		issueTypeBugRegex, err = regexp.Compile(issueTypeBug)
 		if err != nil {
-			return fmt.Errorf("regexp Compile issueTypeBug failed:[%s] stack:[%s]", err.Error(), debug.Stack())
+			return errors.Default.Wrap(err, "regexp Compile issueTypeBug failed")
 		}
 	}
 	var issueTypeRequirement = config.IssueTypeRequirement
 	if len(issueTypeRequirement) > 0 {
 		issueTypeRequirementRegex, err = regexp.Compile(issueTypeRequirement)
 		if err != nil {
-			return fmt.Errorf("regexp Compile issueTypeRequirement failed:[%s] stack:[%s]", err.Error(), debug.Stack())
+			return errors.Default.Wrap(err, "regexp Compile issueTypeRequirement failed")
 		}
 	}
 	var issueTypeIncident = config.IssueTypeIncident
 	if len(issueTypeIncident) > 0 {
 		issueTypeIncidentRegex, err = regexp.Compile(issueTypeIncident)
 		if err != nil {
-			return fmt.Errorf("regexp Compile issueTypeIncident failed:[%s] stack:[%s]", err.Error(), debug.Stack())
+			return errors.Default.Wrap(err, "regexp Compile issueTypeIncident failed")
 		}
 	}
 	extractor, err := helper.NewApiExtractor(helper.ApiExtractorArgs{
 		RawDataSubTaskArgs: *rawDataSubTaskArgs,
-		Extract: func(row *helper.RawData) ([]interface{}, error) {
+		Extract: func(row *helper.RawData) ([]interface{}, errors.Error) {
 			body := &IssuesResponse{}
-			err := json.Unmarshal(row.Data, body)
+			err := errors.Convert(json.Unmarshal(row.Data, body))
 			if err != nil {
 				return nil, err
 			}
@@ -272,13 +270,13 @@ func ExtractApiIssues(taskCtx core.SubTaskContext) error {
 	})
 
 	if err != nil {
-		return err
+		return errors.Convert(err)
 	}
 
 	return extractor.Execute()
 }
 
-func convertGitlabIssue(issue *IssuesResponse, projectId int) (*models.GitlabIssue, error) {
+func convertGitlabIssue(issue *IssuesResponse, projectId int) (*models.GitlabIssue, errors.Error) {
 	gitlabIssue := &models.GitlabIssue{
 		GitlabId:        issue.Id,
 		ProjectId:       projectId,
@@ -311,7 +309,7 @@ func convertGitlabIssue(issue *IssuesResponse, projectId int) (*models.GitlabIss
 	return gitlabIssue, nil
 }
 
-func convertGitlabAuthor(issue *IssuesResponse, connectionId uint64) (*models.GitlabAccount, error) {
+func convertGitlabAuthor(issue *IssuesResponse, connectionId uint64) (*models.GitlabAccount, errors.Error) {
 	gitlabAuthor := &models.GitlabAccount{
 		ConnectionId: connectionId,
 		GitlabId:     issue.Author.Id,
