@@ -19,13 +19,11 @@ package tasks
 
 import (
 	"encoding/json"
-	"fmt"
-	"regexp"
-	"runtime/debug"
-
+	"github.com/apache/incubator-devlake/errors"
 	"github.com/apache/incubator-devlake/plugins/core"
 	"github.com/apache/incubator-devlake/plugins/gitlab/models"
 	"github.com/apache/incubator-devlake/plugins/helper"
+	"regexp"
 )
 
 type MergeRequestRes struct {
@@ -76,7 +74,7 @@ var ExtractApiMergeRequestsMeta = core.SubTaskMeta{
 	DomainTypes:      []string{core.DOMAIN_TYPE_CODE_REVIEW},
 }
 
-func ExtractApiMergeRequests(taskCtx core.SubTaskContext) error {
+func ExtractApiMergeRequests(taskCtx core.SubTaskContext) errors.Error {
 	rawDataSubTaskArgs, data := CreateRawDataSubTaskArgs(taskCtx, RAW_MERGE_REQUEST_TABLE)
 	config := data.Options.TransformationRules
 	var labelTypeRegex *regexp.Regexp
@@ -86,21 +84,21 @@ func ExtractApiMergeRequests(taskCtx core.SubTaskContext) error {
 	if len(prType) > 0 {
 		labelTypeRegex, err = regexp.Compile(prType)
 		if err != nil {
-			return fmt.Errorf("regexp Compile prType failed:[%s] stack:[%s]", err.Error(), debug.Stack())
+			return errors.Default.Wrap(err, "regexp Compile prType failed")
 		}
 	}
 	var prComponent = config.PrComponent
 	if len(prComponent) > 0 {
 		labelComponentRegex, err = regexp.Compile(prComponent)
 		if err != nil {
-			return fmt.Errorf("regexp Compile prComponent failed:[%s] stack:[%s]", err.Error(), debug.Stack())
+			return errors.Default.Wrap(err, "regexp Compile prComponent failed")
 		}
 	}
 	extractor, err := helper.NewApiExtractor(helper.ApiExtractorArgs{
 		RawDataSubTaskArgs: *rawDataSubTaskArgs,
-		Extract: func(row *helper.RawData) ([]interface{}, error) {
+		Extract: func(row *helper.RawData) ([]interface{}, errors.Error) {
 			mr := &MergeRequestRes{}
-			err := json.Unmarshal(row.Data, mr)
+			err := errors.Convert(json.Unmarshal(row.Data, mr))
 			if err != nil {
 				return nil, err
 			}
@@ -154,13 +152,13 @@ func ExtractApiMergeRequests(taskCtx core.SubTaskContext) error {
 	})
 
 	if err != nil {
-		return err
+		return errors.Convert(err)
 	}
 
 	return extractor.Execute()
 }
 
-func convertMergeRequest(mr *MergeRequestRes) (*models.GitlabMergeRequest, error) {
+func convertMergeRequest(mr *MergeRequestRes) (*models.GitlabMergeRequest, errors.Error) {
 	gitlabMergeRequest := &models.GitlabMergeRequest{
 		GitlabId:         mr.GitlabId,
 		Iid:              mr.Iid,
