@@ -18,6 +18,8 @@ limitations under the License.
 package tasks
 
 import (
+	"github.com/apache/incubator-devlake/errors"
+	"github.com/apache/incubator-devlake/models/domainlayer/crossdomain"
 	"reflect"
 
 	"github.com/apache/incubator-devlake/plugins/core/dal"
@@ -35,16 +37,16 @@ var ConvertProjectMeta = core.SubTaskMeta{
 	Name:             "convertApiProject",
 	EntryPoint:       ConvertApiProjects,
 	EnabledByDefault: true,
-	Description:      "Update domain layer Repo according to GitlabProject",
+	Description:      "Add domain layer Repo according to GitlabProject",
 	DomainTypes:      []string{core.DOMAIN_TYPE_CODE, core.DOMAIN_TYPE_TICKET},
 }
 
-func ConvertApiProjects(taskCtx core.SubTaskContext) error {
+func ConvertApiProjects(taskCtx core.SubTaskContext) errors.Error {
 	rawDataSubTaskArgs, data := CreateRawDataSubTaskArgs(taskCtx, RAW_PROJECT_TABLE)
 	db := taskCtx.GetDal()
 	clauses := []dal.Clause{
 		dal.From(&models.GitlabProject{}),
-		dal.Where("gitlab_id=?", data.Options.ProjectId),
+		dal.Where("gitlab_id=? and connection_id = ?", data.Options.ProjectId, data.Options.ConnectionId),
 	}
 
 	cursor, err := db.Cursor(clauses...)
@@ -57,15 +59,16 @@ func ConvertApiProjects(taskCtx core.SubTaskContext) error {
 		InputRowType:       reflect.TypeOf(models.GitlabProject{}),
 		Input:              cursor,
 
-		Convert: func(inputRow interface{}) ([]interface{}, error) {
+		Convert: func(inputRow interface{}) ([]interface{}, errors.Error) {
 			gitlabProject := inputRow.(*models.GitlabProject)
 
 			domainRepository := convertToRepositoryModel(gitlabProject)
 			domainBoard := convertToBoardModel(gitlabProject)
-
+			domainBoardRepo := convertToBoardRepoModel(gitlabProject)
 			return []interface{}{
 				domainRepository,
 				domainBoard,
+				domainBoardRepo,
 			}, nil
 		},
 	})
@@ -103,3 +106,11 @@ func convertToBoardModel(project *models.GitlabProject) *ticket.Board {
 	}
 	return domainBoard
 }
+
+func convertToBoardRepoModel(project *models.GitlabProject) *crossdomain.BoardRepo {
+	domainBoardRepo := &crossdomain.BoardRepo{
+		BoardId: didgen.NewDomainIdGenerator(project).Generate(project.ConnectionId, project.GitlabId),
+		RepoId:  didgen.NewDomainIdGenerator(project).Generate(project.ConnectionId, project.GitlabId),
+	}
+	return domainBoardRepo
+}
