@@ -20,8 +20,9 @@ package tasks
 import (
 	"encoding/json"
 	"fmt"
+	"github.com/apache/incubator-devlake/errors"
 	"github.com/apache/incubator-devlake/plugins/core/dal"
-	"io/ioutil"
+	"io"
 	"net/http"
 	"net/url"
 	"reflect"
@@ -41,39 +42,39 @@ type GitlabInput struct {
 	Iid      int
 }
 
-func GetTotalPagesFromResponse(res *http.Response, args *helper.ApiCollectorArgs) (int, error) {
+func GetTotalPagesFromResponse(res *http.Response, args *helper.ApiCollectorArgs) (int, errors.Error) {
 	total := res.Header.Get("X-Total-Pages")
 	if total == "" {
 		return 0, nil
 	}
 	totalInt, err := strconv.Atoi(total)
 	if err != nil {
-		return 0, err
+		return 0, errors.Convert(err)
 	}
 	return totalInt, nil
 }
 
-func GetRawMessageFromResponse(res *http.Response) ([]json.RawMessage, error) {
+func GetRawMessageFromResponse(res *http.Response) ([]json.RawMessage, errors.Error) {
 	rawMessages := []json.RawMessage{}
 
 	if res == nil {
-		return nil, fmt.Errorf("res is nil")
+		return nil, errors.Default.New("res is nil")
 	}
 	defer res.Body.Close()
-	resBody, err := ioutil.ReadAll(res.Body)
+	resBody, err := io.ReadAll(res.Body)
 	if err != nil {
-		return nil, fmt.Errorf("%w %s", err, res.Request.URL.String())
+		return nil, errors.Default.Wrap(err, fmt.Sprintf("error reading response from %s", res.Request.URL.String()))
 	}
 
-	err = json.Unmarshal(resBody, &rawMessages)
+	err = errors.Convert(json.Unmarshal(resBody, &rawMessages))
 	if err != nil {
-		return nil, fmt.Errorf("%w %s %s", err, res.Request.URL.String(), string(resBody))
+		return nil, errors.Default.Wrap(err, fmt.Sprintf("error decoding response from %s. raw response was: %s", res.Request.URL.String(), string(resBody)))
 	}
 
 	return rawMessages, nil
 }
 
-func GetQuery(reqData *helper.RequestData) (url.Values, error) {
+func GetQuery(reqData *helper.RequestData) (url.Values, errors.Error) {
 	query := url.Values{}
 	query.Set("with_stats", "true")
 	query.Set("sort", "asc")
@@ -95,7 +96,7 @@ func CreateRawDataSubTaskArgs(taskCtx core.SubTaskContext, Table string) (*helpe
 	return RawDataSubTaskArgs, data
 }
 
-func GetMergeRequestsIterator(taskCtx core.SubTaskContext) (*helper.DalCursorIterator, error) {
+func GetMergeRequestsIterator(taskCtx core.SubTaskContext) (*helper.DalCursorIterator, errors.Error) {
 	db := taskCtx.GetDal()
 	data := taskCtx.GetData().(*GitlabTaskData)
 	clauses := []dal.Clause{
