@@ -18,6 +18,7 @@ limitations under the License.
 package helper
 
 import (
+	"github.com/apache/incubator-devlake/errors"
 	"reflect"
 
 	"github.com/apache/incubator-devlake/models/common"
@@ -30,7 +31,7 @@ import (
 type ApiExtractorArgs struct {
 	RawDataSubTaskArgs
 	Params    interface{}
-	Extract   func(row *RawData) ([]interface{}, error)
+	Extract   func(row *RawData) ([]interface{}, errors.Error)
 	BatchSize int
 }
 
@@ -45,7 +46,7 @@ type ApiExtractor struct {
 }
 
 // NewApiExtractor creates a new ApiExtractor
-func NewApiExtractor(args ApiExtractorArgs) (*ApiExtractor, error) {
+func NewApiExtractor(args ApiExtractorArgs) (*ApiExtractor, errors.Error) {
 	// process args
 	rawDataSubTask, err := newRawDataSubTask(args.RawDataSubTaskArgs)
 	if err != nil {
@@ -61,7 +62,7 @@ func NewApiExtractor(args ApiExtractorArgs) (*ApiExtractor, error) {
 }
 
 // Execute sub-task
-func (extractor *ApiExtractor) Execute() error {
+func (extractor *ApiExtractor) Execute() errors.Error {
 	// load data from database
 	db := extractor.args.Ctx.GetDal()
 	log := extractor.args.Ctx.GetLogger()
@@ -74,11 +75,11 @@ func (extractor *ApiExtractor) Execute() error {
 
 	count, err := db.Count(clauses...)
 	if err != nil {
-		return err
+		return errors.Default.Wrap(err, "error getting count of clauses")
 	}
 	cursor, err := db.Cursor(clauses...)
 	if err != nil {
-		return err
+		return errors.Default.Wrap(err, "error running DB query")
 	}
 	log.Info("get data from %s where params=%s and got %d", extractor.table, extractor.params, count)
 	defer cursor.Close()
@@ -95,24 +96,24 @@ func (extractor *ApiExtractor) Execute() error {
 	for cursor.Next() {
 		select {
 		case <-ctx.Done():
-			return ctx.Err()
+			return errors.Convert(ctx.Err())
 		default:
 		}
 		err = db.Fetch(cursor, row)
 		if err != nil {
-			return err
+			return errors.Default.Wrap(err, "error fetching row")
 		}
 
 		results, err := extractor.args.Extract(row)
 		if err != nil {
-			return err
+			return errors.Default.Wrap(err, "error calling plugin Extract implementation")
 		}
 
 		for _, result := range results {
 			// get the batch operator for the specific type
 			batch, err := divider.ForType(reflect.TypeOf(result))
 			if err != nil {
-				return err
+				return errors.Default.Wrap(err, "error getting batch from result")
 			}
 			// set raw data origin field
 			origin := reflect.ValueOf(result).Elem().FieldByName(RAW_DATA_ORIGIN)
@@ -126,7 +127,7 @@ func (extractor *ApiExtractor) Execute() error {
 			// records get saved into db when slots were max outed
 			err = batch.Add(result)
 			if err != nil {
-				return err
+				return errors.Default.Wrap(err, "error adding result to batch")
 			}
 			extractor.args.Ctx.IncProgress(1)
 		}
