@@ -20,6 +20,7 @@ package helper
 import (
 	"encoding/json"
 	"fmt"
+	"github.com/apache/incubator-devlake/errors"
 	"time"
 
 	"github.com/apache/incubator-devlake/plugins/core"
@@ -55,21 +56,21 @@ type RawDataSubTask struct {
 	params string
 }
 
-func newRawDataSubTask(args RawDataSubTaskArgs) (*RawDataSubTask, error) {
+func newRawDataSubTask(args RawDataSubTaskArgs) (*RawDataSubTask, errors.Error) {
 	if args.Ctx == nil {
-		return nil, fmt.Errorf("Ctx is required for RawDataSubTask")
+		return nil, errors.Default.New("Ctx is required for RawDataSubTask")
 	}
 	if args.Table == "" {
-		return nil, fmt.Errorf("Table is required for RawDataSubTask")
+		return nil, errors.Default.New("Table is required for RawDataSubTask")
 	}
 	paramsString := ""
 	if args.Params == nil {
-		args.Ctx.GetLogger().Warn("Missing `Params` for raw data subtask %s", args.Ctx.GetName())
+		args.Ctx.GetLogger().Warn(nil, "Missing `Params` for raw data subtask %s", args.Ctx.GetName())
 	} else {
-		// TODO: maybe sort it to make it consisitence
+		// TODO: maybe sort it to make it consistent
 		paramsBytes, err := json.Marshal(args.Params)
 		if err != nil {
-			return nil, err
+			return nil, errors.Default.Wrap(err, "unable to serialize subtask parameters")
 		}
 		paramsString = string(paramsBytes)
 	}
