@@ -20,6 +20,7 @@ package helper
 import (
 	"context"
 	"fmt"
+	"github.com/apache/incubator-devlake/errors"
 	"sync"
 	"sync/atomic"
 	"time"
@@ -228,7 +229,7 @@ func NewDefaultTaskContext(
 }
 
 // SubTaskContext FIXME ...
-func (c *DefaultTaskContext) SubTaskContext(subtask string) (core.SubTaskContext, error) {
+func (c *DefaultTaskContext) SubTaskContext(subtask string) (core.SubTaskContext, errors.Error) {
 	// no need to lock at this point because subtasks is written only once
 	if run, ok := c.subtasks[subtask]; ok {
 		if run {
@@ -248,7 +249,7 @@ func (c *DefaultTaskContext) SubTaskContext(subtask string) (core.SubTaskContext
 		return nil, nil
 	}
 	// invalid subtask name
-	return nil, fmt.Errorf("subtask %s doesn't exist", subtask)
+	return nil, errors.Default.New(fmt.Sprintf("subtask %s doesn't exist", subtask))
 }
 
 // NewStandaloneSubTaskContext returns a stand-alone core.SubTaskContext,
