@@ -19,6 +19,7 @@ package impl
 
 import (
 	"fmt"
+	"github.com/apache/incubator-devlake/errors"
 
 	"github.com/apache/incubator-devlake/migration"
 	"github.com/apache/incubator-devlake/plugins/core"
@@ -40,7 +41,7 @@ var _ core.CloseablePluginTask = (*Jenkins)(nil)
 
 type Jenkins struct{}
 
-func (plugin Jenkins) Init(config *viper.Viper, logger core.Logger, db *gorm.DB) error {
+func (plugin Jenkins) Init(config *viper.Viper, logger core.Logger, db *gorm.DB) errors.Error {
 	api.Init(config, logger, db)
 	return nil
 }
@@ -48,7 +49,7 @@ func (plugin Jenkins) Init(config *viper.Viper, logger core.Logger, db *gorm.DB)
 func (plugin Jenkins) GetTablesInfo() []core.Tabler {
 	return []core.Tabler{
 		&models.JenkinsBuild{},
-		&models.JenkinsBuildRepo{},
+		&models.JenkinsBuildCommit{},
 		&models.JenkinsConnection{},
 		&models.JenkinsJob{},
 		&models.JenkinsJobDag{},
@@ -71,22 +72,19 @@ func (plugin Jenkins) SubTaskMetas() []core.SubTaskMeta {
 		tasks.ExtractApiBuildsMeta,
 		tasks.CollectApiStagesMeta,
 		tasks.ExtractApiStagesMeta,
-		tasks.EnrichApiBuildOriginTriggerMeta,
 		tasks.EnrichApiBuildWithStagesMeta,
 		tasks.ConvertBuildsToCICDMeta,
 		tasks.ConvertStagesMeta,
 		tasks.ConvertBuildReposMeta,
-		tasks.ConvertJobsMeta,
-		tasks.ConvertBuildsMeta,
 	}
 }
-func (plugin Jenkins) PrepareTaskData(taskCtx core.TaskContext, options map[string]interface{}) (interface{}, error) {
+func (plugin Jenkins) PrepareTaskData(taskCtx core.TaskContext, options map[string]interface{}) (interface{}, errors.Error) {
 	op, err := tasks.DecodeAndValidateTaskOptions(options)
 	if err != nil {
 		return nil, err
 	}
 	if op.ConnectionId == 0 {
-		return nil, fmt.Errorf("connectionId is invalid")
+		return nil, errors.BadInput.New("connectionId is invalid")
 	}
 
 	connection := &models.JenkinsConnection{}
@@ -121,7 +119,7 @@ func (plugin Jenkins) MigrationScripts() []migration.Script {
 	return migrationscripts.All()
 }
 
-func (plugin Jenkins) MakePipelinePlan(connectionId uint64, scope []*core.BlueprintScopeV100) (core.PipelinePlan, error) {
+func (plugin Jenkins) MakePipelinePlan(connectionId uint64, scope []*core.BlueprintScopeV100) (core.PipelinePlan, errors.Error) {
 	return api.MakePipelinePlan(plugin.SubTaskMetas(), connectionId, scope)
 }
 
@@ -142,10 +140,10 @@ func (plugin Jenkins) ApiResources() map[string]map[string]core.ApiResourceHandl
 	}
 }
 
-func (plugin Jenkins) Close(taskCtx core.TaskContext) error {
+func (plugin Jenkins) Close(taskCtx core.TaskContext) errors.Error {
 	data, ok := taskCtx.GetData().(*tasks.JenkinsTaskData)
 	if !ok {
-		return fmt.Errorf("GetData failed when try to close %+v", taskCtx)
+		return errors.Default.New(fmt.Sprintf("GetData failed when try to close %+v", taskCtx))
 	}
 	data.ApiClient.Release()
 	return nil
