@@ -28,9 +28,12 @@ var PluginEntry impl.Jenkins
 func main() {
 	jenkinsCmd := &cobra.Command{Use: "jenkins"}
 	connectionId := jenkinsCmd.Flags().Uint64P("connection", "c", 1, "jenkins connection id")
+	deployTagPattern := jenkinsCmd.Flags().String("deployTagPattern", "(?i)deploy", "deploy tag name")
+
 	jenkinsCmd.Run = func(cmd *cobra.Command, args []string) {
 		runner.DirectRun(cmd, args, PluginEntry, map[string]interface{}{
-			"connectionId": *connectionId,
+			"connectionId":     *connectionId,
+			"deployTagPattern": *deployTagPattern,
 		})
 	}
 	runner.RunCmd(jenkinsCmd)
