@@ -5,7 +5,9 @@ this work for additional information regarding copyright ownership.
 The ASF licenses this file to You under the Apache License, Version 2.0
 (the "License"); you may not use this file except in compliance with
 the License.  You may obtain a copy of the License at
+
     http://www.apache.org/licenses/LICENSE-2.0
+
 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -18,13 +20,13 @@ package migrationscripts
 import (
 	"context"
 
-	"github.com/apache/incubator-devlake/models/common"
-	"github.com/apache/incubator-devlake/plugins/jira/models/migrationscripts/archived"
+	"github.com/apache/incubator-devlake/errors"
+	"github.com/apache/incubator-devlake/models/migrationscripts/archived"
 	"gorm.io/gorm"
 )
 
 type JiraConnectionV010 struct {
-	common.Model
+	archived.Model
 	Name                       string `gorm:"type:varchar(100);uniqueIndex" json:"name" validate:"required"`
 	Endpoint                   string `json:"endpoint" validate:"required"`
 	BasicAuthEncoded           string `json:"basicAuthEncoded" validate:"required"`
@@ -39,14 +41,27 @@ func (JiraConnectionV010) TableName() string {
 	return "_tool_jira_connections"
 }
 
+type JiraSource struct {
+	archived.Model
+	Name                       string `gorm:"type:varchar(100);uniqueIndex" json:"name" validate:"required"`
+	Endpoint                   string `json:"endpoint" validate:"required"`
+	BasicAuthEncoded           string `json:"basicAuthEncoded" validate:"required"`
+	EpicKeyField               string `gorm:"type:varchar(50);" json:"epicKeyField"`
+	StoryPointField            string `gorm:"type:varchar(50);" json:"storyPointField"`
+	RemotelinkCommitShaPattern string `gorm:"type:varchar(255);comment='golang regexp, the first group will be recognized as commit sha, ref https://github.com/google/re2/wiki/Syntax'" json:"remotelinkCommitShaPattern"`
+	Proxy                      string `json:"proxy"`
+	RateLimit                  int    `comment:"api request rate limt per second"`
+}
+
+func (JiraSource) TableName() string {
+	return "_tool_jira_sources"
+}
+
 type renameSourceTable struct{}
 
-func (*renameSourceTable) Up(ctx context.Context, db *gorm.DB) error {
-	err := db.Migrator().RenameTable(archived.JiraSource{}, JiraConnectionV010{})
-	if err != nil {
-		return err
-	}
-	return nil
+func (*renameSourceTable) Up(ctx context.Context, db *gorm.DB) errors.Error {
+	err := db.Migrator().RenameTable(JiraSource{}, JiraConnectionV010{})
+	return errors.Convert(err)
 }
 
 func (*renameSourceTable) Version() uint64 {
