@@ -25,7 +25,7 @@ import (
 
 type JiraWorklog struct {
 	archived.NoPKModel
-	SourceId         uint64 `gorm:"primaryKey"`
+	ConnectionId     uint64 `gorm:"primaryKey"`
 	IssueId          uint64 `gorm:"primarykey"`
 	WorklogId        string `gorm:"primarykey;type:varchar(255)"`
 	AuthorId         string `gorm:"type:varchar(255)"`
@@ -34,6 +34,7 @@ type JiraWorklog struct {
 	TimeSpentSeconds int
 	Updated          time.Time
 	Started          time.Time
+	IssueUpdated     *time.Time
 }
 
 func (JiraWorklog) TableName() string {
