@@ -19,6 +19,7 @@ package tasks
 
 import (
 	"encoding/json"
+	"github.com/apache/incubator-devlake/errors"
 	"net/http"
 	"net/url"
 	"reflect"
@@ -39,7 +40,7 @@ var CollectAccountsMeta = core.SubTaskMeta{
 	DomainTypes:      []string{core.DOMAIN_TYPE_CROSS},
 }
 
-func CollectAccounts(taskCtx core.SubTaskContext) error {
+func CollectAccounts(taskCtx core.SubTaskContext) errors.Error {
 	data := taskCtx.GetData().(*JiraTaskData)
 	db := taskCtx.GetDal()
 	logger := taskCtx.GetLogger()
@@ -59,8 +60,7 @@ func CollectAccounts(taskCtx core.SubTaskContext) error {
 	queryKey := "accountId"
 	urlTemplate := "api/2/user"
 	if data.JiraServerInfo.DeploymentType == models.DeploymentServer {
-		queryKey = "username"
-		urlTemplate = "api/2/user/search"
+		queryKey = "key"
 	}
 
 	collector, err := helper.NewApiCollector(helper.ApiCollectorArgs{
@@ -75,33 +75,24 @@ func CollectAccounts(taskCtx core.SubTaskContext) error {
 		ApiClient:   data.ApiClient,
 		Input:       iterator,
 		UrlTemplate: urlTemplate,
-		Query: func(reqData *helper.RequestData) (url.Values, error) {
+		Query: func(reqData *helper.RequestData) (url.Values, errors.Error) {
 			user := reqData.Input.(*models.JiraAccount)
 			query := url.Values{}
 			query.Set(queryKey, user.AccountId)
 			return query, nil
 		},
-		ResponseParser: func(res *http.Response) ([]json.RawMessage, error) {
-			if data.JiraServerInfo.DeploymentType == models.DeploymentServer {
-				var results []json.RawMessage
-				err := helper.UnmarshalResponse(res, &results)
-				if err != nil {
-					return nil, err
-				}
-
-				return results, nil
-			} else {
-				var result json.RawMessage
-				err := helper.UnmarshalResponse(res, &result)
-				if err != nil {
-					return nil, err
-				}
-				return []json.RawMessage{result}, nil
+		ResponseParser: func(res *http.Response) ([]json.RawMessage, errors.Error) {
+			var result json.RawMessage
+			err := helper.UnmarshalResponse(res, &result)
+			if err != nil {
+				return nil, err
 			}
+			return []json.RawMessage{result}, nil
 		},
+		AfterResponse: ignoreHTTPStatus404,
 	})
 	if err != nil {
-		logger.Error("collect account error:", err)
+		logger.Error(err, "collect account error")
 		return err
 	}
 
