@@ -19,15 +19,13 @@ package tasks
 
 import (
 	"encoding/json"
-	"fmt"
-	"regexp"
-	"runtime/debug"
-
+	"github.com/apache/incubator-devlake/errors"
 	"github.com/apache/incubator-devlake/plugins/core"
 	"github.com/apache/incubator-devlake/plugins/core/dal"
 	"github.com/apache/incubator-devlake/plugins/helper"
 	"github.com/apache/incubator-devlake/plugins/jira/models"
 	"github.com/apache/incubator-devlake/plugins/jira/tasks/apiv2models"
+	"regexp"
 )
 
 var ExtractRemotelinksMeta = core.SubTaskMeta{
@@ -38,7 +36,7 @@ var ExtractRemotelinksMeta = core.SubTaskMeta{
 	DomainTypes:      []string{core.DOMAIN_TYPE_TICKET},
 }
 
-func ExtractRemotelinks(taskCtx core.SubTaskContext) error {
+func ExtractRemotelinks(taskCtx core.SubTaskContext) errors.Error {
 	data := taskCtx.GetData().(*JiraTaskData)
 	connectionId := data.Options.ConnectionId
 	boardId := data.Options.BoardId
@@ -50,7 +48,7 @@ func ExtractRemotelinks(taskCtx core.SubTaskContext) error {
 	if pattern := data.Options.TransformationRules.RemotelinkCommitShaPattern; pattern != "" {
 		commitShaRegex, err = regexp.Compile(pattern)
 		if err != nil {
-			return fmt.Errorf("regexp Compile pattern failed:[%s] stack:[%s]", err.Error(), debug.Stack())
+			return errors.Default.Wrap(err, "regexp Compile pattern failed")
 		}
 	}
 
@@ -63,7 +61,7 @@ func ExtractRemotelinks(taskCtx core.SubTaskContext) error {
 	}
 	cursor, err := db.Cursor(clauses...)
 	if err != nil {
-		return err
+		return errors.Convert(err)
 	}
 	defer cursor.Close()
 
@@ -76,15 +74,15 @@ func ExtractRemotelinks(taskCtx core.SubTaskContext) error {
 			},
 			Table: RAW_REMOTELINK_TABLE,
 		},
-		Extract: func(row *helper.RawData) ([]interface{}, error) {
+		Extract: func(row *helper.RawData) ([]interface{}, errors.Error) {
 			var result []interface{}
 			var raw apiv2models.RemoteLink
-			err := json.Unmarshal(row.Data, &raw)
+			err := errors.Convert(json.Unmarshal(row.Data, &raw))
 			if err != nil {
 				return nil, err
 			}
 			var input apiv2models.Input
-			err = json.Unmarshal(row.Input, &input)
+			err = errors.Convert(json.Unmarshal(row.Input, &input))
 			if err != nil {
 				return nil, err
 			}
@@ -114,7 +112,7 @@ func ExtractRemotelinks(taskCtx core.SubTaskContext) error {
 		},
 	})
 	if err != nil {
-		return err
+		return errors.Convert(err)
 	}
 
 	return extractor.Execute()
