@@ -18,6 +18,7 @@ limitations under the License.
 package api
 
 import (
+	"github.com/apache/incubator-devlake/errors"
 	"github.com/apache/incubator-devlake/plugins/core"
 	"net/http"
 
@@ -35,11 +36,11 @@ import (
 // @Failure 400  {object} shared.ApiBody "Bad Request"
 // @Failure 500  {object} shared.ApiBody "Internal Error"
 // @Router       /plugins/org/teams.csv [get]
-func (h *Handlers) GetTeam(input *core.ApiResourceInput) (*core.ApiResourceOutput, error) {
+func (h *Handlers) GetTeam(input *core.ApiResourceInput) (*core.ApiResourceOutput, errors.Error) {
 	input.Query.Get("fake_data")
 	var teams []team
 	var t *team
-	var err error
+	var err errors.Error
 	if input.Query.Get("fake_data") == "true" {
 		teams = t.fakeData()
 	} else {
@@ -48,7 +49,7 @@ func (h *Handlers) GetTeam(input *core.ApiResourceInput) (*core.ApiResourceOutpu
 			return nil, err
 		}
 	}
-	blob, err := gocsv.MarshalBytes(teams)
+	blob, err := errors.Convert01(gocsv.MarshalBytes(teams))
 	if err != nil {
 		return nil, err
 	}
@@ -73,7 +74,7 @@ func (h *Handlers) GetTeam(input *core.ApiResourceInput) (*core.ApiResourceOutpu
 // @Failure 400  {object} shared.ApiBody "Bad Request"
 // @Failure 500  {object} shared.ApiBody "Internal Error"
 // @Router       /plugins/org/teams.csv [put]
-func (h *Handlers) CreateTeam(input *core.ApiResourceInput) (*core.ApiResourceOutput, error) {
+func (h *Handlers) CreateTeam(input *core.ApiResourceInput) (*core.ApiResourceOutput, errors.Error) {
 	var tt []team
 	err := h.unmarshal(input.Request, &tt)
 	if err != nil {
