@@ -19,6 +19,7 @@ package tasks
 
 import (
 	"fmt"
+	"github.com/apache/incubator-devlake/errors"
 	"reflect"
 
 	"github.com/apache/incubator-devlake/models/domainlayer/code"
@@ -27,7 +28,7 @@ import (
 	"github.com/apache/incubator-devlake/plugins/refdiff/utils"
 )
 
-func CalculateCommitsDiff(taskCtx core.SubTaskContext) error {
+func CalculateCommitsDiff(taskCtx core.SubTaskContext) errors.Error {
 	data := taskCtx.GetData().(*RefdiffTaskData)
 	repoId := data.Options.RepoId
 	db := taskCtx.GetDal()
@@ -55,12 +56,12 @@ func CalculateCommitsDiff(taskCtx core.SubTaskContext) error {
 	for cursor.Next() {
 		select {
 		case <-ctx.Done():
-			return ctx.Err()
+			return errors.Convert(ctx.Err())
 		default:
 		}
 		err = db.Fetch(cursor, commitParent)
 		if err != nil {
-			return fmt.Errorf("failed to read commit from database: %v", err)
+			return errors.Default.Wrap(err, "failed to read commit from database")
 		}
 		commitNodeGraph.AddParent(commitParent.CommitSha, commitParent.ParentCommitSha)
 	}
@@ -75,7 +76,7 @@ func CalculateCommitsDiff(taskCtx core.SubTaskContext) error {
 	for _, pair := range commitPairs {
 		select {
 		case <-ctx.Done():
-			return ctx.Err()
+			return errors.Convert(ctx.Err())
 		default:
 		}
 		// ref might advance, keep commit sha for debugging
