@@ -6,7 +6,7 @@ The ASF licenses this file to You under the Apache License, Version 2.0
 (the "License"); you may not use this file except in compliance with
 the License.  You may obtain a copy of the License at
 
-	http://www.apache.org/licenses/LICENSE-2.0
+    http://www.apache.org/licenses/LICENSE-2.0
 
 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
@@ -14,12 +14,14 @@ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 */
+
 package main
 
 import (
+	"github.com/apache/incubator-devlake/errors"
 	"github.com/apache/incubator-devlake/plugins/core"
+	"github.com/apache/incubator-devlake/plugins/helper"
 	"github.com/apache/incubator-devlake/runner"
-	"github.com/mitchellh/mapstructure"
 	"github.com/spf13/cobra"
 )
 
@@ -31,9 +33,9 @@ func (s StarRocks) SubTaskMetas() []core.SubTaskMeta {
 	}
 }
 
-func (s StarRocks) PrepareTaskData(taskCtx core.TaskContext, options map[string]interface{}) (interface{}, error) {
+func (s StarRocks) PrepareTaskData(taskCtx core.TaskContext, options map[string]interface{}) (interface{}, errors.Error) {
 	var op StarRocksConfig
-	err := mapstructure.Decode(options, &op)
+	err := helper.Decode(options, &op, nil)
 	if err != nil {
 		return nil, err
 	}
@@ -43,7 +45,7 @@ func (s StarRocks) PrepareTaskData(taskCtx core.TaskContext, options map[string]
 	return &op, nil
 }
 
-func (plugin StarRocks) GetTablesInfo() []core.Tabler {
+func (s StarRocks) GetTablesInfo() []core.Tabler {
 	return []core.Tabler{}
 }
 
@@ -59,6 +61,8 @@ var PluginEntry StarRocks
 
 func main() {
 	cmd := &cobra.Command{Use: "StarRocks"}
+	sourceType := cmd.Flags().StringP("source_type", "st", "", "Source type")
+	sourceDsn := cmd.Flags().StringP("source_dsn", "sd", "", "Source dsn")
 	_ = cmd.MarkFlagRequired("host")
 	host := cmd.Flags().StringP("host", "h", "", "StarRocks host")
 	_ = cmd.MarkFlagRequired("port")
@@ -80,16 +84,18 @@ func main() {
 	extra := cmd.Flags().StringP("extra", "e", "", "StarRocks create table sql extra")
 	cmd.Run = func(cmd *cobra.Command, args []string) {
 		runner.DirectRun(cmd, args, PluginEntry, map[string]interface{}{
-			"host":       host,
-			"port":       port,
-			"user":       user,
-			"password":   password,
-			"database":   database,
-			"be_host":    beHost,
-			"be_port":    bePort,
-			"tables":     tables,
-			"batch_size": batchSize,
-			"extra":      extra,
+			"source_type": sourceType,
+			"source_dsn":  sourceDsn,
+			"host":        host,
+			"port":        port,
+			"user":        user,
+			"password":    password,
+			"database":    database,
+			"be_host":     beHost,
+			"be_port":     bePort,
+			"tables":      tables,
+			"batch_size":  batchSize,
+			"extra":       extra,
 		})
 	}
 	runner.RunCmd(cmd)
