@@ -6,7 +6,7 @@ The ASF licenses this file to You under the Apache License, Version 2.0
 (the "License"); you may not use this file except in compliance with
 the License.  You may obtain a copy of the License at
 
-	http://www.apache.org/licenses/LICENSE-2.0
+    http://www.apache.org/licenses/LICENSE-2.0
 
 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
@@ -14,6 +14,7 @@ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 */
+
 package main
 
 import (
@@ -21,14 +22,19 @@ import (
 	"database/sql"
 	"encoding/json"
 	"fmt"
+	"github.com/apache/incubator-devlake/errors"
+	"github.com/apache/incubator-devlake/impl/dalgorm"
+	"github.com/apache/incubator-devlake/plugins/core"
+	"github.com/apache/incubator-devlake/plugins/core/dal"
+	"github.com/lib/pq"
+	"gorm.io/driver/mysql"
+	"gorm.io/driver/postgres"
+	"gorm.io/gorm"
 	"io"
 	"net/http"
 	"net/url"
 	"regexp"
 	"strings"
-
-	"github.com/apache/incubator-devlake/plugins/core"
-	"github.com/apache/incubator-devlake/plugins/core/dal"
 )
 
 type Table struct {
@@ -39,14 +45,34 @@ func (t *Table) TableName() string {
 	return t.name
 }
 
-func LoadData(c core.SubTaskContext) error {
+func LoadData(c core.SubTaskContext) errors.Error {
+	var db dal.Dal
 	config := c.GetData().(*StarRocksConfig)
-	db := c.GetDal()
+	if config.SourceDsn != "" && config.SourceType != "" {
+		var o *gorm.DB
+		var err error
+		if config.SourceType == "mysql" {
+			o, err = gorm.Open(mysql.Open(config.SourceDsn))
+			if err != nil {
+				return errors.Convert(err)
+			}
+		} else if config.SourceType == "postgres" {
+			o, err = gorm.Open(postgres.Open(config.SourceDsn))
+			if err != nil {
+				return errors.Convert(err)
+			}
+		} else {
+			return errors.NotFound.New(fmt.Sprintf("unsupported source type %s", config.SourceType))
+		}
+		db = dalgorm.NewDalgorm(o)
+	} else {
+		db = c.GetDal()
+	}
 	var starrocksTables []string
 	if config.DomainLayer != "" {
 		starrocksTables = getTablesByDomainLayer(config.DomainLayer)
 		if starrocksTables == nil {
-			return fmt.Errorf("no table found by domain layer: %s", config.DomainLayer)
+			return errors.NotFound.New(fmt.Sprintf("no table found by domain layer: %s", config.DomainLayer))
 		}
 	} else {
 		tables := config.Tables
@@ -60,7 +86,7 @@ func LoadData(c core.SubTaskContext) error {
 			for _, table := range allTables {
 				for _, r := range tables {
 					var ok bool
-					ok, err = regexp.Match(r, []byte(table))
+					ok, err = errors.Convert01(regexp.Match(r, []byte(table)))
 					if err != nil {
 						return err
 					}
@@ -74,28 +100,30 @@ func LoadData(c core.SubTaskContext) error {
 
 	starrocks, err := sql.Open("mysql", fmt.Sprintf("%s:%s@tcp(%s:%d)/%s?charset=utf8mb4&parseTime=True&loc=Local", config.User, config.Password, config.Host, config.Port, config.Database))
 	if err != nil {
-		return err
+		return errors.Convert(err)
 	}
 
 	for _, table := range starrocksTables {
 		starrocksTable := strings.TrimLeft(table, "_")
-		err = createTable(starrocks, db, starrocksTable, table, c, config.Extra)
+		var columnMap map[string]string
+		columnMap, err = createTable(starrocks, db, starrocksTable, table, c, config.Extra)
 		if err != nil {
-			c.GetLogger().Error("create table %s in starrocks error: %s", table, err)
-			return err
+			c.GetLogger().Error(err, "create table %s in starrocks error", table)
+			return errors.Convert(err)
 		}
-		err = loadData(starrocks, c, starrocksTable, table, db, config)
+		err = loadData(starrocks, c, starrocksTable, table, columnMap, db, config)
 		if err != nil {
-			c.GetLogger().Error("load data %s error: %s", table, err)
-			return err
+			c.GetLogger().Error(err, "load data %s error", table)
+			return errors.Convert(err)
 		}
 	}
 	return nil
 }
-func createTable(starrocks *sql.DB, db dal.Dal, starrocksTable string, table string, c core.SubTaskContext, extra string) error {
+func createTable(starrocks *sql.DB, db dal.Dal, starrocksTable string, table string, c core.SubTaskContext, extra string) (map[string]string, errors.Error) {
 	columeMetas, err := db.GetColumns(&Table{name: table}, nil)
+	columnMap := make(map[string]string)
 	if err != nil {
-		return err
+		return columnMap, err
 	}
 	var pks []string
 	var columns []string
@@ -104,9 +132,11 @@ func createTable(starrocks *sql.DB, db dal.Dal, starrocksTable string, table str
 		name := cm.Name()
 		starrocksDatatype, ok := cm.ColumnType()
 		if !ok {
-			return fmt.Errorf("Get [%s] ColumeType Failed", name)
+			return columnMap, errors.Default.New(fmt.Sprintf("Get [%s] ColumeType Failed", name))
 		}
-		column := fmt.Sprintf("`%s` %s", name, getDataType(starrocksDatatype))
+		dataType := getDataType(starrocksDatatype)
+		columnMap[name] = dataType
+		column := fmt.Sprintf("`%s` %s", name, dataType)
 		columns = append(columns, column)
 		isPrimaryKey, ok := cm.PrimaryKey()
 		if isPrimaryKey && ok {
@@ -126,11 +156,11 @@ func createTable(starrocks *sql.DB, db dal.Dal, starrocksTable string, table str
 	}
 	tableSql := fmt.Sprintf("create table if not exists `%s` ( %s ) %s", starrocksTable, strings.Join(columns, ","), extra)
 	c.GetLogger().Info(tableSql)
-	_, err = starrocks.Exec(tableSql)
-	return err
+	_, err = errors.Convert01(starrocks.Exec(tableSql))
+	return columnMap, err
 }
 
-func loadData(starrocks *sql.DB, c core.SubTaskContext, starrocksTable string, table string, db dal.Dal, config *StarRocksConfig) error {
+func loadData(starrocks *sql.DB, c core.SubTaskContext, starrocksTable string, table string, columnMap map[string]string, db dal.Dal, config *StarRocksConfig) error {
 	offset := 0
 	starrocksTmpTable := starrocksTable + "_tmp"
 	// create tmp table in starrocks
@@ -138,10 +168,12 @@ func loadData(starrocks *sql.DB, c core.SubTaskContext, starrocksTable string, t
 	if execErr != nil {
 		return execErr
 	}
+	var err error
 	for {
+		var rows *sql.Rows
 		var data []map[string]interface{}
 		// select data from db
-		rows, err := db.RawCursor(fmt.Sprintf("select * from %s limit %d offset %d", table, config.BatchSize, offset))
+		rows, err = db.RawCursor(fmt.Sprintf("select * from %s limit %d offset %d", table, config.BatchSize, offset))
 		if err != nil {
 			return err
 		}
@@ -154,7 +186,14 @@ func loadData(starrocks *sql.DB, c core.SubTaskContext, starrocksTable string, t
 			columns := make([]interface{}, len(cols))
 			columnPointers := make([]interface{}, len(cols))
 			for i := range columns {
-				columnPointers[i] = &columns[i]
+				dataType := columnMap[cols[i]]
+				if strings.HasPrefix(dataType, "array") {
+					var arr []string
+					columns[i] = &arr
+					columnPointers[i] = pq.Array(&arr)
+				} else {
+					columnPointers[i] = &columns[i]
+				}
 			}
 			err = rows.Scan(columnPointers...)
 			if err != nil {
@@ -166,7 +205,7 @@ func loadData(starrocks *sql.DB, c core.SubTaskContext, starrocksTable string, t
 			data = append(data, row)
 		}
 		if len(data) == 0 {
-			c.GetLogger().Warn("no data found in table %s already, limit: %d, offset: %d, so break", table, config.BatchSize, offset)
+			c.GetLogger().Warn(nil, "no data found in table %s already, limit: %d, offset: %d, so break", table, config.BatchSize, offset)
 			break
 		}
 		// insert data to tmp table
@@ -202,6 +241,9 @@ func loadData(starrocks *sql.DB, c core.SubTaskContext, starrocksTable string, t
 		if resp.StatusCode == 307 {
 			var location *url.URL
 			location, err = resp.Location()
+			if err != nil {
+				return err
+			}
 			req, err = http.NewRequest(http.MethodPut, location.String(), bytes.NewBuffer(jsonData))
 			if err != nil {
 				return err
@@ -225,17 +267,17 @@ func loadData(starrocks *sql.DB, c core.SubTaskContext, starrocksTable string, t
 			return err
 		}
 		if resp.StatusCode != http.StatusOK {
-			c.GetLogger().Error("%s %s", resp.StatusCode, b)
+			c.GetLogger().Error(nil, "[%s]: %s", resp.StatusCode, string(b))
 		}
 		if result["Status"] != "Success" {
-			c.GetLogger().Error("load %s failed: %s", table, b)
+			c.GetLogger().Error(nil, "load %s failed: %s", table, string(b))
 		} else {
 			c.GetLogger().Info("load %s success: %s, limit: %d, offset: %d", table, b, config.BatchSize, offset)
 		}
 		offset += len(data)
 	}
 	// drop old table
-	_, err := starrocks.Exec(fmt.Sprintf("drop table if exists %s", starrocksTable))
+	_, err = starrocks.Exec(fmt.Sprintf("drop table if exists %s", starrocksTable))
 	if err != nil {
 		return err
 	}
