@@ -6,7 +6,7 @@ The ASF licenses this file to You under the Apache License, Version 2.0
 (the "License"); you may not use this file except in compliance with
 the License.  You may obtain a copy of the License at
 
-	http://www.apache.org/licenses/LICENSE-2.0
+    http://www.apache.org/licenses/LICENSE-2.0
 
 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
@@ -14,9 +14,13 @@ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 */
+
 package main
 
-import "strings"
+import (
+	"fmt"
+	"strings"
+)
 
 func getTablesByDomainLayer(domainLayer string) []string {
 	switch domainLayer {
@@ -99,6 +103,10 @@ func getDataType(dataType string) string {
 		starrocksDatatype = "double"
 	} else if stringIn(dataType, "json", "jsonb") {
 		starrocksDatatype = "json"
+	} else if dataType == "uuid" {
+		starrocksDatatype = "char(36)"
+	} else if strings.HasSuffix(dataType, "[]") {
+		starrocksDatatype = fmt.Sprintf("array<%s>", getDataType(strings.Split(dataType, "[]")[0]))
 	}
 	return starrocksDatatype
 }
