@@ -19,6 +19,7 @@ package impl
 
 import (
 	"fmt"
+	"github.com/apache/incubator-devlake/errors"
 	"time"
 
 	"github.com/apache/incubator-devlake/plugins/helper"
@@ -30,7 +31,6 @@ import (
 	"github.com/apache/incubator-devlake/plugins/tapd/models"
 	"github.com/apache/incubator-devlake/plugins/tapd/models/migrationscripts"
 	"github.com/apache/incubator-devlake/plugins/tapd/tasks"
-	"github.com/mitchellh/mapstructure"
 	"github.com/spf13/viper"
 	"gorm.io/gorm"
 )
@@ -44,7 +44,7 @@ var _ core.CloseablePluginTask = (*Tapd)(nil)
 
 type Tapd struct{}
 
-func (plugin Tapd) Init(config *viper.Viper, logger core.Logger, db *gorm.DB) error {
+func (plugin Tapd) Init(config *viper.Viper, logger core.Logger, db *gorm.DB) errors.Error {
 	api.Init(config, logger, db)
 	return nil
 }
@@ -158,14 +158,14 @@ func (plugin Tapd) SubTaskMetas() []core.SubTaskMeta {
 	}
 }
 
-func (plugin Tapd) PrepareTaskData(taskCtx core.TaskContext, options map[string]interface{}) (interface{}, error) {
+func (plugin Tapd) PrepareTaskData(taskCtx core.TaskContext, options map[string]interface{}) (interface{}, errors.Error) {
 	var op tasks.TapdOptions
-	err := mapstructure.Decode(options, &op)
+	err := helper.Decode(options, &op, nil)
 	if err != nil {
 		return nil, err
 	}
 	if op.ConnectionId == 0 {
-		return nil, fmt.Errorf("connectionId is invalid")
+		return nil, errors.BadInput.New("connectionId is invalid")
 	}
 	connection := &models.TapdConnection{}
 	connectionHelper := helper.NewConnectionHelper(
@@ -179,9 +179,9 @@ func (plugin Tapd) PrepareTaskData(taskCtx core.TaskContext, options map[string]
 
 	var since time.Time
 	if op.Since != "" {
-		since, err = time.Parse("2006-01-02T15:04:05Z", op.Since)
+		since, err = errors.Convert01(time.Parse("2006-01-02T15:04:05Z", op.Since))
 		if err != nil {
-			return nil, fmt.Errorf("invalid value for `since`: %w", err)
+			return nil, errors.BadInput.Wrap(err, "invalid value for `since`")
 		}
 	}
 	if connection.RateLimitPerHour == 0 {
@@ -189,7 +189,7 @@ func (plugin Tapd) PrepareTaskData(taskCtx core.TaskContext, options map[string]
 	}
 	tapdApiClient, err := tasks.NewTapdApiClient(taskCtx, connection)
 	if err != nil {
-		return nil, fmt.Errorf("failed to create tapd api client: %w", err)
+		return nil, errors.Default.Wrap(err, "failed to create tapd api client")
 	}
 	taskData := &tasks.TapdTaskData{
 		Options:    &op,
@@ -231,10 +231,10 @@ func (plugin Tapd) ApiResources() map[string]map[string]core.ApiResourceHandler
 	}
 }
 
-func (plugin Tapd) Close(taskCtx core.TaskContext) error {
+func (plugin Tapd) Close(taskCtx core.TaskContext) errors.Error {
 	data, ok := taskCtx.GetData().(*tasks.TapdTaskData)
 	if !ok {
-		return fmt.Errorf("GetData failed when try to close %+v", taskCtx)
+		return errors.Default.New(fmt.Sprintf("GetData failed when try to close %+v", taskCtx))
 	}
 	data.ApiClient.Release()
 	return nil
