@@ -18,18 +18,18 @@ limitations under the License.
 package archived
 
 import (
-	"github.com/apache/incubator-devlake/models/common"
+	"github.com/apache/incubator-devlake/models/migrationscripts/archived"
 	"github.com/apache/incubator-devlake/plugins/helper"
 )
 
 type TapdIterationTask struct {
-	common.NoPKModel
+	archived.NoPKModel
 	ConnectionId    uint64 `gorm:"primaryKey"`
 	IterationId     uint64 `gorm:"primaryKey"`
 	TaskId          uint64 `gorm:"primaryKey"`
-	WorkspaceID     uint64 `gorm:"primaryKey"`
-	ResolutionDate  helper.CSTTime
-	TaskCreatedDate helper.CSTTime
+	WorkspaceId     uint64 `gorm:"primaryKey"`
+	ResolutionDate  *helper.CSTTime
+	TaskCreatedDate *helper.CSTTime
 }
 
 func (TapdIterationTask) TableName() string {
