@@ -19,7 +19,7 @@ package tasks
 
 import (
 	"encoding/json"
-
+	"github.com/apache/incubator-devlake/errors"
 	"github.com/apache/incubator-devlake/plugins/core"
 	"github.com/apache/incubator-devlake/plugins/helper"
 	"github.com/apache/incubator-devlake/plugins/tapd/models"
@@ -35,20 +35,20 @@ var ExtractBugCommitMeta = core.SubTaskMeta{
 	DomainTypes:      []string{core.DOMAIN_TYPE_CROSS},
 }
 
-func ExtractBugCommits(taskCtx core.SubTaskContext) error {
+func ExtractBugCommits(taskCtx core.SubTaskContext) errors.Error {
 	rawDataSubTaskArgs, data := CreateRawDataSubTaskArgs(taskCtx, RAW_BUG_COMMIT_TABLE, false)
 	extractor, err := helper.NewApiExtractor(helper.ApiExtractorArgs{
 		RawDataSubTaskArgs: *rawDataSubTaskArgs,
-		Extract: func(row *helper.RawData) ([]interface{}, error) {
+		Extract: func(row *helper.RawData) ([]interface{}, errors.Error) {
 			var issueCommitBody models.TapdBugCommit
-			err := json.Unmarshal(row.Data, &issueCommitBody)
+			err := errors.Convert(json.Unmarshal(row.Data, &issueCommitBody))
 			if err != nil {
 				return nil, err
 			}
 			toolL := issueCommitBody
 			toolL.ConnectionId = data.Options.ConnectionId
 			issue := SimpleBug{}
-			err = json.Unmarshal(row.Input, &issue)
+			err = errors.Convert(json.Unmarshal(row.Input, &issue))
 			if err != nil {
 				return nil, err
 			}
