@@ -18,7 +18,9 @@ limitations under the License.
 package tasks
 
 import (
+	goerror "errors"
 	"fmt"
+	"github.com/apache/incubator-devlake/errors"
 	"github.com/apache/incubator-devlake/plugins/core"
 	"github.com/apache/incubator-devlake/plugins/core/dal"
 	"github.com/apache/incubator-devlake/plugins/helper"
@@ -32,7 +34,7 @@ const RAW_STORY_CHANGELOG_TABLE = "tapd_api_story_changelogs"
 
 var _ core.SubTaskEntryPoint = CollectStoryChangelogs
 
-func CollectStoryChangelogs(taskCtx core.SubTaskContext) error {
+func CollectStoryChangelogs(taskCtx core.SubTaskContext) errors.Error {
 	rawDataSubTaskArgs, data := CreateRawDataSubTaskArgs(taskCtx, RAW_STORY_CHANGELOG_TABLE, false)
 	db := taskCtx.GetDal()
 	logger := taskCtx.GetLogger()
@@ -47,8 +49,8 @@ func CollectStoryChangelogs(taskCtx core.SubTaskContext) error {
 			dal.Orderby("created DESC"),
 		}
 		err := db.First(&latestUpdated, clauses...)
-		if err != nil && err != gorm.ErrRecordNotFound {
-			return fmt.Errorf("failed to get latest tapd changelog record: %w", err)
+		if err != nil && !goerror.Is(err, gorm.ErrRecordNotFound) {
+			return errors.NotFound.Wrap(err, "failed to get latest tapd changelog record")
 		}
 		if latestUpdated.Id > 0 {
 			since = (*time.Time)(latestUpdated.Created)
@@ -62,7 +64,7 @@ func CollectStoryChangelogs(taskCtx core.SubTaskContext) error {
 		ApiClient:          data.ApiClient,
 		PageSize:           100,
 		UrlTemplate:        "story_changes",
-		Query: func(reqData *helper.RequestData) (url.Values, error) {
+		Query: func(reqData *helper.RequestData) (url.Values, errors.Error) {
 			query := url.Values{}
 			query.Set("workspace_id", fmt.Sprintf("%v", data.Options.WorkspaceId))
 			query.Set("page", fmt.Sprintf("%v", reqData.Pager.Page))
@@ -76,7 +78,7 @@ func CollectStoryChangelogs(taskCtx core.SubTaskContext) error {
 		ResponseParser: GetRawMessageArrayFromResponse,
 	})
 	if err != nil {
-		logger.Error("collect story changelog error:", err)
+		logger.Error(err, "collect story changelog error")
 		return err
 	}
 	return collector.Execute()
