@@ -18,7 +18,9 @@ limitations under the License.
 package tasks
 
 import (
+	goerror "errors"
 	"fmt"
+	"github.com/apache/incubator-devlake/errors"
 	"gorm.io/gorm"
 	"net/url"
 	"time"
@@ -33,7 +35,7 @@ const RAW_TASK_TABLE = "tapd_api_tasks"
 
 var _ core.SubTaskEntryPoint = CollectTasks
 
-func CollectTasks(taskCtx core.SubTaskContext) error {
+func CollectTasks(taskCtx core.SubTaskContext) errors.Error {
 	rawDataSubTaskArgs, data := CreateRawDataSubTaskArgs(taskCtx, RAW_TASK_TABLE, false)
 	db := taskCtx.GetDal()
 
@@ -50,8 +52,8 @@ func CollectTasks(taskCtx core.SubTaskContext) error {
 			dal.Orderby("modified DESC"),
 		}
 		err := db.First(&latestUpdated, clauses...)
-		if err != nil && err != gorm.ErrRecordNotFound {
-			return fmt.Errorf("failed to get latest tapd changelog record: %w", err)
+		if err != nil && !goerror.Is(err, gorm.ErrRecordNotFound) {
+			return errors.NotFound.Wrap(err, "failed to get latest tapd changelog record")
 		}
 		if latestUpdated.Id > 0 {
 			since = (*time.Time)(latestUpdated.Modified)
@@ -65,7 +67,7 @@ func CollectTasks(taskCtx core.SubTaskContext) error {
 		ApiClient:          data.ApiClient,
 		PageSize:           100,
 		UrlTemplate:        "tasks",
-		Query: func(reqData *helper.RequestData) (url.Values, error) {
+		Query: func(reqData *helper.RequestData) (url.Values, errors.Error) {
 			query := url.Values{}
 			query.Set("workspace_id", fmt.Sprintf("%v", data.Options.WorkspaceId))
 			query.Set("page", fmt.Sprintf("%v", reqData.Pager.Page))
@@ -80,7 +82,7 @@ func CollectTasks(taskCtx core.SubTaskContext) error {
 		ResponseParser: GetRawMessageArrayFromResponse,
 	})
 	if err != nil {
-		logger.Error("collect task error:", err)
+		logger.Error(err, "collect task error")
 		return err
 	}
 	return collector.Execute()
