@@ -19,7 +19,9 @@ package tasks
 
 import (
 	"encoding/json"
+	goerror "errors"
 	"fmt"
+	"github.com/apache/incubator-devlake/errors"
 	"gorm.io/gorm"
 	"net/http"
 	"net/url"
@@ -40,7 +42,7 @@ type SimpleTask struct {
 	Id uint64
 }
 
-func CollectTaskCommits(taskCtx core.SubTaskContext) error {
+func CollectTaskCommits(taskCtx core.SubTaskContext) errors.Error {
 	rawDataSubTaskArgs, data := CreateRawDataSubTaskArgs(taskCtx, RAW_TASK_COMMIT_TABLE, false)
 	db := taskCtx.GetDal()
 	logger := taskCtx.GetLogger()
@@ -56,8 +58,8 @@ func CollectTaskCommits(taskCtx core.SubTaskContext) error {
 			dal.Orderby("created DESC"),
 		}
 		err := db.First(&latestUpdated, clauses...)
-		if err != nil && err != gorm.ErrRecordNotFound {
-			return fmt.Errorf("failed to get latest tapd changelog record: %w", err)
+		if err != nil && !goerror.Is(err, gorm.ErrRecordNotFound) {
+			return errors.NotFound.Wrap(err, "failed to get latest tapd changelog record")
 		}
 		if latestUpdated.Id > 0 {
 			since = (*time.Time)(latestUpdated.Created)
@@ -88,7 +90,7 @@ func CollectTaskCommits(taskCtx core.SubTaskContext) error {
 		//PageSize:    100,
 		Input:       iterator,
 		UrlTemplate: "code_commit_infos",
-		Query: func(reqData *helper.RequestData) (url.Values, error) {
+		Query: func(reqData *helper.RequestData) (url.Values, errors.Error) {
 			input := reqData.Input.(*SimpleTask)
 			query := url.Values{}
 			query.Set("workspace_id", fmt.Sprintf("%v", data.Options.WorkspaceId))
@@ -97,7 +99,7 @@ func CollectTaskCommits(taskCtx core.SubTaskContext) error {
 			query.Set("order", "created asc")
 			return query, nil
 		},
-		ResponseParser: func(res *http.Response) ([]json.RawMessage, error) {
+		ResponseParser: func(res *http.Response) ([]json.RawMessage, errors.Error) {
 			var data struct {
 				Stories []json.RawMessage `json:"data"`
 			}
@@ -111,7 +113,7 @@ func CollectTaskCommits(taskCtx core.SubTaskContext) error {
 		},
 	})
 	if err != nil {
-		logger.Error("collect issueCommit error:", err)
+		logger.Error(err, "collect issueCommit error")
 		return err
 	}
 	return collector.Execute()
