@@ -20,6 +20,7 @@ package tasks
 import (
 	"encoding/json"
 	"fmt"
+	"github.com/apache/incubator-devlake/errors"
 	"net/http"
 	"net/url"
 
@@ -31,7 +32,7 @@ const RAW_TASK_CUSTOM_FIELDS_TABLE = "tapd_api_task_custom_fields"
 
 var _ core.SubTaskEntryPoint = CollectTaskCustomFields
 
-func CollectTaskCustomFields(taskCtx core.SubTaskContext) error {
+func CollectTaskCustomFields(taskCtx core.SubTaskContext) errors.Error {
 	rawDataSubTaskArgs, data := CreateRawDataSubTaskArgs(taskCtx, RAW_TASK_CUSTOM_FIELDS_TABLE, false)
 	logger := taskCtx.GetLogger()
 	logger.Info("collect task_custom_fields")
@@ -40,12 +41,12 @@ func CollectTaskCustomFields(taskCtx core.SubTaskContext) error {
 		ApiClient:          data.ApiClient,
 		//PageSize:    100,
 		UrlTemplate: "tasks/custom_fields_settings",
-		Query: func(reqData *helper.RequestData) (url.Values, error) {
+		Query: func(reqData *helper.RequestData) (url.Values, errors.Error) {
 			query := url.Values{}
 			query.Set("workspace_id", fmt.Sprintf("%v", data.Options.WorkspaceId))
 			return query, nil
 		},
-		ResponseParser: func(res *http.Response) ([]json.RawMessage, error) {
+		ResponseParser: func(res *http.Response) ([]json.RawMessage, errors.Error) {
 			var data struct {
 				TaskCustomFields []json.RawMessage `json:"data"`
 			}
@@ -54,7 +55,7 @@ func CollectTaskCustomFields(taskCtx core.SubTaskContext) error {
 		},
 	})
 	if err != nil {
-		logger.Error("collect task_custom_fields error:", err)
+		logger.Error(err, "collect task_custom_fields error")
 		return err
 	}
 	return collector.Execute()
