@@ -19,6 +19,7 @@ package runner
 
 import (
 	"fmt"
+	"github.com/apache/incubator-devlake/errors"
 	"net/url"
 	"strings"
 	"time"
@@ -32,7 +33,7 @@ import (
 )
 
 // NewGormDb FIXME ...
-func NewGormDb(config *viper.Viper, logger core.Logger) (*gorm.DB, error) {
+func NewGormDb(config *viper.Viper, logger core.Logger) (*gorm.DB, errors.Error) {
 	dbLoggingLevel := gormLogger.Error
 	switch strings.ToLower(config.GetString("DB_LOGGING_LEVEL")) {
 	case "silent":
@@ -67,32 +68,32 @@ func NewGormDb(config *viper.Viper, logger core.Logger) (*gorm.DB, error) {
 	}
 	dbUrl := config.GetString("DB_URL")
 	if dbUrl == "" {
-		return nil, fmt.Errorf("DB_URL is required")
+		return nil, errors.BadInput.New("DB_URL is required")
 	}
 	u, err := url.Parse(dbUrl)
 	if err != nil {
-		return nil, err
+		return nil, errors.Convert(err)
 	}
 	var db *gorm.DB
 	switch strings.ToLower(u.Scheme) {
 	case "mysql":
-		dbUrl = fmt.Sprintf(("%s@tcp(%s)%s?%s"), u.User.String(), u.Host, u.Path, u.RawQuery)
+		dbUrl = fmt.Sprintf("%s@tcp(%s)%s?%s", u.User.String(), u.Host, u.Path, u.RawQuery)
 		db, err = gorm.Open(mysql.Open(dbUrl), dbConfig)
 	case "postgresql", "postgres", "pg":
 		db, err = gorm.Open(postgres.Open(dbUrl), dbConfig)
 	default:
-		return nil, fmt.Errorf("invalid DB_URL:%s", dbUrl)
+		return nil, errors.BadInput.New(fmt.Sprintf("invalid DB_URL:%s", dbUrl))
 	}
 	if err != nil {
-		return nil, err
+		return nil, errors.Convert(err)
 	}
 	sqlDB, err := db.DB()
 	if err != nil {
-		return nil, err
+		return nil, errors.Convert(err)
 	}
 	sqlDB.SetMaxIdleConns(idleConns)
 	sqlDB.SetMaxOpenConns(dbMaxOpenConns)
 	sqlDB.SetConnMaxLifetime(time.Hour)
 
-	return db, err
+	return db, errors.Convert(err)
 }
