@@ -17,20 +17,23 @@ limitations under the License.
 
 package services
 
-import "github.com/apache/incubator-devlake/models/domainlayer/code"
+import (
+	"github.com/apache/incubator-devlake/errors"
+	"github.com/apache/incubator-devlake/models/domainlayer/code"
+)
 
 // GetRepos FIXME ...
-func GetRepos() ([]*code.Repo, int64, error) {
+func GetRepos() ([]*code.Repo, int64, errors.Error) {
 	repos := make([]*code.Repo, 0)
 	db := db.Model(repos).Order("id DESC")
 	var count int64
 	err := db.Count(&count).Error
 	if err != nil {
-		return nil, 0, err
+		return nil, 0, errors.Convert(err)
 	}
 	err = db.Find(&repos).Error
 	if err != nil {
-		return nil, count, err
+		return nil, count, errors.Convert(err)
 	}
 	return repos, count, nil
 }
