@@ -19,34 +19,35 @@ package utils
 
 import (
 	"fmt"
+	"github.com/apache/incubator-devlake/errors"
 	"net"
 	"time"
 )
 
 // CheckDNS FIXME ...
-func CheckDNS(domain string) error {
+func CheckDNS(domain string) errors.Error {
 	ips, err := net.LookupIP(domain)
 	if err != nil {
-		return err
+		return errors.Convert(err)
 	}
 	if len(ips) > 0 {
 		return nil
 	}
-	return fmt.Errorf("failed to resolve host: %s", domain)
+	return errors.Default.New(fmt.Sprintf("failed to resolve host: %s", domain))
 }
 
 // CheckNetwork FIXME ...
-func CheckNetwork(host, port string, timeout time.Duration) error {
+func CheckNetwork(host, port string, timeout time.Duration) errors.Error {
 	var target = fmt.Sprintf("%s:%s", host, port)
 	_, err := net.DialTimeout("tcp", target, timeout)
 	if err != nil {
-		return err
+		return errors.Convert(err)
 	}
 	return nil
 }
 
 // ResolvePort FIXME ...
-func ResolvePort(port string, schema string) (string, error) {
+func ResolvePort(port string, schema string) (string, errors.Error) {
 	var defaultPorts = map[string]string{
 		"http":  "80",
 		"https": "443",
@@ -57,9 +58,9 @@ func ResolvePort(port string, schema string) (string, error) {
 	if schema != "" {
 		port, ok := defaultPorts[schema]
 		if !ok {
-			return "", fmt.Errorf("schema %s not found", schema)
+			return "", errors.Default.New(fmt.Sprintf("schema %s not found", schema))
 		}
 		return port, nil
 	}
-	return "", fmt.Errorf("you should provide at least one of port or schema")
+	return "", errors.Default.New("you should provide at least one of port or schema")
 }
